(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     35433,       1071]*)
(*NotebookOutlinePosition[     61256,       2015]*)
(*  CellTagsIndexPosition[     61212,       2011]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Alberi", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Tree[root,t1,...,tn]",
    FontWeight->"Bold"],
  "\nAlbero con radice root e rami t1,...,tn, con n >= 0."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Tree]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["TreeQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un albero.\n",
  StyleBox["EmptyTreeQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un albero vuoto.\n",
  StyleBox["LeafQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' una foglia."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[TreeQ,LeafQ]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell["\<\
TreeQ[x_] := MatchQ[x,Tree[_,___?TreeQ]]

EmptyTreeQ[x_] := MatchQ[x,Tree[Null]]

LeafQ[x_] := MatchQ[x,Tree[_,___?EmptyTreeQ]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["GetNode[t]",
    FontWeight->"Bold"],
  "\nContenuto della radice dell'albero t.\n",
  StyleBox["GetNode[t,p]",
    FontWeight->"Bold"],
  "\nContenuto del nodo di posizione p nell'albero t.\n",
  StyleBox["SetNode[t,x]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t ponendo il contenuto della radice uguale ad x.\n",
  StyleBox["SetNode[t,p,x]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t ponendo il contenuto del nodo di posizione p uguale \
ad x."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[GetNode,SetNode]

GetNode[t_Tree,p_:{}] := Extract[t,Flatten[{p + 1,1}]]
SetNode[t_Tree,p_:{},x_] := ReplacePart[t,x,Flatten[{p + 1,1}]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["GetBranch[t,p]",
    FontWeight->"Bold"],
  "\nRamo dell'albero t uscente dal nodo di posizione p.",
  StyleBox["\nSetBranch[t,p,b]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t sostituendo con b il ramo di posizione p.\n",
  StyleBox["InsertBranch[t,p,b]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t inserendo il ramo b nella posizione p.\n",
  StyleBox["DeleteBranch[t,p]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t eliminando il ramo di posizione p."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{441, Inherited}],

Cell["\<\
ClearAll[GetBranch,SetBranch,InsertBranch,DeleteBranch]
         
GetBranch[t_Tree,p_] := If[EmptyQ[p],t,Extract[t,p + 1]]
SetBranch[t_Tree,p_,b_Tree] := If[EmptyQ[p],b,ReplacePart[t,b,p + 1]]

InsertBranch[t_Tree,p_,b_Tree] := Insert[t,b,p + 1]
DeleteBranch[t_Tree,p_] := Delete[t,p + 1]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{371, Inherited}],

Cell[TextData[{
  StyleBox["GetBranches[t]",
    FontWeight->"Bold"],
  "\nLista dei rami che escono dalla radice dell'albero t.\n",
  StyleBox["GetBranches[t,p]",
    FontWeight->"Bold"],
  "\nLista dei rami che escono dal nodo di posizione p nell'albero t.\n",
  StyleBox["SetBranches[t,{b1,...,bn}]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t ponendo i rami uguali a b1,...,bn.\n",
  StyleBox["SetBranches[t,p,{b1,...,bn}]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t ponendo i rami uscenti dal nodo di posizione p \
uguali a b1,...,bn."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{441, Inherited}],

Cell["\<\
ClearAll[GetBranches,SetBranches]
         
GetBranches[t_Tree,p_:{}] := 
  If[EmptyQ[p],Apply[List,Rest[t]],
     Apply[List,Rest[Extract[t,p + 1]]]]

SetBranches[t_Tree,p_:{},{b___Tree}] :=
  If[EmptyQ[p],Tree[GetNode[t],b],
     ReplacePart[t,Tree[GetNode[t,p],b],p + 1]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{371, Inherited}],

Cell[TextData[{
  StyleBox["NodeOrder[t]  \n",
    FontWeight->"Bold"],
  "Numero dei rami uscenti dalla radice dell'albero t.",
  StyleBox["\nNodeOrder[t,p]\n",
    FontWeight->"Bold"],
  "Numero dei rami uscenti dal nodo di posizione p nell'albero t."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{441, Inherited}],

Cell["\<\
ClearAll[NodeOrder]
         
NodeOrder[t_Tree,p_:{}] := Length[GetBranches[t,p]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{371, Inherited}],

Cell[TextData[{
  StyleBox["TreeHeight[t]",
    FontWeight->"Bold"],
  "\nAltezza dell'albero t.\n",
  StyleBox["NodeCount[t]",
    FontWeight->"Bold"],
  "\nNumero dei nodi dell'albero t.\n",
  StyleBox["LeafCount[t]",
    FontWeight->"Bold"],
  "\nNumero delle foglie dell'albero t."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "Unprotect[LeafCount];\nClearAll[TreeHeight,NodeCount,LeafCount]\n",
  StyleBox["\nTreeHeight[t_Tree] := \n  ",
    FontFamily->"Courier"],
  "If[LeafQ[t],0,\n     1 + Max[Map[TreeHeight,GetBranches[t]]]]\n  \n",
  StyleBox["NodeCount[t_Tree] := ",
    FontFamily->"Courier"],
  "\n  If[LeafQ[t],1,\n     1 + Apply[Plus,Map[NodeCount,GetBranches[t]]]]\n\n\
Leaf",
  StyleBox["Count[t_Tree] := ",
    FontFamily->"Courier"],
  "\n  If[LeafQ[t],1,\n     Apply[Plus,Map[LeafCount,GetBranches[t]]]]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["NodeList[t]",
    FontWeight->"Bold"],
  "\nLista dei contenuti dei nodi dell'albero t.\n",
  StyleBox["NodeLevList[t]",
    FontWeight->"Bold"],
  "\nLista dei contenuti dei nodi dell'albero t scanditi per livelli.\n",
  StyleBox["LeafList[t]",
    FontWeight->"Bold"],
  "\nLista dei contenuti delle foglie dell'albero t."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "ClearAll[NodeList,NodeLevList,LeafList]\n",
  StyleBox["\nNodeList[t_Tree] := ",
    FontFamily->"Courier"],
  "\n  If[LeafQ[t],{GetNode[t]},\n     \
Join[{GetNode[t]},Apply[Join,Map[NodeList,GetBranches[t]]]]]\n\n\
NodeLevList[t_Tree] :=\n  Module[{levlist},\n    levlist[tl_] :=\n      \
Module[{rl = Map[GetNode,tl]},\n        If[EmptyQ[rl],{},\n           \
Join[rl,levlist[Apply[Join,Map[GetBranches,tl]]]]]];\n    levlist[{t}]]\n    \
\nLeaf",
  StyleBox["List[t_Tree] := ",
    FontFamily->"Courier"],
  "\n  If[LeafQ[t],{GetNode[t]},\n     \
Apply[Join,Map[LeafList,GetBranches[t]]]]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["TreePlot[t]",
    FontWeight->"Bold"],
  "\nRappresentazione grafica dell'albero t.\n",
  StyleBox["TreePlot[t,n]",
    FontWeight->"Bold"],
  "\nRappresentazione grafica dell'albero t fino ai rami di ordine n."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "ClearAll[TreePlot]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "TreePlot",
  StyleBox["[t_?TreeQ,n_Integer:-1,opts___?OptionQ]",
    FontFamily->"Courier"],
  " := \n  Module[{plot,x=0,y=0},\n    plot[tt_,m_] := \n      Module[{node = \
GetNode[tt],\n              x0=x,x1=x+.6,y0=y,y1=y},\n        {If[x > \
0,{Line[{{x-.4,y},{x,y}}]},{}],\n         If[LeafQ[tt] || m == 0,\n           \
 y-=.2;Nothing,\n            {Line[{{x0,y0},{x1,y0}}],\n             x++; \
Map[(y1=y; plot[#,m-1])&,GetBranches[tt]],\n             x--; \
If[y0==y1,Nothing,Line[{{x1,y0},{x1,y1}}]]}],  \n         \
If[NullQ[node],Nothing,\n            Text[StringJoin[\" \",\n                 \
  ToString[node,FormatType -> StandardForm],\" \"],\n                 \
{x0,y0},{-1,0},Background -> GrayLevel[1]]]}];\n    Show[Graphics[plot[t,n]],\
\n         opts,AspectRatio -> Automatic,PlotRange -> All]]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["Alberi binari", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero binario e' un albero in cui da ogni nodo non terminale \
escono due rami. I nodi terminali non utilizzati contengono Null.\
\>", \
"Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["BinTreeQ[x]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un albero booleano.\n",
  StyleBox["BinTree[l]",
    FontWeight->"Bold"],
  "\nAlbero binario corrispondente alla lista (o sequenza) l."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "ClearAll[BinTreeQ,BinTree]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "BinTreeQ[x_] := MatchQ[x,Tree[Null]|Tree[_,_?BinTreeQ,_?BinTreeQ]]\n\n\
BinTree[l_List] :=\n  \
If[EmptyQ[l],Tree[Null],Tree[First[l],BinTree[Rest[l]],Tree[Null]]]\n\n\
BinTree[x___] := BinTree[{x}]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["BinTreeAntList[t]",
    FontWeight->"Bold"],
  "\nLista degli elementi dell'albero binario t scanditi in modo anticipato.\n\
",
  StyleBox["BinTreeLevList[t]",
    FontWeight->"Bold"],
  "\nLista degli elementi dell'albero binario t scanditi per livelli.\n",
  StyleBox["BinTreeSymList[t]",
    FontWeight->"Bold"],
  "\nLista degli elementi dell'albero binario t scanditi in modo simmetrico."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "ClearAll[BinTreeAntList,BinTreeSymList,BinTreeLevList]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "BinTreeAntList[t_Tree] := NodeList[t] /. Null -> Nothing\n\n\
BinTreeLevList[t_Tree] := NodeLevList[t] /. Null -> Nothing\n\n",
  "BinTreeSymList[t_Tree] :=\n  If[LeafQ[t],{GetNode[t]},\n     \
Join[BinTreeSymList[GetBranch[t,1]],{GetNode[t]},\n          \
BinTreeSymList[GetBranch[t,2]]]] /. Null -> Nothing\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["BinTreeAnt[l]",
    FontWeight->"Bold"],
  "\nAlbero binario quasi-bilanciato contenente gli elementi della lista l \
inseriti in modo anticipato.\n",
  StyleBox["BinTreeLev[l]",
    FontWeight->"Bold"],
  "\nAlbero binario quasi-bilanciato contenente gli elementi della lista l \
inseriti per livelli.\n",
  StyleBox["BinTreeSym[l]",
    FontWeight->"Bold"],
  "\nAlbero binario quasi-bilanciato contenente gli elementi della lista l \
inseriti in modo simmetrico."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  "ClearAll[BinTreeAnt,BinTreeSym,BinTreeLev]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "BinTreeAnt[l_List] :=\n  If[EmptyQ[l],BinTree[],\n     Module[{m = \
Floor[Length[l] / 2]},\n       Tree[First[l],BinTreeAnt[Take[Rest[l],m]],\n   \
                  BinTreeAnt[Drop[l,m + 1]]]]]\n\nBinTreeLev[l_List] :=\n  \
If[EmptyQ[l],BinTree[],\n     Module[{treelev},\n       treelev[ll_,n_] :=\n  \
       If[n <= Length[ll],\n            MapThread[Tree[##]&,\n               \
Join[{Take[ll,n]},\n                    Thread[Partition[treelev[Drop[ll,n],2 \
n],2]]]],\n            Join[Map[BinTree[{#}]&,ll],\n                 \
Table[BinTree[],{n - Length[ll]}]]];\n    treelev[l,1][[1]]]]\n",
  StyleBox["\n",
    FontFamily->"Courier"],
  "BinTreeSym[l_List] :=\n  If[EmptyQ[l],BinTree[],\n     Module[{m = \
Floor[Length[l] / 2]},\n       Tree[l[[m + 1]],BinTreeSym[Take[l,m]],\n       \
                BinTreeSym[Drop[l,m + 1]]]]]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["Alberi con chiavi", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero con chiavi e' un albero binario in cui il contenuto di \
ciascun nodo e' un coppia del tipo {chiave,dati}.\
\>", "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["GetKey[t]  GetData[t]",
    FontWeight->"Bold"],
  "\nChiave/dati contenuti nella radice dell'albero t.\n",
  StyleBox["GetKey[t,p]  GetData[t,p]",
    FontWeight->"Bold"],
  "\nChiave/dati contenuti nel nodo di posizione p dell'albero ordinato t.\n\
",
  StyleBox["SetKey[t,x]  SetData[t,x]",
    FontWeight->"Bold"],
  "\nAlbero ottenuto da t ponendo chiave/dati della radice uguali ad x.\n",
  StyleBox["SetKey[t,p,x]  SetData[t,p,x]\n",
    FontWeight->"Bold"],
  "Albero ottenuto da t ponendo chiave/dati del nodo di posizione p uguali ad \
x."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[GetKey,GetData,SetKey,SetData]

GetKey[t_Tree,p_:{}] := GetKey[GetNode[t,p]]
GetKey[x_List] := First[x]
GetKey[x_] := x

GetData[t_Tree,p_:{}] := GetData[GetNode[t,p]]
GetData[x_List] := Last[x] 
GetData[x_] := x

SetKey[t_Tree,p_:{},x_] := SetNode[t,p,{x,GetData[t,p]}]

SetData[t_Tree,p_:{},x_] := SetNode[t,p,{GetKey[t,p],x}]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["Alberi ordinati", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero ordinato e' un albero binario con chiavi in cui la chiave \
di ciascun nodo e' maggiore di quelle dei nodi del primo ramo e minore di \
quelle dei nodi del secondo ramo, secondo un dato ordine.\
\>", "Subsubtitle",\

  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["OrdTreeQ[x]  OrdTreeQ[x,ord]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un albero ordinato rispetto \
alla relazione d'ordine standard/ord.\n",
  StyleBox["OrdTree[l]  OrdTree[l,ord]",
    FontWeight->"Bold"],
  "\nAlbero ordinato quasi-bilanciato contenente gli elementi (del tipo \
{chiave,dati}) della lista (o sequenza) l."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTree,OrdTreeQ]

OrdTreeQ[x_,ord_:(OrderedQ[{#1,#2}]&)] := 
  And[BinTreeQ[x],
      Module[{l = BinTreeSymList[x]},
        And[MatchQ[l,{___List}],OrderedQ[Map[GetKey,l],ord]]]]

OrdTree[l_List,ord_:(OrderedQ[{#1,#2}]&)] := 
  BinTreeSym[Sort[l,ord[GetKey[#1],GetKey[#2]]&]]

OrdTree[x___] := OrdTree[{x}]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTreeMinPos[t]",
    FontWeight->"Bold"],
  "\nPosizione del nodo con chiave minima nell'albero ordinato t.\n",
  StyleBox["OrdTreeMaxPos[t]",
    FontWeight->"Bold"],
  "\nPosizione del nodo con chiave massima nell'albero ordinato t.\n",
  StyleBox["OrdTreePosition[t,k]  OrdTreePosition[t,k,ord]",
    FontWeight->"Bold"],
  "\nPosizione del nodo con chiave k nell'albero ordinato t (Null se tale \
nodo non esiste)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTreeMinPos,OrdTreeMaxPos,OrdTreePosition]

OrdTreeMinPos[t_Tree] :=
  If[EmptyTreeQ[t],Null,
     If[NullQ[GetNode[t,1]],{},
        Join[{1},OrdTreeMinPos[GetBranch[t,1]]]]]

OrdTreeMaxPos[t_Tree] :=
  If[EmptyTreeQ[t],Null,
     If[NullQ[GetNode[t,2]],{},
        Join[{2},OrdTreeMaxPos[GetBranch[t,2]]]]]

OrdTreePosition[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyTreeQ[t],Null,
     Module[{kt = GetKey[t]},
       Which[SameQ[k,kt],{},
             ord[k,kt],
               Module[{p = OrdTreePosition[GetBranch[t,1],k,ord]},
                 If[NullQ[p],Null,Join[{1},p]]],
             ord[kt,k],
               Module[{p = OrdTreePosition[GetBranch[t,2],k,ord]},
                 If[NullQ[p],Null,Join[{2},p]]]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTreeGetMin[t]",
    FontWeight->"Bold"],
  "\nContenuto del nodo con chiave minima dell'albero ordinato t.\n",
  StyleBox["OrdTreeGetMax[t]",
    FontWeight->"Bold"],
  "\nContenuto del nodo con chiave massima dell'albero ordinato t.\n",
  StyleBox["OrdTreeSearch[t,k]  OrdTreeSearch[t,k,ord]",
    FontWeight->"Bold"],
  "\nContenuto del nodo con chiave k dell'albero ordinato t (Null se tale \
nodo non esiste).\n",
  StyleBox["OrdTreeLower[t,k]  OrdTreeLower[t,k,ord]",
    FontWeight->"Bold"],
  "\nContenuto del nodo con la massima chiave inferiore o uguale a k \
dell'albero ordinato t (Null se tale nodo non esiste).\n",
  StyleBox["OrdTreeUpper[t,k]  OrdTreeUpper[t,k,ord]\n",
    FontWeight->"Bold"],
  "Contenuto del nodo con la minima chiave superiore o uguale a k dell'albero \
ordinato t (Null se tale nodo non esiste).\n",
  StyleBox["OrdTreeRange[t,k1,k2]  OrdTreeRange[t,k1,k2,ord]",
    FontWeight->"Bold"],
  "\nLista dei contenuti dei nodi dell'albero ordinato t con chiavi comprese \
tra k1 e k2."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTreeGetMin,OrdTreeGetMax,
         OrdTreeSearch,OrdTreeLower,OrdTreeUpper,OrdTreeRange]

OrdTreeGetMin[t_Tree] :=
  If[EmptyTreeQ[t],Null,
     If[NullQ[GetNode[t,1]],GetNode[t],OrdTreeGetMin[GetBranch[t,1]]]]

OrdTreeGetMax[t_Tree] :=
  If[EmptyTreeQ[t],Null,
     If[NullQ[GetNode[t,2]],GetNode[t],OrdTreeGetMax[GetBranch[t,2]]]]

OrdTreeSearch[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyTreeQ[t],Null,
     Module[{kt = GetKey[t]},
       Which[SameQ[k,kt],GetNode[t],
             ord[k,kt],OrdTreeSearch[GetBranch[t,1],k,ord],
             ord[kt,k],OrdTreeSearch[GetBranch[t,2],k,ord]]]]

OrdTreeLower[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyTreeQ[t],Null,
     Module[{kt = GetKey[t]},
       Which[SameQ[k,kt],GetNode[t],
             ord[k,kt],OrdTreeLower[GetBranch[t,1],k,ord],
             ord[kt,k],Replace[OrdTreeLower[GetBranch[t,2],k,ord],
                               Null -> GetNode[t]]]]]

OrdTreeUpper[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyTreeQ[t],Null,
     Module[{kt = GetKey[t]},
       Which[SameQ[k,kt],GetNode[t],
             ord[kt,k],OrdTreeUpper[GetBranch[t,2],k,ord],
             ord[k,kt],Replace[OrdTreeUpper[GetBranch[t,1],k,ord],
                               Null -> GetNode[t]]]]]

OrdTreeRange[t_Tree,k1_,k2_,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyTreeQ[t],{},
     Module[{kt = GetKey[t]},
       Which[Not[ord[k1,kt]],OrdTreeRange[GetBranch[t,2],k1,k2,ord],
             Not[ord[kt,k2]],OrdTreeRange[GetBranch[t,1],k1,k2,ord],
             True,Join[OrdTreeRange[GetBranch[t,1],k1,k2,ord],
                       {GetNode[t]},
                       OrdTreeRange[GetBranch[t,2],k1,k2,ord]]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTreeInsert[t,x]  OrdTreeInsert[t,x,ord]",
    FontWeight->"Bold"],
  "\nAlbero ordinato ottenuto inserendo in t il nodo x (del tipo \
{chiave,dati}).\n",
  StyleBox["OrdTreeDelete[t,k]  OrdTreeDelete[t,k,ord]",
    FontWeight->"Bold"],
  "\nAlbero ordinato ottenuto eliminando da t il nodo con chiave k.\n",
  StyleBox["OrdTreeDeleteMin[t]",
    FontWeight->"Bold"],
  "\nAlbero ordinato ottenuto eliminando da t il nodo con chiave minima.\n",
  StyleBox["OrdTreeDeleleMax[t]",
    FontWeight->"Bold"],
  "\nAlbero ordinato ottenuto eliminando da t il nodo con chiave massima."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTreeInsert,OrdTreeDelete,OrdTreeDeleteMin,\
OrdTreeDeleteMax]

OrdTreeInsert[t_Tree,x_,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyTreeQ[t],OrdTree[{x}],
     Module[{k = GetKey[x],kt = GetKey[t]},
       Which[SameQ[k,kt],t,
             ord[k,kt],
               SetBranch[t,1,OrdTreeInsert[GetBranch[t,1],x,ord]],
             ord[kt,k],
               SetBranch[t,2,OrdTreeInsert[GetBranch[t,2],x,ord]]]]]

OrdTreeDelete[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyTreeQ[t],t,
     Module[{kt = GetKey[t],t1 = GetBranch[t,1],t2 = GetBranch[t,2]},
       Which[SameQ[k,kt],
               Which[EmptyTreeQ[t1],t2,
                     EmptyTreeQ[t2],t1,
                     True,Tree[OrdTreeGetMax[t1],
                               OrdTreeDeleteMax[t1],t2]],
             ord[k,kt],SetBranch[t,1,OrdTreeDelete[t1,k,ord]],
             ord[kt,k],SetBranch[t,2,OrdTreeDelete[t2,k,ord]]]]]

OrdTreeDeleteMin[t_Tree] :=
  Which[LeafQ[t],OrdTree[],
        NullQ[GetNode[t,1]],GetBranch[t,2],
        True,SetBranch[t,1,OrdTreeDeleteMin[GetBranch[t,1]]]]

OrdTreeDeleteMax[t_Tree] :=
  Which[LeafQ[t],OrdTree[],
        NullQ[GetNode[t,2]],GetBranch[t,1],
        True,SetBranch[t,2,OrdTreeDeleteMax[GetBranch[t,2]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTreeBalance[t]",
    FontWeight->"Bold"],
  "\nAlbero ordinato quasi-bilanciato contenente gli stessi nodi dell'albero \
ordinato t."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTreeBalance]

OrdTreeBalance[t_Tree] := BinTreeSym[BinTreeSymList[t]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["Alberi a priorita'", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero a priorita' e' un albero binario con chiavi in cui la \
chiave di ciascun nodo precede quelle dei nodi del sottoalbero uscente da \
esso, secondo un dato ordine.\
\>", "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["PriTreeQ[x]  PriTreeQ[x,ord]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se x e' un albero a priorita' \
rispetto alla relazione d'ordine standard/ord.\n",
  StyleBox["PriTree[l]  PriTree[l,ord]",
    FontWeight->"Bold"],
  "\nAlbero a priorita' quasi-bilanciato contenente gli elementi (del tipo \
{chiave,dati}) della lista l."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTree,PriTreeQ]

PriTreeQ[x_,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{priTreeQ},
    priTreeQ = MatchQ[#,Tree[Null]|
                (t:Tree[_,t1_?priTreeQ,t2_?priTreeQ] /;
                    And[Or[EmptyTreeQ[t1],ord[GetKey[t],GetKey[t1]]],
                        Or[EmptyTreeQ[t2],ord[GetKey[t],GetKey[t2]]]])]&;
    MatchQ[x,Tree[{_Integer?Positive...},_?priTreeQ]]]

PriTree[l_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyQ[l],Tree[Null,BinTree[]],
     PriTreeInsert[PriTree[Drop[l,-1],ord],Last[l],ord]]

PriTree[x___] := PriTree[{x}]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["PriTreeContent[t]",
    FontWeight->"Bold"],
  "\nContenuto dell'albero a priorita' t.",
  "\n",
  StyleBox["PriTreeLastPos[t]\n",
    FontWeight->"Bold"],
  "Ultima positione utilizzata nell'albero a priorita' t.",
  StyleBox["\nPrevPos[p]  NextPos[p]\n",
    FontWeight->"Bold"],
  "Posizione precedente/successiva nella scansione per livelli di un albero \
binario."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTreeContent,PriTreeLastPos,PrevPos,NextPos]

PriTreeContent[t_Tree] := GetBranch[t,1]

PriTreeLastPos[t_Tree] := GetNode[t]

PrevPos[p_List] := 
  If[EmptyQ[p],Null,
     If[FreeQ[p,2],Table[2,{Length[p] - 1}],
        Module[{l = Last[Position[p,2]][[1]]},
          Join[Take[p,l - 1],{1},Table[2,{Length[p] - l}]]]]]

NextPos[p_List] := 
  If[NullQ[p],{},
     If[FreeQ[p,1],Table[1,{Length[p] + 1}],
        Module[{l = Last[Position[p,1]][[1]]},
          Join[Take[p,l - 1],{2},Table[1,{Length[p] - l}]]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["PriTreeRestoreUp[t,p]  PriTreeRestoreUp[t,p,ord]\n",
    FontWeight->"Bold"],
  "Albero a priorita' ottenuto riordinando i nodi di t dalla posizione p in \
su. ",
  StyleBox["\nPriTreeRestoreDown[t,p]  PriTreeRestoreDown[t,p,ord]\n",
    FontWeight->"Bold"],
  "Albero a priorita' ottenuto riordinando i nodi di t dalla posizione p in \
giu'. "
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTreeRestoreUp,PriTreeRestoreDown]

PriTreeRestoreUp[t_Tree,p_List,ord_:(OrderedQ[{#1,#2}]&)] := 
  If[EmptyQ[p],t,
     Module[{pp = Prepend[p,1],qq = Prepend[Drop[p,-1],1],tt,x},
       If[ord[GetKey[t,qq],GetKey[t,pp]],t,
          tt = SetNode[t,pp,GetNode[t,qq]];
          tt = SetNode[tt,qq,GetNode[t,pp]];
          PriTreeRestoreUp[tt,Drop[p,-1],ord]]]];
  
PriTreeRestoreDown[t_Tree,p_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  Module[{pp = Prepend[p,1],qq,q1,q2,k1,k2,k,tt,x},
    If[LeafQ[GetBranch[t,pp]],t,
       q1 = Append[pp,1]; q2 = Append[pp,2];
       k1 = GetKey[t,q1]; k2 = GetKey[t,q2];
       If[ord[k1,k2],k = k1;qq = q1,k = k2;qq = q2];
       If[ord[GetKey[t,pp],k],t,
          tt = SetNode[t,pp,GetNode[t,qq]];
          tt = SetNode[tt,qq,GetNode[t,pp]];
          PriTreeRestoreDown[tt,Drop[qq,1],ord]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["PriTreePosition[t,k]  PriTreePosition[t,k,ord]\n",
    FontWeight->"Bold"],
  "Posizione del nodo con chiave k nell'albero a priorita' t (Null se tale \
nodo non esiste)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTreePosition]

PriTreePosition[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{lp = PriTreeLastPos[t],pripos},
    pripos[tt_] :=
      Module[{kt,p},
        If[EmptyTreeQ[tt],Null,
           kt = GetKey[tt];
           Which[SameQ[k,kt],{},
                 ord[k,kt],Null,
                 Not[NullQ[p = pripos[GetBranch[tt,1]]]],Join[{1},p],
                 Not[NullQ[p = pripos[GetBranch[tt,2]]]],Join[{2},p]]]];
    If[NullQ[lp],Null,pripos[PriTreeContent[t]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PriTreeGetFirst[t]\n",
    FontWeight->"Bold"],
  "Primo nodo dell'albero a priorita' t.\n",
  StyleBox["PriTreeDeleteFirst[t]  PriTreeDeleteFirst[t,ord]\n",
    FontWeight->"Bold"],
  "Albero a priorita' ottenuto eliminando da t il primo nodo.",
  StyleBox["\nPriTreeInsert[t,x]  PriTreeInsert[t,x,ord]\n",
    FontWeight->"Bold"],
  "Albero a priorita' ottenuto inserendo in t il nodo x (del tipo \
{chiave,dati}).\n",
  StyleBox["PriTreeDelete[t,k]  PriTreeDelete[t,k,ord]\n",
    FontWeight->"Bold"],
  "Albero a priorita' ottenuto eliminando da t il nodo con chiave k."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTreeGetFirst,PriTreeDeleteFirst,
         PriTreeInsert,PriTreeDelete]

PriTreeGetFirst[t_Tree] := GetNode[t,1]

PriTreeDeleteFirst[t_Tree,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{lp = PriTreeLastPos[t],tt},
    If[NullQ[lp],t,
       tt = PriTreeContent[t];
       tt = SetBranch[SetNode[tt,GetNode[tt,lp]],lp,BinTree[]];
       PriTreeRestoreDown[Tree[PrevPos[lp],tt],{},ord]]]
    
PriTreeInsert[t_Tree,x_,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{lp = PriTreeLastPos[t],np,tt},
    If[NullQ[lp],Tree[{},BinTree[{x}]],
       np = NextPos[lp];
       tt = PriTreeContent[t];
       PriTreeRestoreUp[Tree[np,SetBranch[tt,np,BinTree[{x}]]],np,ord]]]

PriTreeDelete[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{p = PriTreePosition[t,k,ord],lp,tt},
    Which[NullQ[p],t,
          EmptyQ[p],PriTreeDeleteFirst[t,ord],
          True,
            lp = PriTreeLastPos[t]; tt = PriTreeContent[t];
            tt = SetBranch[SetNode[tt,p,GetNode[tt,lp]],lp,BinTree[]];
            If[ord[GetKey[tt,lp],GetKey[tt,Drop[p,-1]]],
               PriTreeRestoreUp[Tree[PrevPos[lp],tt],p,ord],
               PriTreeRestoreDown[Tree[PrevPos[lp],tt],p,ord]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["PriTreeSearch[t,k]  PriTreeSearch[t,k,ord]\n",
    FontWeight->"Bold"],
  "Contenuto del nodo con chiave k dell'albero a priorita' t (Null se tale \
nodo non esiste).\n",
  StyleBox["PriTreeRange[t,k1,k2]  PriTreeRange[t,k1,k2,ord]\n",
    FontWeight->"Bold"],
  "Lista dei contenuti dei nodi dell'albero a priorita' t con chiavi comprese \
tra k1 e k2."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PriTreeSearch,PriTreeRange]

PriTreeSearch[t_Tree,k_,ord_:(OrderedQ[{#1,#2}]&)] := 
  Module[{lp = PriTreeLastPos[t],pripos},
    prisearch[tt_] :=
      Module[{kt,n},
        If[EmptyTreeQ[tt],Null,
           kt = GetKey[tt];
           Which[SameQ[k,kt],GetNode[tt],
                 ord[k,kt],Null,
                 Not[NullQ[n = prisearch[GetBranch[tt,1]]]],n,
                 Not[NullQ[n = prisearch[GetBranch[tt,2]]]],n]]];
    If[NullQ[lp],Null,prisearch[PriTreeContent[t]]]]

PriTreeRange[t_Tree,k1_,k2_,ord_:(OrderedQ[{#1,#2}]&)] := Null
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 713},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 353, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2073, 63, 259, 7, 50, "Text"],
Cell[2335, 72, 181, 7, 32, "Input",
  InitializationCell->True],
Cell[2519, 81, 485, 13, 110, "Text"],
Cell[3007, 96, 188, 7, 32, "Input",
  InitializationCell->True],
Cell[3198, 105, 294, 11, 84, "Input",
  InitializationCell->True],
Cell[3495, 118, 617, 17, 155, "Text"],
Cell[4115, 137, 312, 10, 71, "Input",
  InitializationCell->True],
Cell[4430, 149, 630, 16, 140, "Text"],
Cell[5063, 167, 455, 13, 110, "Input",
  InitializationCell->True],
Cell[5521, 182, 682, 17, 155, "Text"],
Cell[6206, 201, 441, 15, 136, "Input",
  InitializationCell->True],
Cell[6650, 218, 378, 10, 80, "Text"],
Cell[7031, 230, 248, 9, 58, "Input",
  InitializationCell->True],
Cell[7282, 241, 410, 13, 110, "Text"],
Cell[7695, 256, 669, 16, 201, "Input",
  InitializationCell->True],
Cell[8367, 274, 477, 13, 110, "Text"],
Cell[8847, 289, 767, 18, 240, "Input",
  InitializationCell->True],
Cell[9617, 309, 364, 10, 80, "Text"],
Cell[9984, 321, 1062, 21, 266, "Input",
  InitializationCell->True],
Cell[11049, 344, 360, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[11412, 358, 416, 12, 62, "Subsubtitle"],
Cell[11831, 372, 377, 10, 80, "Text"],
Cell[12211, 384, 453, 12, 123, "Input",
  InitializationCell->True],
Cell[12667, 398, 546, 14, 110, "Text"],
Cell[13216, 414, 591, 13, 149, "Input",
  InitializationCell->True],
Cell[13810, 429, 619, 16, 155, "Text"],
Cell[14432, 447, 1114, 21, 344, "Input",
  InitializationCell->True],
Cell[15549, 470, 364, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[15916, 484, 398, 11, 62, "Subsubtitle"],
Cell[16317, 497, 702, 18, 155, "Text"],
Cell[17022, 517, 504, 19, 188, "Input",
  InitializationCell->True],
Cell[17529, 538, 362, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[17894, 552, 487, 13, 77, "Subsubtitle"],
Cell[18384, 567, 513, 12, 110, "Text"],
Cell[18900, 581, 485, 17, 162, "Input",
  InitializationCell->True],
Cell[19388, 600, 574, 14, 125, "Text"],
Cell[19965, 616, 910, 28, 305, "Input",
  InitializationCell->True],
Cell[20878, 646, 1173, 26, 260, "Text"],
Cell[22054, 674, 1852, 48, 565, "Input",
  InitializationCell->True],
Cell[23909, 724, 733, 17, 155, "Text"],
Cell[24645, 743, 1399, 38, 422, "Input",
  InitializationCell->True],
Cell[26047, 783, 289, 8, 65, "Text"],
Cell[26339, 793, 248, 9, 58, "Input",
  InitializationCell->True],
Cell[26590, 804, 365, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[26958, 818, 453, 12, 77, "Subsubtitle"],
Cell[27414, 832, 506, 12, 110, "Text"],
Cell[27923, 846, 720, 21, 214, "Input",
  InitializationCell->True],
Cell[28646, 869, 522, 15, 125, "Text"],
Cell[29171, 886, 691, 23, 240, "Input",
  InitializationCell->True],
Cell[29865, 911, 497, 12, 110, "Text"],
Cell[30365, 925, 1008, 26, 279, "Input",
  InitializationCell->True],
Cell[31376, 953, 324, 8, 65, "Text"],
Cell[31703, 963, 538, 16, 188, "Input",
  InitializationCell->True],
Cell[32244, 981, 727, 17, 155, "Text"],
Cell[32974, 1000, 1330, 35, 396, "Input",
  InitializationCell->True],
Cell[34307, 1037, 507, 12, 110, "Text"],
Cell[34817, 1051, 612, 18, 214, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

