(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15320,        459]*)
(*NotebookOutlinePosition[     41691,       1418]*)
(*  CellTagsIndexPosition[     41647,       1414]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Inizializzazione", "Subsubtitle"],

Cell[TextData[StyleBox["Modifica del limite di ricorsione",
  FontWeight->"Bold"]], "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell["\<\
$RecursionLimit = 4096;
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Nothing, NullQ, EmptyQ",
  FontWeight->"Bold"]], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Nothing,NullQ,EmptyQ]

Nothing := Sequence[]

NullQ[x_] := SameQ[x,Null]

EmptyQ[x_] := SameQ[x,{}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RandomPermutation[n]\n",
    FontWeight->"Bold"],
  "Lista ottenuta permutando in modo casuale la lista {1,2,...,n}.",
  StyleBox["\nRandomPermutation[l]\n",
    FontWeight->"Bold"],
  "Lista ottenuta permutando in modo casuale la lista l."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[RandomPermutation]

RandomPermutation[n_Integer?Positive] := 
  Module[{l = Range[n],i,p,t},
    Do[p = Random[Integer,{i,n}];
       t = l[[i]];l[[i]] = l[[p]];l[[p]] = t,{i,1,n - 1}];l]
       
RandomPermutation[l_List] := l[[RandomPermutation[Length[l]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["MinPosition[l]  MinPosition[f,l]\nMinPosition[l,ord]  \
MinPosition[f,l,ord]\n",
    FontWeight->"Bold"],
  "Posizioni del minimo globale della lista l/Map[f,l] rispetto all'ordine \
standard/ord. Nel caso di piu' minimi globali la posizione e' quella del \
primo se l'ordine e' stretto e dell'ultimo altrimenti.\n",
  StyleBox["MaxPosition[l]  MaxPosition[f,l]\nMinPosition[l,ord]  \
MinPosition[f,l,ord]\n",
    FontWeight->"Bold"],
  "Posizioni del massimo globale della lista l/Map[f,l] rispetto all'ordine \
standard/ord. Nel caso di piu' massimi globali la posizione e' quella del \
primo se l'ordine e' stretto e dell'ultimo altrimenti."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[MinPosition,MaxPosition]

MinPosition[l_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyQ[l],Null,
     Module[{m = l[[1]],p = 1,i},
       Do[If[ord[l[[i]],m],m = l[[i]];p = i],{i,2,Length[l]}];p]]

MinPosition[f_,l_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyQ[l],Null,
     Module[{m = f[l[[1]]],n,p = 1,i},
       Do[If[ord[n = f[l[[i]]],m],m = n;p = i],{i,2,Length[l]}];p]]

MaxPosition[l_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyQ[l],Null,
     Module[{m = l[[1]],p = 1,i},
       Do[If[ord[m,l[[i]]],m = l[[i]];p = i],{i,2,Length[l]}];p]]

MaxPosition[f_,l_List,ord_:(OrderedQ[{#1,#2}]&)] :=
  If[EmptyQ[l],Null,
     Module[{m = f[l[[1]]],n,p = 1,i},
       Do[If[ord[m,n = f[l[[i]]]],m = n;p = i],{i,2,Length[l]}];p]]
       \
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FirstRelPosition[l,rel]  FirstRelPosition[f,l,rel]\n",
    FontWeight->"Bold"],
  "Posizione del primo elemento della lista l/Map[f,l] che soddisfa la \
relazione rel con il successivo.\n",
  StyleBox["LastRelPosition[l,rel]  LastRelPosition[f,l,rel]\n",
    FontWeight->"Bold"],
  "Posizione dell'ultimo elemento della lista l/Map[f,l] che soddisfa la \
relazione rel con il successivo.\n",
  StyleBox["ListRelPosition[l,rel]  ListRelPosition[f,l,rel]\n",
    FontWeight->"Bold"],
  "Lista delle posizioni degli elementi ",
  "della lista l/Map[f,l] che soddisfano la relazione rel con i successivi."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FirstRelPosition,LastRelPosition,ListRelPosition]

FirstRelPosition[l_List,rel_] :=
  If[EmptyQ[l],Null,
     Module[{n = Length[l],p = 1},
       While[And[p < n,Not[rel[l[[p]],l[[p + 1]]]]],p++];
       If[p == n,Null,p]]]

FirstRelPosition[f_,l_List,rel_] :=
  If[EmptyQ[l],Null,
     Module[{n = Length[l],p = 1,t = f[l[[1]]]},
       While[And[p < n,Not[rel[t,t = f[l[[p + 1]]]]]],p++];
       If[p == n,Null,p]]]

LastRelPosition[l_List,rel_] :=
  If[EmptyQ[l],Null,
     Module[{p = Length[l]},
       While[And[p > 1,Not[rel[l[[p - 1]],l[[p]]]]],p--];
       If[p == 1,Null,p - 1]]]

LastRelPosition[f_,l_List,rel_] :=
  If[EmptyQ[l],Null,
     Module[{p = Length[l],t1,t2 = f[l[[-1]]]},
       While[And[p > 1,Not[rel[t1 = f[l[[p - 1]]],t2]]],t2 = t1;p--];
       If[p == 1,Null,p - 1]]]

ListRelPosition[l_List,rel_] :=
  If[EmptyQ[l],{},
     Module[{i,p = {}},
       Do[If[rel[l[[i]],l[[i + 1]]],AppendTo[p,i]],
          {i,1,Length[l] - 1}];p]]

ListRelPosition[f_,l_List,rel_] :=
  If[EmptyQ[l],{},
     Module[{i,t = f[l[[1]]],p = {}},
       Do[If[rel[t,t = f[l[[i + 1]]]],AppendTo[p,i]],
          {i,1,Length[l] - 1}];p]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FirstPosition[l,x]  FirstPosition[f,l,x]\n",
    FontWeight->"Bold"],
  "Posizione della prima occorrenza di x nella lista l/Map[f,l].\n",
  StyleBox["LastPosition[l,x]  LastPosition[f,l,x]\n",
    FontWeight->"Bold"],
  "Posizione dell'ultima occorrenza di x nella lista l/Map[f,l].",
  StyleBox["\nListPosition[l,x]  ListPosition[f,l,x]\n",
    FontWeight->"Bold"],
  "Lista delle posizioni delle occorrenze di x nella lista l/Map[f,l]."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FirstPosition,LastPosition,ListPosition]

FirstPosition[l_List,x_] := 
  If[EmptyQ[l],Null,
     Module[{n = Length[l],p = 1},
       While[And[p <= n,Not[MatchQ[l[[p]],x]]],p++];
       If[p > n,Null,p]]]
         
FirstPosition[f_,l_List,x_] := FirstPosition[l,_?(MatchQ[f[#],x]&)]

LastPosition[l_List,x_] := 
  If[EmptyQ[l],Null,
     Module[{p = Length[l]},
       While[And[p >= 1,Not[MatchQ[l[[p]],x]]],p--];
       If[p < 1,Null,p]]]

LastPosition[f_,l_List,x_] := LastPosition[l,_?(MatchQ[f[#],x]&)]

ListPosition[l_List,x_] := Flatten[Position[l,x,{1}]]
ListPosition[f_,l_List,x_] := ListPosition[l,_?(MatchQ[f[#],x]&)]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["CoefficientTable -> True|False\n",
    FontWeight->"Bold"],
  "Opzione per la funzione Fit che regola l'espressione del risultato come \
tabella dei coefficienti delle funzioni test."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
Unprotect[Fit]; ClearAll[FitTable]
Options[Fit] = {CoefficientTable -> False};

Fit[data_,funs_,vars_,opts__?OptionQ] :=
  Module[{fs = Flatten[{funs}],vpt = Apply[Alternatives,vars],
          op = Flatten[{opts,Options[Fit]}],fit,tfs,terms,const},
    tfs = Select[fs,Not[FreeQ[#,vpt]]&];
    fit = Fit[data,funs,vars];
    If[Not[SameQ[CoefficientTable /. op,True]],fit,
       terms = Select[Apply[List,fit],Not[FreeQ[#,vpt]]&];
       const = Select[Apply[List,fit],FreeQ[#,vpt]&];
       Join[tfs /. (terms /. Times[c_Real t___] :> 
                               (Times[1,t] -> {Times[t],c})),
            If[EmptyQ[const],{},{Apply[Plus,const]}]]]]

Protect[Fit];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Counting[exp,{f1,f2,...}]\n",
    FontWeight->"Bold"],
  "Coppia {count,val} dove count e' la lista {f1 -> n1,f2 -> n2,...} con \
n1,n2,... numeri di applicazioni delle funzioni f1,f2,... durante la \
valutazione dell'espressione exp, e val e' il risultato di tale valutazione.\n\
",
  StyleBox["CountFunction -> fc  CountFunction -> {fc1,fc2,...}\n",
    FontWeight->"Bold"],
  "Opzione di Counting che regola la determinazione dei numeri n1,n2,... come \
somme dei contributi di ciascuna applicazione delle funzioni f1,f2,..., \
calcolati mediante la funziona fc o le diverse funzion fc1,fc2,...",
  StyleBox["\nCountList ->  False|True\n",
    FontWeight->"Bold"],
  "Opzione di Counting che regola se n1,n2,... devono essere sostituiti con \
liste {n11,n12,...},{n21,n22,...},...., nelle quali per ogni occorrenza delle \
f1,f2,... e' riportato il relativo contributo."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Counting]
SetAttributes[Counting,HoldAll];
Options[Counting] = {CountFunction -> (1&),CountList ->  False};

Counting[exp_,s:_Symbol|{___Symbol},opts___?OptionQ] :=
  Module[{l,n,p,f,t,x,y,r,h = Unique[],
          op = Flatten[{opts,Options[Counting]}]},  
    l = Flatten[{s},1]; n = Length[l];
    p = Apply[Alternatives,Append[Map[Blank[#]&,l],h]];
    t = Flatten[Trace[h[exp],Evaluate[p]]];
    f = CountFunction /. op;
    f = PadRight[{},n,If[MatchQ[f,_List],f,Hold[f]]];
    r = With[{h = h},Block[{h = (#&)},Last[t][[1]]]]; 
    t = Cases[t,_?(FreeQ[#,h]&)];
    t = Table[Cases[t,x_?(With[{h = l[[i]]},
                            MatchQ[#,HoldForm[h[y___]] /; 
                                       Not[ValueQ[{y}]]]]&) :>
                      f[[i]][(x /. l[[i]] -> List)[[1]]]],{i,n}];
    If[SameQ[CountList /. op,True],{MapThread[Rule,{l,t}],r},
       {MapThread[Rule,{l,Apply[Plus,t,1]}],r}]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Showing[exp,{f1,f2,...}]\n",
    FontWeight->"Bold"],
  "Valutazione dell'espressione exp con la visualizzazione di tutti\ni \
risultati delle applicazioni delle funzioni f1,f2,... durante la valutazione. \
\n",
  StyleBox["ShowFunction -> show  ShowFunction -> {show1,show2,...}\n",
    FontWeight->"Bold"],
  "Opzione di Showing che regola la funzione di visualizzazione.",
  StyleBox["\nShowOptions -> shopts\n",
    FontWeight->"Bold"],
  "Opzione di Showing che regola le opzioni di visualizzazione."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Showing]
SetAttributes[Showing,HoldAll]; 
Options[Showing] = {ShowFunction -> (Show[Graphics[#1]]&),
                    ShowOptions -> {}};
 
Showing[exp_,s:_Symbol|{___Symbol},opts___?OptionQ] := 
  Module[{l,n,p,f,t,x,w,h = Unique[],id = #&,r,shop, 
          op = Flatten[{opts,Options[Showing]}]},
    shop = Flatten[{ShowOptions /. op}];
    l = Flatten[{s},1]; n = Length[l];
    l = Append[Map[With[{h = #},
          HoldPattern[h[x___]] /; Not[ValueQ[{x}]]]&,Append[l,h]],h];
    p = Apply[Alternatives,l]; 
    f = (ShowFunction /. op) /. 
              Graphics[g_,o___] :> Graphics[g,shop,o]; 
    f = Join[PadRight[{},n,If[MatchQ[f,_List],f,Hold[f]]],{id,id}];
    w = Apply[Sequence,Flatten[Thread[{Map[Hold,l],f}],1]];
    f = With[{w = w},Switch[#1,w]&];
    t = Flatten[Trace[h[exp],Evaluate[x:p :> f[Hold[x]][x]]]];
    r = With[{h = h},Block[{h = #&},Last[t][[1]]]]; 
    t = Cases[t,_?(FreeQ[#,h]&)];{t,r}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PolygonMode -> Gray|Line|FilledLine\n",
    FontWeight->"Bold"],
  "Opzione per Show che regola il modo di visualizzazione delle primitive \
Polygon in Graphics: Gray = riempimento grigio; Line = poligonale di bordo; \
FilledLine = riempimento grigio e poligonale di bordo."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
Unprotect[Show]; ClearAll[PolygonMode]

Show[g___,opts___?OptionQ] /; Not[FreeQ[{opts},PolygonMode]]:=
  Module[{gr,op = Flatten[{opts}],grop},
    Switch[PolygonMode /. op,
           Gray,gr = g /. Polygon[l_] :> 
                            {GrayLevel[.5],Polygon[l]},
           Line,gr = g /. Polygon[l_] :> 
                            Line[Append[l,First[l]]],
           FilledLine,gr = g /. Polygon[l_] :> 
                                  {{GrayLevel[.5],Polygon[l]},
                                   Line[Append[l,First[l]]]}];
    Show[gr,grop = Select[op,FreeQ[#,PolygonMode]&]]; 
    Block[{$DisplayFunction = Identity},Show[g,grop]]]

Protect[Show];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Modifica opzioni di Graphics",
  FontWeight->"Bold"]], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
SetOptions[Graphics,AspectRatio -> Automatic];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[StyleBox["Simboli riservati",
  FontWeight->"Bold"]], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
Unprotect[V,X,Y,XY,CCW,CW];
ClearAll[V,X,Y,XY,CCW,CW]
Protect[V,X,Y,XY,CCW,CW];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Caricamento dei moduli",
    FontWeight->"Bold"],
  "\nI comandi che seguono caricano i vari moduli. \nE' necessario modificare \
l'argomento di SetDirectory indicando la directory nella quale si trova \
questo stesso file e i file relativi ai moduli da caricare."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
SetDirectory[\"C:\\GeomComp\"];

Get[\"Alberi.m\"]
Get[\"Strutture.m\"]
Get[\"Poligoni.m\"]
Get[\"Poligonazioni.m\"]
Get[\"Partizioni.m\"]
Get[\"Ottimizzazione.m\"]
Get[\"Reticoli.m\"]
Get[\"Automi.m\"]\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageFooters->{{Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], " / ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}, {Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], " / ", 
          CounterBox[ "Page"]}], "Footer"], Inherited}},
PageFooterLines->{True, True},
PrintingOptions->{"PrintingMargins"->{{28, 28}, {56, 56}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->True,
"PrintMultipleHorizontalPages"->True},
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@0000000000000006D801T1T00000008000
00000000007ooaWE]c3oo`02Wl400000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 39, 0, 36, "Subsubtitle"],
Cell[1759, 51, 349, 9, 47, "Subsubtitle"],
Cell[2111, 62, 77, 4, 32, "Input",
  InitializationCell->True],
Cell[2191, 68, 193, 4, 35, "Text"],
Cell[2387, 74, 162, 10, 110, "Input",
  InitializationCell->True],
Cell[2552, 86, 393, 10, 80, "Text"],
Cell[2948, 98, 321, 11, 123, "Input",
  InitializationCell->True],
Cell[3272, 111, 797, 16, 170, "Text"],
Cell[4072, 129, 798, 24, 292, "Input",
  InitializationCell->True],
Cell[4873, 155, 754, 16, 155, "Text"],
Cell[5630, 173, 1204, 40, 500, "Input",
  InitializationCell->True],
Cell[6837, 215, 592, 13, 110, "Text"],
Cell[7432, 230, 692, 23, 279, "Input",
  InitializationCell->True],
Cell[8127, 255, 336, 8, 65, "Text"],
Cell[8466, 265, 725, 19, 227, "Input",
  InitializationCell->True],
Cell[9194, 286, 1026, 20, 230, "Text"],
Cell[10223, 308, 975, 23, 279, "Input",
  InitializationCell->True],
Cell[11201, 333, 658, 15, 140, "Text"],
Cell[11862, 350, 990, 24, 292, "Input",
  InitializationCell->True],
Cell[12855, 376, 427, 9, 80, "Text"],
Cell[13285, 387, 721, 19, 227, "Input",
  InitializationCell->True],
Cell[14009, 408, 199, 4, 35, "Text"],
Cell[14211, 414, 100, 4, 32, "Input",
  InitializationCell->True],
Cell[14314, 420, 188, 4, 35, "Text"],
Cell[14505, 426, 133, 6, 58, "Input",
  InitializationCell->True],
Cell[14641, 434, 417, 9, 95, "Text"],
Cell[15061, 445, 255, 12, 136, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

