(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15968,        466]*)
(*NotebookOutlinePosition[     41791,       1410]*)
(*  CellTagsIndexPosition[     41747,       1406]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Partizioni", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Voronoi[pts]\n",
    FontWeight->"Bold"],
  "Decomposizione di Voronoi della lista di punti pts.\n",
  StyleBox["CircCenter[{{x1,y1},{x2,y2},{x3,y3}},{x,y}]\n",
    FontWeight->"Bold"],
  "Circocentro del triangolo di vertici {x1,y1},{x2,y2},{x3,y3}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Voronoi,CircCenter]

Voronoi[pts_List] := 
  Module[{x1 = Min[Thread[pts][[1]]],x2 = Max[Thread[pts][[1]]], 
          y1 = Min[Thread[pts][[2]]],y2 = Max[Thread[pts][[2]]], 
          tri = Triangulation[pts,Method -> Delaunay,Mode -> DCEList], 
          x0,y0,lx,ly,l,f0,vlist,elist,flist,coord,vor,n,
          f,ft,e,t,nt,fe,ce,ne,pe,ve,p1,p2,newe,newv},
    x0 = (x1 + x2)/2; y0 = (y1 + y2)/2; 
    lx = x2 - x1; x1 = x0 - 0.6 lx; x2 = x0 + 0.6 lx;
    ly = y2 - y1; y1 = y0 - 0.6 ly; y2 = y0 + 0.6 ly;
    l = lx + ly; 
    f0 = UnboundedFace[tri];
    vlist = ReplacePart[Map[TwinEdge,FaceList[tri],{2}],Null,f0];
    coord = vlist /. {e_Integer} :> 
      (f = EdgeFace[tri,TwinEdge[e]];
       CircCenter[VertexCoord[tri,FaceOuterVertices[tri,f]]]);
    flist = ReplacePart[VertexList[tri],Null,
                        Thread[{FaceInnerVertices[tri,f0][[1]]}]];
    AppendTo[flist,{0,0}];
    elist = EdgeList[tri]; 
    newe = Length[elist] + 1; newv = Length[vlist] + 1;
    elist = elist /. {f_,_,p_,n_,v_} :> 
        (e = PrevEdge[tri,n]; t = TwinEdge[e];
         ft = EdgeFace[tri,t]; nt = NextEdge[tri,t];
         fe = If[NullQ[flist[[v]]],flist[[-1,2]] = e;Length[flist],v];
         ce = If[NullQ[flist[[v]]],2,1];
         pe = If[ft != f0,nt,t];
         ne = If[f != f0,TwinEdge[p],t];
         ve = If[ft != f0,ft,
                 AppendTo[vlist,{e}]; 
                 AppendTo[coord,
                          p1 = VertexCoord[tri,v]; 
                          p2 = VertexCoord[tri,EdgeEnd[tri,e]]; 
                          (p1 + p2)/2 + l Cross[p2 - p1]/
                            Sqrt[(p2 - p1).(p2 - p1)]];newv++];
         {fe,ce,pe,ne,ve});
    BoxClip[DCEList[flist,elist,vlist,coord],{{x1,x2},{y1,y2}}]]
    
CircCenter[{{x1_,y1_},{x2_,y2_},{x3_,y3_}}] := 
  {-Det[{{1,1,1},{y1,y2,y3},{x1^2 + y1^2,x2^2 + y2^2,x3^2 + y3^2}}], 
   +Det[{{1,1,1},{x1,x2,x3},{x1^2 + y1^2,x2^2 + y2^2,x3^2 + y3^2}}]}/
   (2 Det[{{1,x1,y1},{1,x2,y2},{1,x3,y3}}])
\
\>", "Input",
  InitializationCell->True],

Cell["Binary Space Partition", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero BSP (Binary Space Partition) e' un albero binario con \
chiavi del tipo {{a,b},c}, che rappresenta una partizione binaria del piano, \
in base alle condizioni: a x + b y < c (primo ramo), a x + b y > c (secondo \
ramo) e a x + b y == c (contenuto del nodo).\
\>", "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["BSPTreeToDCEList[bsp,{{x1,x2},{y1,y2}}]\n",
    FontWeight->"Bold"],
  "Struttura DCEList corrispondente all'albero bsp con rettangolo di clipping \
[x1,x2] x [y1,y2].\n",
  StyleBox["SplitFace[dce,f,{{a,b},c}]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta suddividendo la faccia f lungo la retta di \
equazione a x + b y == c."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[BSPTree,BSPTreeToDCEList,SplitFace]

BSPTreeToDCEList[t_Tree,{{x1_,x2_},{y1_,y2_}}] :=  
  Module[{dce,split},
    split[bsp_,f_] :=
      If[Not[LeafQ[bsp]],
         dce = SplitFace[dce,f,GetKey[bsp]];
         split[GetBranch[bsp,2],Length[FaceList[dce]]];
         split[GetBranch[bsp,1],f]];
    dce = RegionToDCEList[Polygon[{{x1,y1},{x2,y1},{x2,y2},{x1,y2}}]];
    split[t,1]; dce] 
    
SplitFace[dce_DCEList,f_,{v:{_,_},c_}] :=
  Module[{loop = FaceOuterBoundary[dce,f],
          dce1 = dce,val,pos1,pos2,t,v1,v2,p1,p2},
    val = Map[Chop[v . VertexCoord[dce,EdgeOrigin[dce,#]] - c]&,loop];
    AppendTo[val,First[val]]; AppendTo[loop,First[loop]];
    Switch[val = Append[val,First[val]],
      {_?NonPositive ..}|{_?NonNegative ..},dce,
      _,pos1 = FirstRelPosition[val,And[#1 < 0,#2 >= 0]&];
        pos2 = FirstRelPosition[val,And[#1 > 0,#2 <= 0]&];
      v1 = VertexCoord[dce,EdgeOrigin[dce,loop[[pos1]]]];
      v2 = VertexCoord[dce,EdgeOrigin[dce,loop[[pos1 + 1]]]];
      t = val[[pos1]] / (val[[pos1 + 1]] - val[[pos1]]);
      p1 = (1 + t) v1 - t v2;
      v1 = VertexCoord[dce,EdgeOrigin[dce,loop[[pos2]]]];
      v2 = VertexCoord[dce,EdgeOrigin[dce,loop[[pos2 + 1]]]];
      t = val[[pos2]] / (val[[pos2 + 1]] - val[[pos2]]);
      p2 = (1 + t) v1 - t v2;
      If[val[[pos1 + 1]] != 0,dce1 = SplitEdge[dce1,loop[[pos1]],p1]];
      If[val[[pos2 + 1]] != 0,dce1 = SplitEdge[dce1,loop[[pos2]],p2]];
      InsertEdge[dce1,loop[[pos1]],NextEdge[dce1,loop[[pos1]]],
                      loop[[pos2]],NextEdge[dce1,loop[[pos2]]]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["PainterList[bsp,view]\n",
    FontWeight->"Bold"],
  "Lista dei dati dell'albero bsp ordinati in base all'algoritmo del pittore \
con punto di vista view."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[PainterList]

PainterList[bsp_Tree,p:{_,_}] := 
  If[LeafQ[bsp],GetData[bsp],
     If[GetKey[bsp][[1]] . p - GetKey[bsp][[2]] >= 0,
        Join[PainterList[GetBranch[bsp,1],p],
             GetData[bsp],PainterList[GetBranch[bsp,2],p]],
        Join[PainterList[GetBranch[bsp,2],p],GetData[bsp],
             PainterList[GetBranch[bsp,1],p]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["\<\
Un albero di ricerca 2D e' un albero binario con chiavi reali c, \
che rappresenta una partizione binaria del piano, in base alle condizioni: x \
< c (primo ramo), x > c (secondo ramo) e x == c (contenuto del nodo) per i \
nodi di livello dispari, e y < c (primo ramo), y > c (secondo ramo) e y == c \
(contenuto del nodo) per i nodi di livello pari.\
\>", "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["OrdTree2DToBSPTree[t2D]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Albero BSP corrispondente all'albero di ricerca t2d",
  ".\n",
  StyleBox["OrdTree2DToDCEList[t2D,{{x1,x2},{y1,y2}}]",
    FontWeight->"Bold"],
  "\nStruttura DCEList corrispondente all'albero di ricerca t2d con \
rettangolo di clipping [x1,x2] x [y1,y2]."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTree2DToBSPTree,OrdTree2DToDCEList]

OrdTree2DToBSPTree[t2d_Tree] :=  
  Module[{tobsp},
    tobsp[t_,l_] :=
      If[LeafQ[t],t,
         Tree[{{If[OddQ[l],{1,0},{0,1}],GetKey[t]},GetData[t]},
              tobsp[GetBranch[t,1],l + 1],tobsp[GetBranch[t,2],l + 1]]];
    tobsp[t2d,1]] 

OrdTree2DToDCEList[t2d_Tree,{{x1_,x2_},{y1_,y2_}}] :=  
  BSPTreeToDCEList[OrdTree2DToBSPTree[t2d],{{x1,x2},{y1,y2}}]
    \
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTree2D[pts]\n",
    FontWeight->"Bold"],
  "Albero di ricerca 2D costruito a partire dalla lista di punti pts, in modo \
che ciascun nodo terminale contenga un solo punto."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTree2D]

OrdTree2D[pts_List] := 
  Module[{tree},
    tree[p_,l_] :=
      If[Length[p] < 2,Tree[{Null,p}],
         Module[{s,m,c,t1,t2,odd = OddQ[l]},
           s = Sort[p,If[odd,OrderedQ[{#1,#2}]&,
                         OrderedQ[{Reverse[#1],Reverse[#2]}]&]];
           m = Floor[Length[s] / 2];
           c = (s[[m]] + s[[m + 1]]) / 2;
           t1 = tree[Take[s,m],l + 1];
           t2 = tree[Drop[s,m],l + 1];
           Tree[{If[odd,c[[1]],c[[2]]],{}},t1,t2]]];
       tree[pts,1]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["OrdTree2DSearch[t2d,{{x1,x2},{y1,y2}}]\n",
    FontWeight->"Bold"],
  "Lista dei dati dell'albero t2d contenuti nel rettangolo [x1,x2] x \
[y1,y2]."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[OrdTree2DSearch]

OrdTree2DSearch[t2d_Tree,{{x1_,x2_},{y1_,y2_}}] := Null
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell["Quad Partition", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["\<\
Un albero QuadTree e' un albero in cui tutti i nodi non terminali \
hanno ordine 4. Ogni nodo rappresenta un quadrato (rettangolo) e i rami che \
escono dal nodo rappresentano i quadrati (rettangoli) che si ottengono \
suddividendo a meta' i lati.\
\>", "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["QuadTreeContent[qt]\n",
    FontWeight->"Bold"],
  "Contenuto dell'albero QuadTree qt.\n",
  StyleBox["QuadTreeRange[qt]\n",
    FontWeight->"Bold"],
  "Range dell'albero QuadTree qt."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell[TextData[{
  StyleBox["ClearAll[QuadTreeContent,QuadTreeRange]\n\n\
QuadTreeContent[qt_Tree] := GetBranch[qt,1]\n\n",
    FontFamily->"Courier"],
  StyleBox["QuadTreeRange",
    FontFamily->"Courier"],
  StyleBox["[qt_Tree] := GetNode[qt]\n",
    FontFamily->"Courier"]
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["QuadTreeToDCEList[qt]",
    FontWeight->"Bold"],
  "\nStruttura DCEList corrispondente all'albero QuadTree qt."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[QuadTreeToDCEList]

QuadTreeToDCEList[qt_Tree] :=  
  Module[{dce,split,x1,x2,y1,y2,xm,ym},
    split[t_,f_,{{x1_,x2_},{y1_,y2_}}] :=
      If[Not[LeafQ[t]],
         Module[{xm = (x1 + x2)/2,ym = (y1 + y2)/2,f1,f2,f3},
           dce = SplitFace[dce,f,{{1,0},xm}];
           dce = SplitFace[dce,Length[FaceList[dce]],{{0,1},ym}];
           dce = SplitFace[dce,f,{{0,1},ym}];
           f1 = Length[FaceList[dce]] - 2; f2 = f1 + 2; f3 = f1 + 1;
           split[GetBranch[t,1],f,{{x1,xm},{y1,ym}}];
           split[GetBranch[t,2],f1,{{xm,x2},{y1,ym}}];
           split[GetBranch[t,3],f2,{{x1,xm},{ym,y2}}];
           split[GetBranch[t,4],f3,{{xm,x2},{ym,y2}}]]];
    {{x1,x2},{y1,y2}} = QuadTreeRange[qt];
    dce = RegionToDCEList[Polygon[{{x1,y1},{x2,y1},{x2,y2},{x1,y2}}]];
    split[QuadTreeContent[qt],1,{{x1,x2},{y1,y2}}]; dce] 
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}],

Cell[TextData[{
  StyleBox["QuadTree",
    FontWeight->"Bold"],
  StyleBox["[pts,{{x1,x2},{y1,y2}}]\n",
    FontWeight->"Bold"],
  "Albero QuadTree con range {{x1,x2},{y1,y2}}, costruito a partire dalla \
lista di punti pts, in modo che ciascun nodo terminale contenga al piu' un \
punto."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{448, Inherited}],

Cell["\<\
ClearAll[QuadTree]

QuadTree[pts_List,rg:{{_,_},{_,_}}] := 
  Module[{tree},
    tree[p_,{{x1_,x2_},{y1_,y2_}}] :=
      If[Length[p] < 2,Tree[{Null,p}],
         Module[{xm = (x1 + x2)/2,ym = (y1 + y2)/2,
                 p1 = {},p2 = {},p3 = {},p4 = {}},
           Scan[Switch[{#[[1]] < xm,#[[2]] < ym},
                  {True,True},AppendTo[p1,#],
                  {False,True},AppendTo[p2,#],
                  {True,False},AppendTo[p3,#],
                  {False,False},AppendTo[p4,#]]&,p];
           Tree[Null,tree[p1,{{x1,xm},{y1,ym}}],
                     tree[p2,{{xm,x2},{y1,ym}}],
                     tree[p3,{{x1,xm},{ym,y2}}],
                     tree[p4,{{xm,x2},{ym,y2}}]]]];
    Tree[rg,tree[pts,rg]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{469, Inherited}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 357, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2077, 63, 404, 10, 80, "Text"],
Cell[2484, 75, 2044, 46, 578, "Input",
  InitializationCell->True],
Cell[4531, 123, 369, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[4903, 137, 549, 13, 92, "Subsubtitle"],
Cell[5455, 152, 494, 12, 110, "Text"],
Cell[5952, 166, 1729, 39, 448, "Input",
  InitializationCell->True],
Cell[7684, 207, 308, 8, 65, "Text"],
Cell[7995, 217, 520, 15, 136, "Input",
  InitializationCell->True],
Cell[8518, 234, 632, 14, 107, "Subsubtitle"],
Cell[9153, 250, 505, 14, 95, "Text"],
Cell[9661, 266, 587, 18, 175, "Input",
  InitializationCell->True],
Cell[10251, 286, 328, 8, 65, "Text"],
Cell[10582, 296, 675, 21, 214, "Input",
  InitializationCell->True],
Cell[11260, 319, 301, 8, 65, "Text"],
Cell[11564, 329, 249, 9, 58, "Input",
  InitializationCell->True],
Cell[11816, 340, 361, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[12180, 354, 529, 13, 92, "Subsubtitle"],
Cell[12712, 369, 337, 10, 80, "Text"],
Cell[13052, 381, 315, 9, 84, "Input",
  InitializationCell->True],
Cell[13370, 392, 264, 7, 50, "Text"],
Cell[13637, 401, 1015, 24, 253, "Input",
  InitializationCell->True],
Cell[14655, 427, 414, 11, 80, "Text"],
Cell[15072, 440, 892, 24, 266, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

