(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     31245,        742]*)
(*NotebookOutlinePosition[     57068,       1686]*)
(*  CellTagsIndexPosition[     57024,       1682]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Poligonazioni", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["InsideTriangleQ[{{x1,y1},{x2,y2},{x3,y3}},{x,y}]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se il punto {x,y} sta all'interno del \
triangolo di vertici {x1,y1},{x2,y2},{x3,y3}.",
  StyleBox["\nInsideCircleQ[{{x1,y1},{x2,y2},{x3,y3}},{x,y}]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se il punto {x,y} sta all'interno del \
circum-cerchio al triangolo di vertici {x1,y1},{x2,y2},{x3,y3}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[InsideTriangleQ,InsideCircleQ]

InsideTriangleQ[{{x1_,y1_},{x2_,y2_},{x3_,y3_}},{x_,y_}] :=
  SameQ[1,TriangleClass[{{x1,y1},{x2,y2},{x,y}}],
          TriangleClass[{{x1,y1},{x,y},{x3,y3}}],
          TriangleClass[{{x,y},{x2,y2},{x3,y3}}]]

InsideCircleQ[{{x1_,y1_},{x2_,y2_},{x3_,y3_}},{x_,y_}] :=
  SameQ[Sign[Chop[Det[{{1,x1,y1,x1^2 + y1^2},{1,x2,y2,x2^2 + y2^2},
                       {1,x3,y3,x3^2 + y3^2},{1,x,y,x^2 + y^2}}]]],-1]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["Triangulation[pts]\n",
    FontWeight->"Bold"],
  "Triangolazione della lista di punti pts.",
  StyleBox["\nMethod -> Sweep|Delaunay\n",
    FontWeight->"Bold"],
  "Opzione di Triangulation che indica l'algoritmo da utilizzare.\n",
  StyleBox["Indexed -> True|False",
    FontWeight->"Bold"],
  "\nOpzione di Triangulation che indica se la lista risultante e' espressa \
mediante gli indici dei vertici nella lista pts.\n",
  StyleBox["Mode -> EdgeList|TriangleList|DCEList\n",
    FontWeight->"Bold"],
  "Opzione di Triangulation che indica se la triangolazione e' espressa come \
lista di spigoli, lista di triangoli o struttura DCE."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[Triangulation,TriangleList,Sweep,Delaunay]\n\
Options[Triangulation] = \n  {Method -> Delaunay,Indexed -> False,Mode -> \
DCEList};\n\nTriangulation[pts_List,opts___?OptionQ] :=\n  Module[{op = \
Flatten[{opts,Options[Triangulation]}],ind,tr,l,i = 1},\n    Switch[Method /. \
op,\n      Sweep,\n        ind = \
Sort[Range[Length[pts]],OrderedQ[pts[[{#1,#2}]]]&];\n        tr = \
SweepTR[ind,N[pts]],\n      Delaunay,\n        ind = \
RandomPermutation[Length[pts]];\n        tr = DelaunayTR[ind,N[pts]]];\n    \
Switch[Mode /. op,\n      EdgeList,\n        l = \
Map[{EdgeOrigin[tr,#],EdgeEnd[tr,#]}&,\n                \
Flatten[Partition[Edges[tr],1,2]]];\n        l = l /. \
Dispatch[Map[Rule[i++,#]&,ind]];\n        If[Indexed /. op,l,l /. i_Integer \
:> pts[[i]]],\n      TriangleList,\n        l = \
Map[FaceOuterVertices[tr,#]&,BoundedFaces[tr]];\n        l = l /. \
Dispatch[Map[Rule[i++,#]&,ind]];\n        If[Indexed /. op,l,l /. i_Integer \
:> pts[[i]]],\n      DCEList,tr]]\n\nClearAll[SweepTR,DelaunayTR]\n\n\
SweepTR[pts_,coord_] := \n  Module[{tr = DCEList[],i = \
2,v1,v2,e1,e2,e3,f,p1,p2,l},\n    If[Length[pts] < 2,tr,\n       tr = \
InsertEdge[tr,1,coord[[pts[[1]]]],coord[[pts[[2]]]]];\n       While[i++ < \
Length[pts],\n         v1 = Length[VertexList[tr]];\n         f = \
UnboundedFace[tr];\n         e2 = Select[VertexEdgeList[tr,v1],\n             \
        SameQ[EdgeFace[tr,#],f]&,1][[1]];\n         e1 = PrevEdge[tr,e2];\n   \
      l = EdgeLoop[tr,e2];\n         tr = \
InsertEdge[tr,e1,e2,coord[[pts[[i]]]]];\n         v2 = v1 + 1;\n         e3 = \
PrevEdge[tr,e2];\n         p1 = LastPosition[l,\n                \
_?((PointLineClass[VertexCoord[tr,v2],\n                    \
{VertexCoord[tr,EdgeOrigin[tr,#]],\n                     \
VertexCoord[tr,EdgeEnd[tr,#]]}] < 1)&)];\n         p2 = FirstPosition[l,\n    \
            _?((PointLineClass[VertexCoord[tr,v2],\n                    \
{VertexCoord[tr,EdgeOrigin[tr,#]],\n                     \
VertexCoord[tr,EdgeEnd[tr,#]]}] < 1)&)];\n         e1 = NextEdge[tr,e1];\n    \
     Do[e2 = Length[EdgeList[tr]];\n            tr = \
InsertEdge[tr,l[[j]],l[[j + 1]],e1,e2], \n            {j,p1,Length[l] - 1}];\n\
         e1 = PrevEdge[tr,e3];\n         Do[e2 = NextEdge[tr,e1];\n           \
 tr = InsertEdge[tr,l[[j-1]],l[[j]],e1,e2],\n            {j,2,p2}]]; tr]]\n\n\
DelaunayTR[pts_,coord_] := \n  Module[{m = \
Max[Abs[coord]],tr,lkf,lke,lkp,split,swap,delq,mkdel,\n          \
e,x,v,n,i,j,l,e0,e1,e2,e3,e4,e5,e6,e7,t1,f,f1,f2,f3,f4,\n          \
v1,v2,v3,v4,p0,p1,p2,p3,p4,vi,ci},\n    tr = RegionToDCEList[Polygon[{{- 4 \
m,- 4 m},{4 m,0},{0,4 m}}]];\n    lkf = {pts,{}}; lke = {{},{},{}}; \n    lkp \
= Table[{1,Null},{Length[pts]}];\n    split[{Null,e_},x_] := \n      (e0 = 2 \
e; e1 = NextEdge[tr,e0]; e2 = NextEdge[tr,e1];\n       e3 = \
NextEdge[tr,TwinEdge[e0]]; e4 = NextEdge[tr,e3];\n       tr = \
SplitEdge[tr,e0,x]; e5 = NextEdge[tr,e4]; \n       e6 = NextEdge[tr,e5]; e7 = \
NextEdge[tr,e0]; \n       p0 = VertexCoord[tr,EdgeOrigin[tr,e7]]; \n       p1 \
= VertexCoord[tr,EdgeOrigin[tr,e1]]; \n       p2 = \
VertexCoord[tr,EdgeOrigin[tr,e2]]; \n       p4 = \
VertexCoord[tr,EdgeOrigin[tr,e4]];\n       tr = InsertEdge[tr,e0,e7,e1,e2];\n \
      tr = InsertEdge[tr,e3,e4,e5,e6]; \n       f1 = EdgeFace[tr,e1]; f2 = \
EdgeFace[tr,e2];\n       f3 = EdgeFace[tr,e3]; f4 = EdgeFace[tr,e4];\n       \
n = Length[lke]; lke = Join[lke,{{},{},{}}]; \n       v = lke[[e]]; lke[[e]] \
= {}; lkf = Join[lkf,{{},{}}];\n       i = 0; While[i++ < Length[v],\n        \
        If[PointLineClass[coord[[vi = v[[i]]]],{p0,p1}] == 0,\n               \
    lkp[[vi]] = {Null,n + 1}; AppendTo[lke[[-3]],vi],\n                   \
lkp[[vi]] = {Null,e}; AppendTo[lke[[e]],vi]]];                          \n    \
   v = Apply[Join,lkf[[{f1,f2}]]]; lkf[[{f1,f2}]] = {};     \n       i = 0; \
While[i++ < Length[v],\n                Switch[PointLineClass[coord[[vi = \
v[[i]]]],{p0,p2}],\n                  1,lkp[[vi]] = {f2,Null}; \
AppendTo[lkf[[f2]],vi],\n                  0,lkp[[vi]] = {Null,n + 2}; \
AppendTo[lke[[-2]],vi],\n                  _,lkp[[vi]] = {f1,Null}; \
AppendTo[lkf[[f1]],vi]]];          \n       v = Apply[Join,lkf[[{f3,f4}]]]; \
lkf[[{f3,f4}]] = {};     \n       i = 0; While[i++ < Length[v],\n             \
   Switch[PointLineClass[coord[[vi = v[[i]]]],{p0,p4}],\n                  \
1,lkp[[vi]] = {f4,Null}; AppendTo[lkf[[f4]],vi],\n                  \
0,lkp[[vi]] = {Null,n + 3}; AppendTo[lke[[-1]],vi],\n                  \
_,lkp[[vi]] = {f3,Null}; AppendTo[lkf[[f3]],vi]]];\n       mkdel[e1]; \
mkdel[e2]; mkdel[e3]; mkdel[e4]);\n    split[{f_,Null},x_] := \n      (e1 = \
FaceOuterEdge[tr,f]; \n       e2 = NextEdge[tr,e1]; e3 = NextEdge[tr,e2];\n   \
    tr = InsertEdge[tr,e1,e2,x];\n       e4 = NextEdge[tr,e1]; e5 = \
NextEdge[tr,e4];\n       tr = InsertEdge[tr,e2,e3,e4,e5]; e6 = \
NextEdge[tr,e4];\n       tr = InsertEdge[tr,e3,e1,e4,e6]; \n       f1 = \
EdgeFace[tr,e1]; f2 = EdgeFace[tr,e2]; f3 = EdgeFace[tr,e3];\n       n = \
Length[lke]; lke = Join[lke,{{},{},{}}];\n       lkf = Join[lkf,{{},{}}];\n   \
    v = Apply[Join,lkf[[{f1,f2,f3}]]]; lkf[[{f1,f2,f3}]] = {};\n       p0 = \
VertexCoord[tr,EdgeOrigin[tr,e6]]; \n       p1 = \
VertexCoord[tr,EdgeOrigin[tr,e1]]; \n       p2 = \
VertexCoord[tr,EdgeOrigin[tr,e2]]; \n       p3 = \
VertexCoord[tr,EdgeOrigin[tr,e3]];\n       i = 0; While[i++ < Length[v], \n   \
             ci = coord[[vi = v[[i]]]];\n                \
Switch[{PointLineClass[ci,{p0,p1}],\n                        \
PointLineClass[ci,{p0,p2}],\n                        \
PointLineClass[ci,{p0,p3}]},\n                  {1,-1,_},lkp[[vi]] = \
{f1,Null}; \n                           AppendTo[lkf[[f1]],vi],\n             \
     {_,1,-1},lkp[[vi]] = {f2,Null}; \n                           \
AppendTo[lkf[[f2]],vi],\n                  {-1,_,1},lkp[[vi]] = {f3,Null}; \n \
                          AppendTo[lkf[[f3]],vi],\n                  \
{0,_,_},lkp[[vi]] = {Null,n + 3};\n                          \
AppendTo[lke[[-1]],vi],\n                  {_,0,_},lkp[[vi]] = {Null,n + 1};\n\
                          AppendTo[lke[[-3]],vi],\n                  \
{_,_,0},lkp[[vi]] = {Null,n + 2}; \n                          \
AppendTo[lke[[-2]],vi]]];\n       mkdel[e1]; mkdel[e2]; mkdel[e3]);\n    \
delq[e1_] :=",
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  "      Switch[Sign[{v1 = EdgeOrigin[tr,e1],\n                   v2 = \
EdgeOrigin[tr,t1 = TwinEdge[e1]],\n                   v3 = \
EdgeOrigin[tr,PrevEdge[tr,e1]],\n                   v4 = \
EdgeOrigin[tr,PrevEdge[tr,t1]]} - 3],\n        \
{1,1,1,1},DelaunayEdgeQ[tr,e1],\n        \
{_,1,1,1},PolygonClass[VertexCoord[tr,{v2,v3,v4}]] <= 0,\n        \
{1,_,1,1},PolygonClass[VertexCoord[tr,{v1,v3,v4}]] >= 0,\n        \
{1,1,_,1}|{1,1,1,_}|{-1|0,-1|0,_,_},True,\n        \
{_,_,_,_},DelaunayEdgeQ[tr,e1] || Min[v1,v2] < Min[v3,v4]];\n    mkdel[e1_] \
:= \n      If[Not[delq[e1]], t1 = TwinEdge[e1];\n         Module[{e2 = \
NextEdge[tr,t1],e3 = PrevEdge[tr,t1]},\n           swap[e1]; mkdel[e2]; \
mkdel[e3]]];\n    swap[e1_] :=\n      (Module[{e,e2,e3,e4},\n       e = \
Quotient[e1 + 1,2]; e2 = TwinEdge[e1];\n       f1 = EdgeFace[tr,e1]; f2 = \
EdgeFace[tr,e2];\n       e3 = PrevEdge[tr,e1]; e4 = PrevEdge[tr,e2];  \n      \
 tr = SwapEdge[tr,e1];\n       f3 = EdgeFace[tr,e3]; f4 = EdgeFace[tr,e4];\n  \
     p1 = VertexCoord[tr,EdgeOrigin[tr,e3]];\n       p2 = \
VertexCoord[tr,EdgeOrigin[tr,e4]];\n       v = \
Union[lkf[[f1]],lkf[[f2]],lke[[e]]];\n       lkf[[{f1,f2}]] = {}; \
AppendTo[lkf,{}]; \n       n = Length[lke]; lke[[e]] = {}; AppendTo[lke,{}];\n\
       i = 0; While[i++ < Length[v],\n               \
Switch[PointLineClass[coord[[vi = v[[i]]]],{p1,p2}],\n                 \
1,lkp[[vi]] = {f4,Null}; AppendTo[lkf[[f4]],vi],\n                 \
0,lkp[[vi]] = {Null,n + 1}; AppendTo[lke[[-1]],vi],        \n                 \
_,lkp[[vi]] = {f3,Null}; AppendTo[lkf[[f3]],vi]]]]);           \n    j = 0; \
While[j++ < Length[pts],\n             \
split[lkp[[pts[[j]]]],coord[[pts[[j]]]]]];\n    l = \
Apply[Union,Table[VertexEdgeList[tr,i],{i,1,3}]];\n    tr = \
Fold[DeleteEdge,tr,Complement[l,{1,3,5}]]; tr]\n "
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SwapEdge[tri,e]",
    FontWeight->"Bold"],
  "\nTriangolazione ottenuta effettuando lo swap dello spigolo e."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[SwapEdge]

SwapEdge[tri_DCEList,e_] :=
  Module[{e1,e2,e3,e4}, 
          e2 = NextEdge[tri,e1 = NextEdge[tri,e]];
          e4 = NextEdge[tri,e3 = NextEdge[tri,TwinEdge[e]]];
          InsertEdge[DeleteEdge[tri,e],e1,e2,e3,e4]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["DelaunayEdgeQ[tri,e]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se lo spigolo e della triangolazione \
tri soddisfa la condizione di Delaunay.\n",
  StyleBox["DelaunayQ[tri]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se la triangolazione tri e' una \
triangolazione di Delaunay.\n",
  StyleBox["MakeDelaunay[tri]",
    FontWeight->"Bold"],
  "\nTriangolazione di Delaunay ottenuta a partire dalla triangolazione tri."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[DelaunayEdgeQ,DelaunayQ,MakeDelaunay]
          
DelaunayEdgeQ[tri_DCEList,e_] :=
  Module[{t = TwinEdge[e]},
    Not[BoundedQ[tri,EdgeFace[tri,e]] &&
        BoundedQ[tri,EdgeFace[tri,t]] &&
        InsideCircleQ[VertexCoord[tri,{EdgeOrigin[tri,e],EdgeEnd[tri,e],
                                       EdgeEnd[tri,NextEdge[tri,e]]}],
                      VertexCoord[tri,EdgeEnd[tri,NextEdge[tri,t]]]]]]

DelaunayQ[tri_DCEList] :=
  Module[{l = Flatten[Partition[Edges[tri],1,2]],t = True,n,i = 1},
    n = Length[l];
    While[And[t,i < n],
          If[Not[DelaunayEdgeQ[tri,l[[i++]]]],t = False]]; t]

MakeDelaunay[tri_DCEList] :=
  Module[{tr = tri,l,p},
    While[Not[NullQ[p = FirstPosition[
                          l = Flatten[Partition[Edges[tr],1,2]],
                          _?(Not[DelaunayEdgeQ[tr,#]]&)]]],
          tr = SwapEdge[tr,l[[p]]]]; tr]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["MinSpanningTree[tri]",
    FontWeight->"Bold"],
  "\nStruttura DCE corrispondente ad un albero di lunghezza totale minima che \
connette tutti i vertici della triangolazione tri."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[MinSpanningTree]
          
MinSpanningTree[tri_DCEList] := 
  Module[{l = Sort[Flatten[Partition[Edges[tri],1,2]],
                (EdgeLength[tri,#1] > EdgeLength[tri,#2])&],
          i = 1,tr = tri,e,t},  
    While[Length[Faces[tr]] > 1,
      e = l[[i++]]; t = TwinEdge[e];
      If[EdgeFace[tr,e] != EdgeFace[tr,t],tr = DeleteEdge[tr,e]]]; tr]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["CircCenter[{{x1,y1},{x2,y2},{x3,y3}},{x,y}]\n",
    FontWeight->"Bold"],
  "Circocentro del triangolo di vertici {x1,y1},{x2,y2},{x3,y3}.\n",
  StyleBox["Voronoi[pts]\n",
    FontWeight->"Bold"],
  "Decomposizione di Voronoi della lista di punti pts."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[CircCenter, Voronoi]

CircCenter[{{x1_,y1_},{x2_,y2_},{x3_,y3_}}] := 
  {-Det[{{1,1,1},{y1,y2,y3},{x1^2 + y1^2,x2^2 + y2^2,x3^2 + y3^2}}], 
   +Det[{{1,1,1},{x1,x2,x3},{x1^2 + y1^2,x2^2 + y2^2,x3^2 + y3^2}}]}/
   (2 Det[{{1,x1,y1},{1,x2,y2},{1,x3,y3}}])

Voronoi[pts_List] := 
  Module[{x1 = Min[Thread[pts][[1]]],x2 = Max[Thread[pts][[1]]], 
          y1 = Min[Thread[pts][[2]]],y2 = Max[Thread[pts][[2]]], 
          tri = Triangulation[pts,Method -> Delaunay,Mode -> DCEList], 
          x0,y0,lx,ly,l,f0,vlist,elist,flist,coord,vor,n,
          f,ft,e,t,nt,fe,ce,ne,pe,ve,p1,p2,newe,newv},
    x0 = (x1 + x2)/2; y0 = (y1 + y2)/2; 
    lx = x2 - x1; x1 = x0 - 0.6 lx; x2 = x0 + 0.6 lx;
    ly = y2 - y1; y1 = y0 - 0.6 ly; y2 = y0 + 0.6 ly;
    l = lx + ly; 
    f0 = UnboundedFace[tri];
    vlist = ReplacePart[Map[TwinEdge,FaceList[tri],{2}],Null,f0];
    coord = vlist /. {e_Integer} :> 
      (f = EdgeFace[tri,TwinEdge[e]];
       CircCenter[VertexCoord[tri,FaceOuterVertices[tri,f]]]);
    flist = ReplacePart[VertexList[tri],Null,
                        Thread[{FaceInnerVertices[tri,f0][[1]]}]];
    AppendTo[flist,{0,0}];
    elist = EdgeList[tri]; 
    newe = Length[elist] + 1; newv = Length[vlist] + 1;
    elist = elist /. {f_,_,p_,n_,v_} :> 
        (e = PrevEdge[tri,n]; t = TwinEdge[e];
         ft = EdgeFace[tri,t]; nt = NextEdge[tri,t];
         fe = If[NullQ[flist[[v]]],flist[[-1,2]] = e;Length[flist],v];
         ce = If[NullQ[flist[[v]]],2,1];
         pe = If[ft != f0,nt,t];
         ne = If[f != f0,TwinEdge[p],t];
         ve = If[ft != f0,ft,
                 AppendTo[vlist,{e}]; 
                 AppendTo[coord,
                          p1 = VertexCoord[tri,v]; 
                          p2 = VertexCoord[tri,EdgeEnd[tri,e]]; 
                          (p1 + p2)/2 + l Cross[p2 - p1]/
                            Sqrt[(p2 - p1).(p2 - p1)]];newv++];
         {fe,ce,pe,ne,ve});
    BoxClip[DCEList[flist,elist,vlist,coord],{{x1,x2},{y1,y2}}]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangulatePolygon[pts]\n",
    FontWeight->"Bold"],
  "Triangolazione del poligono che ha come vertici i punti della lista pts, \
ordinata in modo standard lungo il bordo.",
  StyleBox["\nMethod -> Split|Reduce|Sweep\n",
    FontWeight->"Bold"],
  "Opzione di TriangulatePolygon che indica l'algoritmo da utilizzare.\n",
  StyleBox["Indexed -> True|False",
    FontWeight->"Bold"],
  "\nOpzione di TriangulatePolygon che indica se la lista risultante e' \
espressa mediante gli indici dei vertici nella lista pts.\n",
  StyleBox["Mode -> EdgeList|TriangleList|DCEList\n",
    FontWeight->"Bold"],
  "Opzione di TriangulatePolygon che indica se la triangolazione e' espressa \
come lista di spigoli, lista di triangoli o struttura DCE."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[TriangulatePolygon]
Options[TriangulatePolygon] = 
  {Method -> Sweep,Indexed -> False,Mode -> DCEList};

TriangulatePolygon[pts_List,opts___?OptionQ] :=
  Module[{op = Flatten[{opts,Options[TriangulatePolygon]}],tr,l,i},  
    Switch[Method /. op,
      Reduce,tr = ReduceTP[RegionToDCEList[Polygon[N[pts]]],1],
      Split,tr = SplitTP[RegionToDCEList[Polygon[N[pts]]],1],
      Sweep,tr = SweepTP[RegionToDCEList[Polygon[N[pts]]],1]];
    Switch[Mode /. op,
      EdgeList,
        l = Map[{EdgeOrigin[tr,#],EdgeEnd[tr,#]}&,
                Flatten[Partition[Edges[tr],1,2]]];
        If[Indexed /. op,l,l /. i_Integer :> pts[[i]]],
      TriangleList,
        l = Map[FaceOuterVertices[tr,#]&,BoundedFaces[tr]];
        If[Indexed /. op,l,l /. i_Integer :> pts[[i]]],
      DCEList,tr]]

Clear[ReduceTP,SplitTP,SweepTP]

ReduceTP[dce_,f_] :=
  Module[{bd = FaceOuterBoundary[dce,f],v,d,e1,e2,dce1},
    If[Length[bd] <= 3,dce,
       v = VertexCoord[dce,Map[EdgeOrigin[dce,#]&,bd]];
       d = FindShortDiagonal[v,Indexed -> True]; 
       {e1,e2} = bd[[d]];
       dce1 = InsertEdge[dce,PrevEdge[dce,e1],e1,PrevEdge[dce,e2],e2];
       ReduceTP[dce1,EdgeFace[dce1,e1]]]]

SplitTP[dce_,f_] := 
  Module[{bd = FaceOuterBoundary[dce,f],v,d,e1,e2,dce1},
    If[Length[bd] <= 3,dce,
       v = VertexCoord[dce,Map[EdgeOrigin[dce,#]&,bd]];
       d = FindDiagonal[v,Indexed -> True]; 
       {e1,e2} = bd[[d]];
       dce1 = InsertEdge[dce,PrevEdge[dce,e1],e1,PrevEdge[dce,e2],e2];
       dce1 = SplitTP[dce1,EdgeFace[dce1,e1]];
       SplitTP[dce1,EdgeFace[dce1,e2]]]]
   
SweepTP[dce_,f_] := Triangulate[dce,f]
  \
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Triangulate[dce]\n",
    FontWeight->"Bold"],
  "Struttura DCE ottenuta triangolando la struttura dce.\n",
  StyleBox["MakeMonotone[dce]",
    FontWeight->"Bold"],
  "\nStruttura DCE ottenuta decomponendo le facce limitate della struttura \
dce in facce monotone.\n",
  StyleBox["Triangulate[dce,f1]",
    FontWeight->"Bold"],
  "  ",
  StyleBox["Triangulate[dce,{f1,f2,...}]\n",
    FontWeight->"Bold"],
  "Struttura DCE ottenuta triangolando le facce f1,f2,... della struttura \
dce.",
  StyleBox["\nMakeMonotone[dce,f1]  MakeMonotone[dce,{f1,f2,...}]\n",
    FontWeight->"Bold"],
  "Struttura DCE ottenuta decomponendo in facce monotone le facce f1,f2,... \
della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Triangulate,MakeMonotone]

Triangulate[dce_DCEList] := Triangulate[dce,BoundedFaces[dce]]

Triangulate[dce_DCEList,l_List] := Fold[Triangulate,dce,l]

Triangulate[dce_DCEList,f_] := 
  Module[{triang,sweep,insedge,dce0,dce1,m,l,v1,v2,
          X = 1,SIDE = 2,PE = 3,NE = 4,upper = 1,lower = -1},
    triang[dce0_,m_] := 
      Module[{bd = FaceOuterBoundary[dce0,m],vl,sd,l}, 
        vl = Map[VertexCoord[dce0,EdgeOrigin[dce0,#1]]&,bd]; 
        sd = - Apply[Order,Partition[vl,2,1,1],1];
        l = Sort[Thread[{vl,sd,RotateRight[bd],bd}]];
        If[Length[l] <= 3,dce0,sweep[dce0,Drop[l,2],Take[l,2]]]];
    sweep[dce0_,l_,st_] :=
      Module[{dce1 = dce0,st1 = st,v = First[l],w = Last[st],n},
        If[Length[l] == 1,
           Switch[w[[SIDE]],
             upper,p = 1;
               While[p++ < Length[st1] - 1,
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]] - 1;
                     v = ReplacePart[v,n,PE]]; dce1,
             lower,p = 1;
               While[p++ < Length[st1] - 1,
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]];
                     v = ReplacePart[v,n,NE]]]; dce1,
           Switch[{w[[SIDE]],v[[SIDE]]},
             {upper,upper},
               p = Length[st1];
               While[And[p-- > 1,LineSlope[st1[[{p,p + 1},X]]] >
                                   LineSlope[{st1[[p + 1,X]],v[[X]]}]],
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]];
                     st1[[p]] = ReplacePart[st1[[p]],n,PE];
                     v = ReplacePart[v,n,NE]];
               sweep[dce1,Rest[l],Append[Take[st1,p + 1],v]],
             {upper,lower},
               p = 1;
               While[p++ < Length[st1],
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]] - 1;
                     v = ReplacePart[v,n,PE]];
               sweep[dce1,Rest[l],{ReplacePart[w,n,NE],v}],
             {lower,upper},
               p = 1;
               While[p++ < Length[st1],
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]];
                     v = ReplacePart[v,n,NE]];
               sweep[dce1,Rest[l],{ReplacePart[w,n,PE],v}],
             {lower,lower},
               p = Length[st1];
               While[And[p-- > 1,LineSlope[st1[[{p,p + 1},X]]] <
                                   LineSlope[{st1[[p + 1,X]],v[[X]]}]],
                     dce1 = insedge[dce1,st1[[p]],v];
                     n = Length[EdgeList[dce1]] - 1;
                     st1[[p]] = ReplacePart[st1[[p]],n,NE];
                     v = ReplacePart[v,n,PE]];
               sweep[dce1,Rest[l],Append[Take[st1,p + 1],v]]]]];
    insedge[dce0_,v1_,v2_] := 
      InsertEdge[dce0,v1[[PE]],v1[[NE]],v2[[PE]],v2[[NE]]];
    dce1 = MakeMonotone[dce,f];
    l := Join[{f},Range[Length[Faces[dce]] + 1,Length[Faces[dce1]]]];
    Fold[triang,dce1,l]]

MakeMonotone[dce_DCEList] := MakeMonotone[dce,BoundedFaces[dce]]

MakeMonotone[dce_DCEList,l_List] := Fold[MakeMonotone,dce,l]

MakeMonotone[dce_DCEList,f_] := 
  Module[{sweep,insedge,height,ord,helper,dce0,v1,v2,e,x,bd,vl,tp,l,
          end = 0,lower = 1,upper = 2,split = 3,merge = 4,start = 5,
          X = 1,TYPE = 2,PE = 3,NE = 4},      
    sweep[dce0_,l_,st_] :=
      If[EmptyQ[l],dce0,
      Module[{dce1 = dce0,st1 = st,v = First[l],w,e,n},
        x = v[[X,1]];
        Switch[v[[TYPE]],
          start,
            e = v[[NE]];
            st1 = OrdTreeInsert[st1,{height[e],e},ord[x]];
            helper[e] = v;
            sweep[dce1,Rest[l],st1],
          end,
            e = v[[PE]];
            w = helper[e];
            If[SameQ[w[[TYPE]],merge],
               dce1 = insedge[dce1,w,v]];
            st1 = OrdTreeDelete[st1,height[e],ord[x]];
            sweep[dce1,Rest[l],st1],
          lower,
            e = v[[PE]];
            w = helper[e];
            If[SameQ[w[[TYPE]],merge],
               dce1 = insedge[dce1,w,v];
               n = Length[EdgeList[dce1]] - 1;
               v[[PE]] = n];
            st1 = OrdTreeDelete[st1,height[e],ord[x]];
            e = v[[NE]];
            st1 = OrdTreeInsert[st1,{height[e],e},ord[x]];
            helper[e] = v;
            sweep[dce1,Rest[l],st1],
          upper,
            e = GetData[OrdTreeLower[st1,v[[X,2]]&,ord[x]]];
            w = helper[e];
            If[SameQ[w[[TYPE]],merge],
               dce1 = insedge[dce1,w,v];
               n = Length[EdgeList[dce1]];
               v[[NE]] = n];
            helper[e] = v;
            sweep[dce1,Rest[l],st1],
          split,
            e = GetData[OrdTreeLower[st1,v[[X,2]]&,ord[x]]];
            w = helper[e];
            dce1 = insedge[dce1,w,v];
            n = Length[EdgeList[dce1]];
            helper[e] = ReplacePart[v,n,NE];
            e = v[[NE]];
            st1 = OrdTreeInsert[st1,{height[e],e},ord[x]];
            helper[e] = ReplacePart[v,n - 1,PE];
            sweep[dce1,Rest[l],st1],
          merge,
            e = v[[PE]];
            w = helper[e];
            If[SameQ[w[[TYPE]],merge],
               dce1 = insedge[dce1,w,v];
               n = Length[EdgeList[dce1]] - 1;
               v[[PE]] = n];
            st1 = OrdTreeDelete[st1,height[e],ord[x]];
            e = GetData[OrdTreeLower[st1,v[[X,2]]&,ord[x]]];
            w = helper[e];
            If[SameQ[w[[TYPE]],merge],
               dce1 = insedge[dce1,w,v];
               n = Length[EdgeList[dce1]];
               v[[NE]] = n];
            helper[e] = v;
            sweep[dce1,Rest[l],st1]]]];
    insedge[dce0_,v1_,v2_] := 
      InsertEdge[dce0,v1[[PE]],v1[[NE]],v2[[PE]],v2[[NE]]];
    height[e_][x_] := 
      Module[{v1 = VertexCoord[dce,EdgeOrigin[dce,e]],
              v2 = VertexCoord[dce,EdgeEnd[dce,e]],dx},
        If[(dx = v2[[1]] - v1[[1]]) == 0,v1[[2]],
           v1[[2]] + (v2[[2]] - v1[[2]]) (x - v1[[1]])/dx]];
    ord[x_][k1_,k2_] := k1[x] <= k2[x];
    bd = FaceBoundaries[dce,f];
    vl = Map[VertexCoord[dce,EdgeOrigin[dce,#1]]&,bd,{2}]; 
    tp = Apply[{Order[#1,#2],Order[#2,#3],
                If[SameQ[#1,#3],1,Order[LineSlope[{#2,#1}],
                                        LineSlope[{#2,#3}]]]}&,
               Map[Partition[#,3,1,2]&,vl],{2}];
    tp = tp /. {{-1,1,-1} -> start,{1,-1,-1} -> end,
                {1,1,_}  -> lower,{-1,-1,_} -> upper,
                {-1,1,1} -> split,{1,-1,1} -> merge};
    l = Sort[Flatten[Map[Thread,
               Thread[{vl,tp,Map[RotateRight,bd],bd}]],1]];
    sweep[dce,l,OrdTree[]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["CartesianMesh[{x1,x2},n]",
    FontWeight->"Bold"],
  "\nMesh 1-dimensionale costituita da n segmenti consecutivi con vertici \
equidistanziati nell'intervallo [x1,x2].\n",
  StyleBox["CartesianMesh[{x1,...,xn}]",
    FontWeight->"Bold"],
  "\nMesh 1-dimensionale costituita da n segmenti consecutivi con vertici di \
ascisse x1,...,xn.\n",
  StyleBox["CartesianMesh[{x1,x2},{y1,y2},n,m]",
    FontWeight->"Bold"],
  "\nMesh cartesiana generata da n x m punti uniformemente distribuiti nel \
rettangolo [x1,x2] x [y1,y2].\n",
  StyleBox["CartesianMesh[{x1,...,xn},{y1,...,ym}]",
    FontWeight->"Bold"],
  "\nMesh cartesiana generata dagli n x m punti di coordinate {xi,yj}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[CartesianMesh]

CartesianMesh[{x1_,x2_},n_Integer] := 
  CartesianMesh[Range[x1,x2,(x2-x1)/(n-1)]]

CartesianMesh[x_List] := 
  Indexed[LineStrip[Range[Length[x]]],N[x]]

CartesianMesh[{x1_,x2_},{y1_,y2_},n_Integer] := 
  CartesianMesh[{x1,x2},{y1,y2},n,n]

CartesianMesh[{x1_,x2_},{y1_,y2_},n_Integer,m_Integer] := 
  CartesianMesh[Range[x1,x2,(x2-x1)/n],Range[y1,y2,(y2-y1)/m]]

CartesianMesh[x_List,y_List] := 
  Module[{n = Length[x],m = Length[y],t,v},
    t = Array[V,n m]; 
    v = Table[{x[[i]],y[[j]]},{j,1,m},{x,1,n}];
    Indexed[QuadPatch[n,t],N[Flatten[v,1]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["BilinearMesh[{exp1,exp2},{exp3,exp4},{x,x1,x2},{y,y1,y2},n,m]",
    FontWeight->"Bold"],
  "\nMesh bilineare con n x m elementi e parametrizzazioni di bordo definite \
dalle espressioni exp1 e exp2 con variabile x nell'intervallo [x1,x2], exp3 e \
exp4 con variabile y nell'intervallo [y1,y2].\n",
  StyleBox["BilinearMesh[{v11,...,v1n},{vm1,...,vmn},\n             \
{v11,...,vm1},{v1n,...,vmn}]",
    FontWeight->"Bold"],
  "\nMesh bilineare con n x m elementi e vertici di bordo lungo i quattro \
lati rispettivamente {v11,...,v1n},{vm1,...,vmn}, {v11,...,vm1} e \
{v1n,...,vmn}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[BilinearMesh]

BilinearMesh[{f1_,f2_},{g1_,g2_},{x1_,x2_},{y1_,y2_},n_Integer] := 
  BilinearMesh[{f1,f2},{g1,g2},{x1,x2},{y1,y2},n,n]

BilinearMesh[{exp1_,exp2_},{exp3_,exp4_},{x_,x1_,x2_},{y_,y1_,y2_},
              n_Integer,m_Integer] := 
  BilinearMesh[Table[exp1,{x,x1,x2,(x2 - x1)/n}],
               Table[exp2,{x,x1,x2,(x2 - x1)/n}],
               Table[exp3,{y,y1,y2,(y2 - y1)/m}],
               Table[exp4,{y,y1,y2,(y2 - y1)/m}]]

BilinearMesh[l1_List,l2_List,l3_List,l4_List] :=
  Module[{n = Length[l1],m = Length[l3],t,v},
    t = Array[V,n m];
    v = Table[((m - j) l1[[i]] + (j - 1) l2[[i]]) / (m - 1) +
              ((n - i) l3[[j]] + (i - 1) l4[[j]]) / (n - 1) +
              - ((n - i)(m - j) l1[[1]] + (i - 1)(m - j) l1[[n]]
                 + (n - i)(j - 1) l2[[1]] + (i - 1)(j - 1) l2[[n]]) /
                   ((n - 1)(m - 1)),
              {j,1,m},{i,1,n}];
    Indexed[QuadPatch[n,t],N[Flatten[v,1]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 360, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2080, 63, 591, 12, 110, "Text"],
Cell[2674, 77, 615, 16, 149, "Input",
  InitializationCell->True],
Cell[3292, 95, 789, 18, 170, "Text"],
Cell[4084, 115, 8301, 124, 2164, "Input",
  InitializationCell->True],
Cell[12388, 241, 262, 7, 50, "Text"],
Cell[12653, 250, 291, 10, 110, "Input",
  InitializationCell->True],
Cell[12947, 262, 620, 15, 140, "Text"],
Cell[13570, 279, 929, 25, 305, "Input",
  InitializationCell->True],
Cell[14502, 306, 332, 8, 65, "Text"],
Cell[14837, 316, 413, 12, 136, "Input",
  InitializationCell->True],
Cell[15253, 330, 404, 10, 80, "Text"],
Cell[15660, 342, 2041, 46, 591, "Input",
  InitializationCell->True],
Cell[17704, 390, 889, 19, 185, "Text"],
Cell[18596, 411, 1676, 45, 565, "Input",
  InitializationCell->True],
Cell[20275, 458, 835, 22, 185, "Text"],
Cell[21113, 482, 6694, 163, 2099, "Input",
  InitializationCell->True],
Cell[27810, 647, 828, 19, 185, "Text"],
Cell[28641, 668, 749, 25, 266, "Input",
  InitializationCell->True],
Cell[29393, 695, 736, 15, 155, "Text"],
Cell[30132, 712, 1109, 28, 305, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

