(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23119,        577]*)
(*NotebookOutlinePosition[     48942,       1521]*)
(*  CellTagsIndexPosition[     48898,       1517]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Poligoni", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["LineSlope[{{x1,y1},{x2,y2}}]\n",
    FontWeight->"Bold"],
  "Coefficiente angolare del segmento di estremi {x1,y2} e {x2,y2} (se x2 e' \
uguale ad x1, vale -Infinity/Indeterminate/+Infinity a seconda che y2 sia \
minore/uguale/maggiore di y1).\n",
  StyleBox["LineAngle[{{x1,y1},{x2,y2}}]",
    FontWeight->"Bold"],
  "\nAngolo orientato tra il semiasse positivo X e il segmento orientato di \
estremi {x1,y2} e {x2,y2}.\n",
  StyleBox["LineLength[",
    FontWeight->"Bold"],
  StyleBox["{{x1,y1},{x2,y2}}",
    FontWeight->"Bold"],
  StyleBox["]\n",
    FontWeight->"Bold"],
  "Lunghezza del segmento di estremi ",
  "{x1,y2} e {x2,y2}.\n",
  StyleBox["LineArea[{{x1,y1},{x2,y2}}]",
    FontWeight->"Bold"],
  "\nArea sottesa dal segmento orientato di estremi {x1,y2} e {x2,y2}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[LineSlope,LineAngle,LineLength,LineArea]

LineSlope[{{x1_,y1_},{x2_,y2_}}] := 
  If[Chop[x2 - x1] != 0,(y2 - y1) / (x2 - x1),
     If[Chop[y2 - y1] != 0,Sign[y2 - y1] Infinity,Indeterminate]]

LineAngle[{{x1_,y1_},{x2_,y2_}}] := ArcTan[x2 - x1,y2 - y1]

LineLength[{{x1_,y1_},{x2_,y2_}}] := Sqrt[(x2 - x1)^2 + (y2 - y1)^2]

LineArea[{{x1_,y1_},{x2_,y2_}}] := (x2 - x1) (y1 + y2)/2
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangleArea[{{x1,y1},{x2,y2},{x3,y3}}]\n",
    FontWeight->"Bold"],
  "Area del triangolo di vertici {x1,y1},{x2,y2},{x3,y3} (positiva se i \
vertici sono ordinati in modo standard negativa altrimenti).",
  StyleBox["\nTriangleClass[{{x1,y1},{x2,y2},{x3,y3}}]\n",
    FontWeight->"Bold"],
  "Classificazione del triangolo di vertici {x1,y1},{x2,y2},{x3,y3}:\nvale \
-1/0/+1 a seconda del segno dell'area (quindi dell'orientazione)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[TriangleArea,TriangleClass]\n\n\
TriangleArea[{{x1_,y1_},{x2_,y2_},{x3_,y3_}}] :=\n  ",
  StyleBox["Det[{{1,x1,y1},{1,x2,y2},{1,x3,y3}}] / 2",
    FontFamily->"Courier"],
  "\n\nTriangleClass[{{x1_,y1_},{x2_,y2_},{x3_,y3_}}] := \n  Sign[Chop[",
  StyleBox["Det[{{1,x1,y1},{1,x2,y2},{1,x3,y3}}]",
    FontFamily->"Courier"],
  "]]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PointLineClass[{x,y},{{x1,y1},{x2,y2}}]\n",
    FontWeight->"Bold"],
  "Classificazione della coppia {p,s}, con p punto di coordinate {x,y} e s \
segmento orientato di estremi {x1,y1} e {x2,y2}: vale 0 se il p sta in s, \
-0.5/+0.5 se p sta sul prolungamento negativo/positivo di s, -1/+1 se p sta \
nel semipiano positivo/negativo determinato da s.",
  StyleBox["\nPointLineClass[{x,y},{{x1,y1},{x2,y2}},X]\n\
PointLineClass[{x,y},{{x1,y1},{x2,y2}},Y]\n",
    FontWeight->"Bold"],
  "Classificazione della coppia {p,s}, con p punto di coordinate {x,y} e s \
segmento orientato di estremi {x1,y1} e {x2,y2}, rispetto alla direzione X/Y: \
vale Indeterminate se il p sta su s, altrimenti vale 0 se il s e' paralello \
all'asse X/Y o la retta parallela all'asse X/Y uscente da p non incontra s, \
-0.5/+0.5 se la retta incontra un estremo di s e p sta nel semipiano \
negativo/positivo determinato da s, -1/+1 se la retta incontra l'interno di s \
e p sta nel semipiano negativo/positivo."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[PointLineClass]

PointLineClass[{x_,y_},{{x1_,y1_},{x2_,y2_}}] :=
  Module[{det = Det[{{1,x,y},{1,x1,y1},{1,x2,y2}}]},
    If[Chop[det] != 0,Sign[det],
       If[(x - x2)(x2 - x1) + (y - y2)(y2 - y1) > 0,1/2,
          If[(x - x1)(x2 - x1) + (y - y1)(y2 - y1) < 0,-1/2,0]]]]
       
PointLineClass[{x_,y_},{{x1_,y1_},{x2_,y2_}},X] :=
  If[Or[y < Min[y1,y2],Max[y1,y2] < y],0,
     If[y1 == y2,If[Min[x1,x2] < x < Max[x1,x2],Indeterminate,0],
        Module[{det = Det[{{1,x,y},{1,x1,y1},{1,x2,y2}}]},
          If[Chop[det] == 0,Indeterminate,
             If[Or[y == y1,y == y2],Sign[det] / 2,Sign[det]]]]]]

PointLineClass[{x_,y_},{{x1_,y1_},{x2_,y2_}},Y] := 
  If[Or[x < Min[x1,x2],Max[x1,x2] < x],0,
     If[x1 == x2,If[Min[y1,y2] < y < Max[y1,y2],Indeterminate,0],
        Module[{det = Det[{{1,x,y},{1,x1,y1},{1,x2,y2}}]},
          If[Chop[det] == 0,Indeterminate,
             If[Or[x == x1,x == x2],Sign[det] / 2,Sign[det]]]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["LineLineClass[{{x1,y1},{x2,y2}},{{x3,y3},{x4,y4}}]\n",
    FontWeight->"Bold"],
  "Classificazione della coppia di segmenti {s1,s2} rispettivamente di \
estremi {x1,y1},{x2,y2} e {x3,y3},{x4,y4}: vale 0 se s1 e s2 sono disgiunti, \
Indeterminate se si incontrano e sono allineati, -1/+1 se hanno \
un'intersezione trasversale negativa/positiva, -0.5/+0.5 se l'intersezione e' \
estremo di uno dei due segmenti, -0.25/+0.25 se e' estremo di entrambi. \n",
  StyleBox["LineIntersection[{{x1,y1},{x2,y2}},{{x3,y3},{x4,y4}}]",
    FontWeight->"Bold"],
  "\nCoordinate del punto di intersezione dei segmenti di estremi \
{x1,y1},{x2,y2} e {x3,y3},{x4,y4} (vale Null se tale punto non esiste e \
Indeterminate se non e' unico.\n",
  StyleBox["LineAngle[{{x1,y1},{x2,y2}},{{x3,y3},{x4,y4}}]\n",
    FontWeight->"Bold"],
  "Angolo orientato tra il segmento orientato di estremi {x1,y1},{x2,y2} e il \
segmento orientato di estremi ",
  "{x3,y3},{x4,y4}.",
  "\n",
  StyleBox["Angle[{x1,y1},{x2,y2},{x3,y3}]",
    FontWeight->"Bold"],
  "\n",
  "Angolo orientato tra i segmenti orientati consecutivi di estremi \
{x1,y1},{x2,y2} e ",
  "{x2,y2},{x3,y3}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[LineLineClass,LineIntersection,Angle]\n\n",
  StyleBox["LineLineClass[{{x1_,y1_},{x2_,y2_}},{{x3_,y3_},{x4_,y4_}}] :=\n  \
Module[{cls = Sign[Chop[{Det[{{1,x1,y1},{1,x3,y3},{1,x4,y4}}],\n              \
             Det[{{1,x2,y2},{1,x3,y3},{1,x4,y4}}],\n                          \
 Det[{{1,x3,y3},{1,x1,y1},{1,x2,y2}}],\n                           \
Det[{{1,x4,y4},{1,x1,y1},{1,x2,y2}}]}]]},\n    Which[Count[cls,0] > 2,\n      \
      Module[{v12 = {x2 - x1,y2 - y1},v13 = {x3 - x1,y3 - y1},\n              \
      v14 = {x4 - x1,y4 - y1},v23 = {x3 - x2,y3 - y2},\n                    \
v24 = {x4 - x2,y4 - y2}},\n              If[Or[And[Chop[v12 . v23] > \
0,Chop[v12 . v24] > 0],\n                    And[Chop[v12 . v13] < 0,Chop[v12 \
. v14] < 0]],\n                 0,Indeterminate]],\n          \
MatchQ[cls,{1,1,_,_}|{-1,-1,_,_}|{_,_,1,1}|{_,_,-1,-1}],0,\n          \
True,Module[{c = cls.{1,-1,-1,1}},Sign[c] 2 ^ (Abs[c] - 4)]]]\n\n\
LineIntersection[{{x1_,y1_},{x2_,y2_}},{{x3_,y3_},{x4_,y4_}}] :=\n  \
Module[{cls = Sign[Chop[{Det[{{1,x1,y1},{1,x3,y3},{1,x4,y4}}],\n              \
             Det[{{1,x2,y2},{1,x3,y3},{1,x4,y4}}],\n                          \
 Det[{{1,x3,y3},{1,x1,y1},{1,x2,y2}}],\n                           \
Det[{{1,x4,y4},{1,x1,y1},{1,x2,y2}}]}]]},\n    Which[Count[cls,0] > 2,\n      \
      Module[{v12 = {x2 - x1,y2 - y1},v13 = {x3 - x1,y3 - y1},\n              \
      v14 = {x4 - x1,y4 - y1},v23 = {x3 - x2,y3 - y2},\n                    \
v24 = {x4 - x2,y4 - y2}},\n              Which[And[Chop[v12 . v23] >= \
0,Chop[v12 . v24] >= 0],\n                      If[Or[Chop[v23] == {0,0},\n   \
                         Chop[v24] == {0,0}],{x2,y2},Null],\n                 \
   And[Chop[v12 . v13] <= 0,Chop[v12 . v14] <= 0],\n                      \
If[Or[Chop[v13] == {0,0},\n                            Chop[v14] == \
{0,0}],{x1,y1},Null],\n                    True,Indeterminate]],\n          \
MatchQ[cls,{1,1,_,_}|{-1,-1,_,_}|{_,_,1,1}|{_,_,-1,-1}],Null,\n          \
True,Module[{t = cls[[1]]/(cls[[4]] - cls[[3]])},\n                 {x1,y1} + \
t {x2 - x1,y2 - y1}]]]\n\n",
    FontFamily->"Courier"],
  "LineAngle[{{x1_,y1_},{x2_,y2_}},{{x3_,y3_},{x4_,y4_}}] :=\n  Module[{v1 = \
{x2 - x1,y2 - y1},v2 = {x4 - x3,y4 - y3}},\n    Sign[v1 . Cross[v2]] \
ArcCos[v1 . v2 / Sqrt[(v1 . v1)(v2 . v2)]]]",
  StyleBox["\n\nAngle[",
    FontFamily->"Courier"],
  "{x1_,y1_},{x2_,y2_},{x3_,y3_}",
  StyleBox["] :=\n",
    FontFamily->"Courier"],
  "  Module[{v1 = {x2 - x1,y2 - y1},v2 = {x3 - x2,y3 - y2}},\n    Sign[v1 . \
Cross[v2]] ArcCos[v1 . v2 / Sqrt[(v1 . v1)(v2 . v2)]]]",
  StyleBox["\n",
    FontFamily->"Courier"]
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PolygonArea[{{x1,y1},...,{xn,yn}}]\n",
    FontWeight->"Bold"],
  "Area del poligono (semplice) di vertici {x1,y1},...,{xn,yn} (positiva se i \
vertici sono ordinati in modo standard negativa altrimenti).",
  StyleBox["\nPolygonClass[{{x1,y1},...,{xn,yn}}]\n",
    FontWeight->"Bold"],
  "Classificazione del poligono (semplice) di vertici {x1,y1},...,{xn,yn}:\n\
vale -1/0/+1 a seconda del segno dell'area (quindi dell'orientazione).\n",
  StyleBox["SimplePolygonQ[{{x1,y1},...,{xn,yn}}]",
    FontWeight->"Bold"],
  "\n",
  StyleBox["ConvexPolygonQ[{{x1,y1},...,{xn,yn}}]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se il poligono di vertici \
{x1,y1},...,{xn,yn} (ordinati in modo standard) e' semplice/convesso."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[PolygonArea,PolygonClass,SimplePolygonQ,ConvexPolygonQ]

PolygonArea[l_List] := - Apply[Plus,Map[LineArea,Partition[l,2,1,1]]]

PolygonClass[l_List] := Sign[Chop[PolygonArea[l]]]

SimplePolygonQ[l_List] := Null

ConvexPolygonQ[l_List] := Null
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["PointPolygonClass[{x,y},{{x1,y1},...,{xn,yn}}]\n",
    FontWeight->"Bold"],
  "Classificazione della coppia {p,pol}, con p punto di coordinate {x,y} e \
pol poligono semplice di vertici {x1,y1},...,{xn,yn}: vale 0/1 se il p sta \
all'esterno/interno di pol, 0.5 se p sta sul bordo di pol.\n",
  StyleBox["InsidePolygonQ[{{x1,y1},...,{xn,yn}},{x,y}]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se il punto di {x,y} sta all'interno \
del poligono di vertici {x1,y1},...,{xn,yn}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[PointPolygonClassInsidePolygonQ]

PointPolygonClass[{x_,y_},l_List] :=
  If[Length[l] < 2,0,
     Abs[Apply[Plus,Map[PointLineClass[{x,y},#,X]&,
                        Partition[l,2,1,1]]] / 2] /. 
                                            Indeterminate -> 1/2]

InsidePolygonQ[l_,{x_,y_}] := SameQ[PointPolygonClass[{x,y},l],1]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FindDiagonal[pts]  FindShortDiagonal[pts]\n",
    FontWeight->"Bold"],
  "Coppia degli estremi di una",
  " diagonale interna al poligono semplice che ",
  "ha come vertici i punti della lista pts ordinata in modo standard lungo il \
bordo. FindDiagonal restituisce una qualunque diagonale, mentre \
FindShortDiagonal restituisce una diagonale tra estremi di lati consecutivi.\n\
",
  StyleBox["Indexed -> True|False",
    FontWeight->"Bold"],
  "\nOpzione di ",
  "FindDiagomal",
  " che indica se la coppia risultante e' espressa mediante gli indici dei \
vertici nella lista pts."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FindDiagonal,FindShortDiagonal]
Options[FindDiagonal] = {Indexed -> False};
Options[FindShortDiagonal] = {Indexed -> False};

FindDiagonal[pts_List,opts___?OptionQ] := 
  If[Length[pts] <= 3,Null,
     Module[{pos = MinPosition[pts],l,p1,p2,p3,m,d,
             op = Flatten[{opts, Options[FindDiagonal]}]}, 
     l = RotateLeft[Range[Length[pts]],pos - 2]; 
     {p1,p2,p3} = pts[[l[[{1,2,3}]]]]; 
     m = Map[If[SameQ[1,TriangleClass[{p1,p2,pts[[#1]]}], 
                        TriangleClass[{p2,p3,pts[[#1]]}]], 
                TriangleArea[{p1,p3,pts[[#1]]}],
                Infinity]&, Drop[l,3]]; 
     pos = MinPosition[m];
     If[Chop[m[[pos]]] > 0,d = l[[{3,1}]],d = l[[{2,pos + 3}]]]; 
     If[Indexed /. op,d,pts[[d]]]]]
     
FindShortDiagonal[pts_List,opts___?OptionQ] := 
  If[Length[pts] <= 3,Null,
     Module[{fsd,l,p1,p2,p3,d,
             op = Flatten[{opts, Options[FindShortDiagonal]}]},
       fsd[l_] := 
         If[And[TriangleClass[{p1,p2,p3} = Take[l,3]] == 1,
                FreeQ[Drop[l,3], 
                  _?((And[TriangleClass[{p1,p3,#}] < 1, 
                          SameQ[1,TriangleClass[{p1,p2,#}],
                                  TriangleClass[{p2,p3,#}]]])&),{1}]], 
            1,1 + fsd[RotateLeft[l]]];
       d = fsd[pts] + {2,0}; 
       If[Indexed /. op,d,pts[[d]]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SimplePolygon[pts]\n",
    FontWeight->"Bold"],
  "Lista ottenuta ordinando la lista di punti pts in modo standard lungo il \
bordo di un poligono semplice avente per vertici gli stessi punti.",
  StyleBox["\nMethod -> Monotone|Starshape\n",
    FontWeight->"Bold"],
  "Opzione di SimplePolygon che indica l'algoritmo da utilizzare.\n",
  StyleBox["Indexed -> True|False",
    FontWeight->"Bold"],
  "\nOpzione di SimplePolygon che indica se la lista risultante e' espressa \
mediante gli indici dei vertici nella lista pts.\n",
  StyleBox["Mode -> VertexList|Polygon|DCEList\n",
    FontWeight->"Bold"],
  "Opzione di SimplePolygon che indica se il poligono e' espresso come \
primitiva Polygon o struttura DCE, invece che come lista di vertici."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[SimplePolygon,Monotone,Starshaped]
Options[SimplePolygon] = 
  {Method -> Starshaped,Indexed -> False,Mode -> VertexList};

SimplePolygon[pts_List,opts___?OptionQ] :=
  Module[{op = Flatten[{opts,Options[SimplePolygon]}],
          ind = Range[Length[pts]],poly},
    Switch[Method /. op,
      Monotone,poly = MonotoneSP[ind,N[pts]],
      Starshaped,poly = StarshapedSP[ind,N[pts]]];
    Switch[Mode /. op,
      VertexList,If[Indexed /. op,poly,pts[[poly]]],
      Polygon,Polygon[If[Indexed /. op,poly,pts[[poly]]]],
      DCEList,RegionToDCEList[Polygon[pts[[poly]]]]]]

ClearAll[MonotoneSP,StarshapedSP]

MonotoneSP[pts_,coord_] :=
  Module[{pts0 = Sort[pts,OrderedQ[{coord[[#1]],coord[[#2]]}]&],
          p1,p2,cls,pts1,pts2},
    p1 = First[pts0]; p2 = Last[pts0];
    cls = Map[PointLineClass[coord[[#]],coord[[{p1,p2}]],Y]&,pts0];
    pts1 = pts0[[ListPosition[cls,_?Positive]]];
    pts2 = pts0[[ListPosition[cls,_?Negative]]];
    Flatten[{p2,Reverse[pts1],p1,pts2}]]

StarshapedSP[pts_,coord_] :=
  Module[{c,cls,slps,pts1,pts2},
    c = Apply[Plus,coord]/Length[coord];
    cls = Map[Order[c,#]&,coord];
    pts1 = pts[[ListPosition[cls,_?Negative]]];
    pts2 = pts[[ListPosition[cls,_?NonNegative]]];
    slps = Map[LineSlope[{c,#}]&,coord];
    pts1 = Sort[pts1,(slps[[#1]] < slps[[#2]])&];
    pts2 = Sort[pts2,(slps[[#1]] < slps[[#2]])&];
    Flatten[{pts1,pts2}]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ConvexHull[pts]\n",
    FontWeight->"Bold"],
  "Lista dei vertici del poligono convesso generato dalla lista di punti pts, \
ordinata in modo standard lungo il bordo del poligono.",
  StyleBox["\nMethod -> Graham|Merge|Quick\n",
    FontWeight->"Bold"],
  "Opzione di ConvexHull che indica l'algoritmo da utilizzare.\n",
  StyleBox["Indexed -> True|False",
    FontWeight->"Bold"],
  "\nOpzione di ConvexHull che indica se la lista risultante e' espressa \
mediante gli indici dei vertici nella lista pts.\n",
  StyleBox["Mode -> VertexList|Polygon|DCEList\n",
    FontWeight->"Bold"],
  "Opzione di ConvexHull che indica se il poligono e' espresso come primitiva \
Polygon o struttura DCE, invece che come lista di vertici."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[ConvexHull,Graham,Merge,Quick]
Options[ConvexHull] = 
  {Method -> Quick,Indexed -> False,Mode -> VertexList};

ConvexHull[pts_List,opts___?OptionQ] :=
  Module[{op = Flatten[{opts,Options[ConvexHull]}],
          ind = Range[Length[pts]],poly},
    Switch[Method /. op,
      Graham,poly = GrahamCH[ind,N[pts]],
      Merge,poly = MergeCH[ind,N[pts]],
      Quick,poly = QuickCH[ind,N[pts]]];
    Switch[Mode /. op,
      VertexList,If[Indexed /. op,poly,pts[[poly]]],
      Polygon,Polygon[If[Indexed /. op,poly,pts[[poly]]]],
      DCEList,RegionToDCEList[Polygon[pts[[poly]]]]]]

ClearAll[GrahamCH,GrahamUH,MergeCH,MergeUH,JoinBridgeUH,QuickCH,QuickUH]

GrahamCH[pts_,coord_] :=
  Module[{pts0 = Sort[pts,OrderedQ[{coord[[#1]],coord[[#2]]}]&],
          p1,p2,cls,pts1,pts2},
    p1 = First[pts0]; p2 = Last[pts0];
    cls = Map[PointLineClass[coord[[#]],coord[[{p1,p2}]],Y]&,pts0];
    pts1 = Flatten[{p1,pts0[[ListPosition[cls,_?Positive]]],p2}]; 
    pts2 = Flatten[{p1,pts0[[ListPosition[cls,_?Negative]]],p2}];
    Reverse[Join[Rest[GrahamUH[pts1,coord]],
                 Rest[GrahamUH[Reverse[pts2],-coord]]]]]

GrahamUH[pts_,coord_] :=
  If[Length[pts] < 3,pts,
     Module[{p1 = First[pts],slps,pts1},
       slps = Map[LineSlope[coord[[{p1,#}]]]&,Rest[pts]];
       pts1 = Drop[pts,MaxPosition[slps]];
       Join[{p1},GrahamUH[pts1,coord]]]]  
  
MergeCH[pts_,coord_] :=
  Module[{pts0 = Sort[pts,OrderedQ[{coord[[#1]],coord[[#2]]}]&],
          p1,p2,cls,pts1,pts2},
    p1 = First[pts0]; p2 = Last[pts0];
    cls = Map[PointLineClass[coord[[#]],coord[[{p1,p2}]],Y]&,pts0];
    pts1 = Flatten[{p1,pts0[[ListPosition[cls,_?Positive]]],p2}]; 
    pts2 = Flatten[{p1,pts0[[ListPosition[cls,_?Negative]]],p2}];
    Reverse[Join[Rest[MergeUH[pts1,coord]],
                 Rest[MergeUH[Reverse[pts2],-coord]]]]]

MergeUH[pts_,coord_] := 
  If[Length[pts] < 3,pts,
     Module[{m = Floor[Length[pts]/2]},
       JoinBridgeUH[MergeUH[Take[pts,m],coord],
                    MergeUH[Drop[pts,m],coord],coord]]]
                  
JoinBridgeUH[uh1_,uh2_,coord_] :=
  Module[{p1 = Last[uh1],p2 = First[uh2],pos1,pos2},
    pos1 = LastRelPosition[LineSlope[coord[[{#,p2}]]]&,uh1,Greater];
    pos1 = If[NullQ[pos1],1,pos1 + 1];
    pos2 = FirstRelPosition[LineSlope[coord[[{p1,#}]]]&,uh2,Greater];
    pos2 = If[NullQ[pos2],Length[uh2],pos2];
    If[And[pos1 == Length[uh1],pos2 == 1],Join[uh1,uh2],
       JoinBridgeUH[Take[uh1,pos1],Drop[uh2,pos2 - 1],coord]]]

QuickCH[pts_,coord_] := 
  Module[{pts0 = Sort[pts,OrderedQ[{coord[[#1]],coord[[#2]]}]&],
          p1,p2,cls,pts1,pts2},
    p1 = First[pts0]; p2 = Last[pts0];
    cls = Map[PointLineClass[coord[[#]],coord[[{p1,p2}]],Y]&,pts0];
    pts1 = Flatten[{p1,pts0[[ListPosition[cls,_?Positive]]],p2}]; 
    pts2 = Flatten[{p1,pts0[[ListPosition[cls,_?Negative]]],p2}];
    Reverse[Join[Rest[QuickUH[pts1,coord]],
                 Rest[QuickUH[Reverse[pts2],-coord]]]]]

QuickUH[pts_,coord_] := 
  If[Length[pts]\[NonBreakingSpace]< 3, pts,
     Module[{p1 = First[pts],p2 = Last[pts],m,pos,pm,pts1,pts2},
       m = LineSlope[coord[[{p1,p2}]]];
       pm = pts[[pos = MaxPosition[(coord[[#]].{-m,1})&,pts]]];
       pts1 = Select[Take[pts,pos - 1],
         SameQ[PointLineClass[coord[[#]],coord[[{p1,pm}]],Y],1]&];
       pts2 = Select[Drop[pts,pos],
         SameQ[PointLineClass[coord[[#]],coord[[{pm,p2}]],Y],1]&];
       Join[QuickUH[Flatten[{p1,pts1,pm}],coord],
            Rest[QuickUH[Flatten[{pm,pts2,p2}],coord]]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RandomPoints[n]  \n",
    FontWeight->"Bold"],
  "Lista di n punti casuali intorno a {0,0} con distribuzione uniforme nel \
disco/quadrato unitario o normale con deviazione standard 1.\n",
  StyleBox["RandomPoints[n,s]\n",
    FontWeight->"Bold"],
  "Lista di n punti casuali intorno a {0,0} con distribuzione uniforme nel \
disco/quadrato di raggio s o normale con deviazione standard s.\n",
  StyleBox["Distribution -> UniformDisk|UniformSquare|Normal\n",
    FontWeight->"Bold"],
  "Opzione di RandomPoint che regola la distribuzione da utilizzare."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[RandomPoints,Distribution,UniformDisk,UniformSquare]
Options[RandomPoints] = {Distribution -> UniformSquare};

RandomPoints[n_Integer?Positive,s:(_?NumberQ):1,opts___?OptionQ] :=
  Module[{dis = Distribution /. Flatten[{opts,Options[RandomPoints]}]},
    Which[SameQ[dis,Normal],
            Table[Sqrt[-2 s Log[Random[]]] Cos[2 Pi Random[]],{n},{2}],
          SameQ[dis,UniformDisk],
            Table[s Sqrt[Random[]] {Cos[#],Sin[#]}&[2 Pi Random[]],{n}],
          SameQ[dis,UniformSquare],
            Table[Random[Real,{-s,s}],{n},{2}]]]
\
\>", "Input",
  InitializationCell->True]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 355, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2075, 63, 933, 24, 185, "Text"],
Cell[3011, 89, 443, 14, 162, "Input",
  InitializationCell->True],
Cell[3457, 105, 586, 12, 110, "Text"],
Cell[4046, 119, 401, 10, 110, "Input",
  InitializationCell->True],
Cell[4450, 131, 1140, 20, 245, "Text"],
Cell[5593, 153, 999, 24, 292, "Input",
  InitializationCell->True],
Cell[6595, 179, 1298, 28, 275, "Text"],
Cell[7896, 209, 2729, 44, 591, "Input",
  InitializationCell->True],
Cell[10628, 255, 893, 19, 170, "Text"],
Cell[11524, 276, 305, 12, 136, "Input",
  InitializationCell->True],
Cell[11832, 290, 654, 13, 125, "Text"],
Cell[12489, 305, 394, 12, 136, "Input",
  InitializationCell->True],
Cell[12886, 319, 736, 18, 155, "Text"],
Cell[13625, 339, 1385, 34, 435, "Input",
  InitializationCell->True],
Cell[15013, 375, 900, 19, 185, "Text"],
Cell[15916, 396, 1447, 39, 487, "Input",
  InitializationCell->True],
Cell[17366, 437, 878, 19, 185, "Text"],
Cell[18247, 458, 3551, 84, 1072, "Input",
  InitializationCell->True],
Cell[21801, 544, 705, 15, 140, "Text"],
Cell[22509, 561, 606, 14, 162, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

