(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     34749,        963]*)
(*NotebookOutlinePosition[     60572,       1907]*)
(*  CellTagsIndexPosition[     60528,       1903]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Reticoli", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Lattice[obj,{x1,x2},{y1,y2},opts]\n",
    FontWeight->"Bold"],
  "Oggetto grafico che rappresenta l'oggetto (o lista di oggetti) obj in un \
reticolo cellulare unitario nel rettangolo [x1,x2] x [y1,y2], con le opzioni \
opts."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Lattice]  
Options[Lattice] = {Grid -> True};

Lattice[obj_,{x1_,x2_},{y1_,y2_},opts___?OptionQ] :=
  Module[{gr1 = obj /. {r_Raster :> RasterExpand[r],c_Chain :> Nothing},
          gr2 = obj /. {r_Raster :> Nothing,c_Chain :> ChainExpand[c]},
          xx1 = x1 - .5, xx2 = x2 + .5,
          yy1 = y1 - .5, yy2 = y2 + .5, 
          op = Flatten[{opts,Options[Lattice]}]},  
    Graphics[{{GrayLevel[1],Rectangle[{xx1,yy1},{xx2,yy2}]},
              gr1,
              If[Grid /. op,
                 {GrayLevel[.5],
                  Table[Line[{{xx1,yy},{xx2,yy}}],{yy,yy1,yy2}],
                  Table[Line[{{xx,yy1},{xx,yy2}}],{xx,xx1,xx2}]},
                 Nothing],
              PointSize[.02],Thickness[.005],gr2},
             Select[op,FreeQ[#,Grid]&],
             Frame -> True,
             FrameTicks -> {Range[x1,x2],Range[y1,y2]},
             PlotRange -> {{x1 - .75,x2 + .75},{y1 - .75,y2 + .75}},
             AspectRatio -> Automatic]]
\
\>", "Input",
  InitializationCell->True],

Cell["Oggetti Raster", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Raster[{x,y},m]\n",
    FontWeight->"Bold"],
  "Oggetto raster con origine nel punto di coordinate (intere) {x,y}, \
descritto dalla matrice binaria m: m[[i,j]] vale 1 se il pixel di coordinate \
{x + i,y + j} appartiene all'oggetto e 0 altrimenti.\n",
  StyleBox["RasterExpand[r]\n",
    FontWeight->"Bold"],
  "Espansione dell'oggetto raster r in termini di primitive grafiche."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[RasterExpand]

RasterExpand[Raster[x_,m_]] :=
  MapIndexed[
    Which[#1 == 0,Nothing,
          #1 == 1,Rectangle[x + #2 - 1.5,x + #2 - .5],
          0 < #1 < 1,{GrayLevel[1 - #1],
                      Rectangle[x + #2 - 1.5,x + #2 - .5]},
          -1 <= #1 < 0,{RGBColor[1,1 + #1,1 + #1],
                        Rectangle[x + #2 - 1.5,x + #2 - .5]},
          True,{RGBColor[0,0,1],
                        Rectangle[x + #2 - 1.5,x + #2 - .5]}]&,
           m,{2}]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Origin[r]\n",
    FontWeight->"Bold"],
  "Origine dell'oggetto raster r.\n",
  StyleBox["Pixels[r]\n",
    FontWeight->"Bold"],
  "Matrice dei pixel dell'oggetto raster r.\n",
  StyleBox["Range[r]\n",
    FontWeight->"Bold"],
  "Limiti dell'oggetto raster r nella forma {{xmin,xmax},{ymin,ymax}}.\n",
  StyleBox["InRangeQ[r,{x,y}]\n",
    FontWeight->"Bold"],
  "Espressione booleana vere se e solo se {x,y} sta nel range dell'oggetto \
raster r.\n",
  StyleBox["GetPixel[r,{x,y}]  GetPixel[r,{x,y},d]",
    FontWeight->"Bold"],
  "\nValore del pixel di coordinate {x,y} dell'oggetto raster r (con valore \
di default d se {x,y} sta fuori di limiti di r).\n",
  StyleBox["SetPixel[r,{x,y},p]",
    FontWeight->"Bold"],
  "\nOggetto raster ottenuto da r sosituendo con p il valore del pixel di \
coordinate {x,y} ."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Origin,Pixels,InRangeQ,GetPixel,SetPixel]
Unprotect[Range];

Origin[r_Raster] := r[[1]]

Pixels[r_Raster] := r[[2]]

Range[r_Raster] := 
  Thread[{Origin[r],Origin[r] + Dimensions[Pixels[r]] - {1,1}}]

InRangeQ[r_Raster,{x_,y_}] :=
  Apply[And,Thread[0 <= {x,y} - Origin[r] < Dimensions[Pixels[r]]]]
  
GetPixel[r_Raster,{x_,y_},d_:0] := 
  If[InRangeQ[r,{x,y}],Extract[Pixels[r],{x,y} - Origin[r] + 1],d]

SetPixel[r_Raster,{x_,y_},p_] := 
  If[InRangeQ[r,{x,y}],
     Raster[Origin[r],ReplacePart[Pixels[r],p,{x,y} - Origin[r] + 1]],r]

Protect[Range];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Square[n]  Diamond[n]  Disk[n]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster binario che rappresenta un quadrato/diamante/disco \
di raggio n centrato in {0,0}.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Square,Diamond]
Unprotect[Disk];

Square[n_] := 
  Raster[{-n,-n},Table[1,{2 n + 1},{2 n + 1}]]

Diamond[n_] := 
  Raster[{-n,-n},Table[If[Abs[i] + Abs[j] <= n,1,0],{i,-n,n},{j,-n,n}]]

Disk[n_] := 
  Raster[{-n,-n},Table[If[i^2 + j^2 <= n^2,1,0],{i,-n,n},{j,-n,n}]]

Protect[Disk];\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["ClipRaster[r,{{x1,x2},{y1,y2}}]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r ponendo il range uguale \
{{x1,x2},{y1,y2}} e riposizionando l'origine. I pixel di r fuori dal nuovo \
range vengono eliminati, mentre quelli inclusi in tale range ma non nel range \
di r sono lasciati vuoti.",
    FontFamily->"Courier"],
  StyleBox["\nTrimRaster[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r eliminando tutte le righe e colonne \
vuote ai margini della matrice e riposizionando l'origine.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[ClipRaster,TrimRaster]

ClipRaster[r_Raster,{{x1_,x2_},{y1_,y2_}}] :=
  Module[{ori = Origin[r],rg = Range[r],cx1,cx2,cy1,cy2,
          pxs = Table[0,{x2 - x1 + 1},{y2 - y1 + 1}]},
    cx1 = Max[x1,rg[[1,1]]]; cx2 = Min[x2,rg[[1,2]]];
    cy1 = Max[y1,rg[[2,1]]]; cy2 = Min[y2,rg[[2,2]]];
    If[And[cx1 <= cx2,cy1 <= cy2],
       pxs[[Range[cx1,cx2] - x1 + 1,
            Range[cy1,cy2] - y1 + 1]] =
         Take[Pixels[r],{cx1,cx2} - ori[[1]] + 1,
                        {cy1,cy2} - ori[[2]] + 1];
       Raster[{x1,y1},pxs]]]

TrimRaster[r_Raster] := 
  ClipRaster[r,Origin[r] + 
                Map[{Min[#],Max[#]}&,
                     Thread[Position[Pixels[r],_?Positive]]] - 1]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TranslateRaster[r,v]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto traslando r mediante il vettore v.",
    FontFamily->"Courier"],
  StyleBox["\nRotateRaster[r,CCW]  RotateRaster[r,CW]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto ruotando r di 90\[Degree] in senso \
antiorario/orario.",
    FontFamily->"Courier"],
  StyleBox["\nReflectRaster[r,X]  ReflectRaster[r,X]  ReflectRaster[r,XY]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto riflettendo r nella direzione dell'asse \
X/Y/entrambi.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[TranslateRaster,RotateRaster,ReflectRaster]

TranslateRaster[r_Raster,v_] := Raster[Origin[r] + v,Pixels[r]]

RotateRaster[r_Raster,CCW] := 
  Raster[Origin[r],Reverse[Thread[Pixels[r]]]]

RotateRaster[r_Raster,CW] := 
  Raster[Origin[r],Thread[Reverse[Pixels[r]]]]

ReflectRaster[r_Raster,X] := 
  Raster[Origin[r],Reverse[Pixels[r]]]

ReflectRaster[r_Raster,Y] := 
  Raster[Origin[r],Map[Reverse,Pixels[r]]]  
  
ReflectRaster[r_Raster,XY] := 
  Raster[Origin[r],Reverse[Map[Reverse,Pixels[r]]]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RasterUnion[r1,r1,...]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster unione di r1,r2,...",
    FontFamily->"Courier"],
  StyleBox["\nRasterIntersection[r1,r2,...]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster intersezione di r1,r2,...\n",
    FontFamily->"Courier"],
  StyleBox["RasterComplement[r1,r2]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster differenza tra r1 e r2.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["RasterUnion",
    FontFamily->"Courier"],
  ",",
  StyleBox["RasterIntersection,RasterComplement",
    FontFamily->"Courier"],
  "]\nSetAttributes[{RasterUnion,RasterIntersection},{Flat,OneIdentity}]\n\n\
RasterUnion[r1_Raster,r2_Raster] :=\n  Module[{rg1 = Range[r1],rg2 = \
Range[r2],rg,cl1,cl2},\n    rg = Map[{Min[#[[1]]],Max[#[[2]]]}&,\n            \
 Transpose[{rg1,rg2},{3,1,2}]];\n    cl1 = ClipRaster[r1,rg]; cl2 = \
ClipRaster[r2,rg];\n    \
Raster[Origin[cl1],MapThread[Max,{Pixels[cl1],Pixels[cl2]},2]]]\n\n\
RasterIntersection[r1_Raster,r2_Raster] := \n  Module[{rg1 = Range[r1],rg2 = \
Range[r2],rg,cl1,cl2},\n    rg = Map[{Max[#[[1]]],Min[#[[2]]]}&,\n            \
 Transpose[{rg1,rg2},{3,1,2}]];\n    If[And[rg[[1,1]] <= rg[[1,2]],rg[[2,1]] \
<= rg[[2,2]]],\n       cl1 = ClipRaster[r1,rg]; cl2 = ClipRaster[r2,rg];\n    \
   Raster[Origin[cl1],MapThread[Min,{Pixels[cl1],Pixels[cl2]},2]]]]\n\n\
RasterComplement[r1_Raster,r2_Raster] := \n  Module[{cl2 = \
ClipRaster[r2,Range[r1]]},\n    Raster[Origin[r1],MapThread[Max[0,#1 - #2]&,\n\
                                {Pixels[r1],Pixels[cl2]},2]]]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RasterConvolve[r,mat]  RasterConvolve[r,mat,d]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r mediante convoluzione con matrice \
dei coefficienti mat (assumendo d come valore di default per i pixel fuori \
dai limiti di r).\n",
    FontFamily->"Courier"],
  StyleBox["RasterConvolve[r,ker]  RasterConvolve[r,ker,d]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r mediante convoluzione con nucleo ker \
(assumendo d come valore di default per i pixel fuori dai limiti di r).",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[RasterConvolve]\n\nRaster",
  StyleBox["Convolve",
    FontFamily->"Courier"],
  "[r_Raster,m:(_?MatrixQ|_Raster),d_:0] := \n  Module[{r1 = r,rg = \
Range[r],mat,dim,ngbds,val,x1,x2,y1,y2},\n    If[MatchQ[m,_?MatrixQ],\n       \
(dim = Reverse[Dimensions[m]];\n        mat = Thread[Reverse[m]]),\n       \
(dim = Dimensions[Pixels[m]];\n        mat = \
Reverse[Map[Reverse,Pixels[m]]])];\n    ngbds = \
Partition[Pixels[r],dim,{1,1},{Ceiling[dim/2]},d];\n    x1 = rg[[1,1]]; x2 = \
rg[[1,2]]; y1 = rg[[2,1]]; y2 =rg[[2,2]];\n    Do[val = (mat ngbds[[x - x1 + \
1,y - y1 + 1]]) /. List -> Plus;\n       If[val != GetPixel[r,{x,y}],r1 = \
SetPixel[r1,{x,y},val]],\n       {y,y1,y2},{x,x1,x2}]; r1]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RasterApply[f,r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r applicando la funzione f a tutti i \
pixel. \n",
    FontFamily->"Courier"],
  StyleBox["RasterApply[f,r,pos]  RasterApply[f,r,pos,d]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r sostituendo ogni pixel con il valore \
della funzione f applicata alla lista dei pixel vicini specificati dalla \
lista pos di posizioni relative (assumendo d come valore di default per i \
pixel fuori dai limiti di r).\n",
    FontFamily->"Courier"],
  StyleBox["RasterApply[f,r,mask]  RasterApply[f,r,mask,d]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r sostituendo ogni pixel con il valore \
della funzione f applicata alla lista dei pixel vicini specificati dal raster \
binario mask (assumendo d come valore di default per i pixel fuori dai limiti \
di r).",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[RasterApply]\n\nRaster",
  StyleBox["Apply",
    FontFamily->"Courier"],
  "[f_,r_Raster,l:(_List|_Raster):{{0,0}},d_:0] := \n  Module[{r1 = r,rg = \
Range[r],pos,val},\n    If[MatchQ[l,_List],pos = l,\n       pos = Map[(# + \
Origin[l] - 1)&,\n                 Position[Pixels[l],_?Positive]];\n       \
pos = Split[pos,(#1[[1]] == #2[[1]])&]];\n    Do[val = f[Map[GetPixel[r,{x,y} \
+ #,d]&,pos,{-2}]];\n       If[val != GetPixel[r,{x,y}],r1 = \
SetPixel[r1,{x,y},val]],\n       \
{y,rg[[2,1]],rg[[2,2]]},{x,rg[[1,1]],rg[[1,2]]}]; r1]\n       "
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RasterInverse[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster inverso di r.",
    FontFamily->"Courier"],
  StyleBox["\nRasterThreshold[r]  RasterThreshold[r,t]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto binarizzando r con soglia 0 o t.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[RasterInverse,",
  StyleBox["RasterThreshold",
    FontFamily->"Courier"],
  "]",
  "\n\nRasterInverse[r_Raster] := RasterApply[(1 - #[[1]])&,r]\n\n",
  StyleBox["RasterThreshold",
    FontFamily->"Courier"],
  "[r_Raster,t_:0] := RasterApply[If[#[[1]] <= t,0,1]&,r]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["RasterDilate[r]  RasterDilate[r,mask]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r per dilatazione (utilizzando il \
raster binario mask come maschera).",
    FontFamily->"Courier"],
  StyleBox["\nRasterErode[r]  RasterErode[r,mask]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster ottenuto da r per oresione (utilizzando il raster \
binario mask come maschera).",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["RasterDilate",
    FontFamily->"Courier"],
  ",",
  StyleBox["RasterErode",
    FontFamily->"Courier"],
  ",",
  StyleBox["RasterInverse",
    FontFamily->"Courier"],
  "]\n\nRaster",
  StyleBox["Dilate",
    FontFamily->"Courier"],
  "[r_Raster,mask_Raster:Square[1]] := RasterApply[Max,r,mask]\n\n\
RasterErode[r_Raster,mask_Raster:Square[1]] := RasterApply[Min,r,mask,1]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FourEdges[r]  EightEdges[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster contenente i bordi 4-/8-connessi di r.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["FourEdges",
    FontFamily->"Courier"],
  ",",
  StyleBox["EightEdges",
    FontFamily->"Courier"],
  "]\n\n",
  StyleBox["FourEdges",
    FontFamily->"Courier"],
  "[r_Raster] := \n  RasterApply[If[(Max[#] != #[[2,2]]),1,0]&,r,Square[1]]\n\
\n",
  StyleBox["EightEdges",
    FontFamily->"Courier"],
  "[r_Raster] := \n  RasterApply[If[(Max[#] != #[[2,2]]),1,0]&,r,Diamond[1]]\n\
"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FourConnectedQ[r]  EightConnectedQ[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana vera se e solo se r e' un oggetto raster \
4-/8-connesso.",
    FontFamily->"Courier"],
  StyleBox["\nFourComponent[r,{x,y}]  EightComponent[r,{x,y}]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster contenente la 4-/8-connessa di r a cui appartiene \
il pixel di coordinate {x,y}.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["FourConnectedQ,EightConnectedQ",
    FontFamily->"Courier"],
  ",",
  StyleBox["FourComponent",
    FontFamily->"Courier"],
  ",",
  StyleBox["EightComponent",
    FontFamily->"Courier"],
  "]\n\n",
  StyleBox["FourConnectedQ",
    FontFamily->"Courier"],
  "[r_Raster] := \n  Module[{x = Position[Pixels[r],_?Positive,2,1]},\n    \
Or[EmptyQ[x],SameQ[r,FourComponent[r,Origin[r] + x[[1]] - 1]]]]\n\n",
  StyleBox["EightConnectedQ",
    FontFamily->"Courier"],
  "[r_Raster] :=\n  Module[{x = Position[Pixels[r],_?Positive,2,1]},\n    \
Or[EmptyQ[x],SameQ[r,EightComponent[r,Origin[r] + x[[1]] - 1]]]]\n\n",
  StyleBox["FourComponent",
    FontFamily->"Courier"],
  "[r_Raster,x_] :=\n  Module[{r0 = \
Raster[Origin[r],Map[0&,Pixels[r],{2}]],comp,val},\n    comp[x0_] :=\n      \
If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         r0 = \
SetPixel[r0,x0,val];\n         comp[x0 + {1,0}]; comp[x0 + {0,1}];\n         \
comp[x0 + {-1,0}]; comp[x0 + {0,-1}]];\n    comp[x]; r0]\n\n",
  StyleBox["EightComponent",
    FontFamily->"Courier"],
  "[r_Raster,x_] :=\n  Module[{r0 = \
Raster[Origin[r],Map[0&,Pixels[r],{2}]],comp,val},\n    comp[x0_] :=\n      \
If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         r0 = \
SetPixel[r0,x0,val];\n         comp[x0 + {1,0}]; comp[x0 + {1,1}];\n         \
comp[x0 + {0,1}]; comp[x0 + {-1,1}];\n         comp[x0 + {-1,0}]; comp[x0 + \
{-1,-1}];\n         comp[x0 + {0,-1}]; comp[x0 + {1,-1}]];\n    comp[x]; r0]\n\
"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FourFill[r,{x,y}]  EightFill[r,{x,y}]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster contenente il 4-/8-riempimento della regione \
complementare ad r a cui appartiene il pixel di coordinate {x,y}.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["FourFill,EightFill",
    FontFamily->"Courier"],
  "]\n\n",
  StyleBox["FourFill",
    FontFamily->"Courier"],
  "[r_Raster,x_] :=\n  Module[{r0 = \
Raster[Origin[r],Map[0&,Pixels[r],{2}]],fill,x1},\n    fill[x0_] :=\n      \
If[GetPixel[r0,x0,1] == 0,\n         r0 = SetPixel[r0,x0,1];\n         \
If[GetPixel[r,x1 = x0 + {1,0},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 = \
x0 + {0,1},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 = x0 + {-1,0},1] == \
0,fill[x1]];\n         If[GetPixel[r,x1 = x0 + {0,-1},1] == 0,fill[x1]]];\n   \
 If[GetPixel[r,x,1] == 0,fill[x]]; r0]\n",
  StyleBox["\nEightFill",
    FontFamily->"Courier"],
  "[r_Raster,x_] :=\n  Module[{r0 = \
Raster[Origin[r],Map[0&,Pixels[r],{2}]],fill,x1},\n    fill[x0_] :=\n      \
If[GetPixel[r0,x0,1] == 0,\n         r0 = SetPixel[r0,x0,1];\n         \
If[GetPixel[r,x1 = x0 + {1,0},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 = \
x0 + {1,1},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 = x0 + {0,1},1] == \
0,fill[x1]];\n         If[GetPixel[r,x1 = x0 + {-1,1},1] == 0,fill[x1]];\n    \
     If[GetPixel[r,x1 = x0 + {-1,0},1] == 0,fill[x1]];\n         \
If[GetPixel[r,x1 = x0 + {-1,-1},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 \
= x0 + {0,-1},1] == 0,fill[x1]];\n         If[GetPixel[r,x1 = x0 + {1,-1},1] \
== 0,fill[x1]]];\n    If[GetPixel[r,x,1] == 0,fill[x]]; r0]\n"
}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["SimpleFourPathQ[r]  SimpleEightPathQ[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se l'oggetto raster \
r rappresenta un 4-/8-arco semplice.",
    FontFamily->"Courier"],
  StyleBox["\nSimpleFourLoopQ[r]  SimpleEightLoopQ[r]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se l'oggetto raster \
r rappresenta un 4-/8-cappio semplice.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["SimpleFourPathQ,SimpleEightPathQ,\n         \
SimpleFourLoopQ,SimpleEightLoopQ",
    FontFamily->"Courier"],
  "]\n\n",
  StyleBox["SimpleFourPathQ",
    FontFamily->"Courier"],
  "[r_Raster] := \n  Module[{x = Position[Pixels[r],_?Positive,2,1],\n        \
  r0 = Raster[Origin[r],Map[0&,Pixels[r],{2}]],check,val},\n    check[x0_] :=\
\n      If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         \
If[Count[{GetPixel[r,x0 + {1,0}],GetPixel[r,x0 + {1,1}],\n                   \
GetPixel[r,x0 + {0,1}],GetPixel[r,x0 + {-1,1}],\n                   \
GetPixel[r,x0 + {-1,0}],GetPixel[r,x0 + {-1,-1}],\n                   \
GetPixel[r,x0 + {0,-1}],GetPixel[r,x0 + {1,-1}]},\n                  \
_?Positive] > 2,False,\n            r0 = SetPixel[r0,x0,val];\n            \
And[check[x0 + {1,0}],check[x0 + {0,1}],\n                check[x0 + \
{-1,0}],check[x0 + {0,-1}]]],True];\n     And[Not[EmptyQ[x]],check[Origin[r] \
+ x[[1]] - 1],SameQ[r,r0]]]\n",
  StyleBox["\nSimpleHeightPathQ",
    FontFamily->"Courier"],
  "[r_Raster] := \n  Module[{x = Position[Pixels[r],_?Positive,2,1],\n        \
  r0 = Raster[Origin[r],Map[0&,Pixels[r],{2}]],check,val},\n    check[x0_] :=\
\n      If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         \
If[Count[{GetPixel[r,x0 + {1,0}],GetPixel[r,x0 + {1,1}],\n                   \
GetPixel[r,x0 + {0,1}],GetPixel[r,x0 + {-1,1}],\n                   \
GetPixel[r,x0 + {-1,0}],GetPixel[r,x0 + {-1,-1}],\n                   \
GetPixel[r,x0 + {0,-1}],GetPixel[r,x0 + {1,-1}]},\n                  \
_?Positive] > 2,False,\n            r0 = SetPixel[r0,x0,val];\n            \
And[check[x0 + {1,0}],check[x0 + {1,1}],\n                check[x0 + \
{0,1}],check[x0 + {-1,1}],\n                check[x0 + {-1,0}],check[x0 + \
{-1,-1}],\n                check[x0 + {0,-1}],check[x0 + {1,-1}]]],True];\n   \
  And[Not[EmptyQ[x]],check[Origin[r] + x[[1]] - 1],SameQ[r,r0]]]\n\n",
  StyleBox["SimpleFourLoopQ",
    FontFamily->"Courier"],
  "[r_Raster] := \n  Module[{x = Position[Pixels[r],_?Positive,2,1],\n        \
  r0 = Raster[Origin[r],Map[0&,Pixels[r],{2}]],check,val},\n    check[x0_] :=\
\n      If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         \
If[Count[{GetPixel[r,x0 + {1,0}],GetPixel[r,x0 + {1,1}],\n                   \
GetPixel[r,x0 + {0,1}],GetPixel[r,x0 + {-1,1}],\n                   \
GetPixel[r,x0 + {-1,0}],GetPixel[r,x0 + {-1,-1}],\n                   \
GetPixel[r,x0 + {0,-1}],GetPixel[r,x0 + {1,-1}]},\n                  \
_?Positive] != 2,False,\n            r0 = SetPixel[r0,x0,val];\n            \
And[check[x0 + {1,0}],check[x0 + {0,1}],\n                check[x0 + \
{-1,0}],check[x0 + {0,-1}]]],True];\n     And[Not[EmptyQ[x]],check[Origin[r] \
+ x[[1]] - 1],SameQ[r,r0]]]\n",
  StyleBox["\nSimpleHeightLoopQ",
    FontFamily->"Courier"],
  "[r_Raster] := \n  Module[{x = Position[Pixels[r],_?Positive,2,1],\n        \
  r0 = Raster[Origin[r],Map[0&,Pixels[r],{2}]],check,val},\n    check[x0_] :=\
\n      If[And[GetPixel[r0,x0] == 0,(val = GetPixel[r,x0]) > 0],\n         \
If[Count[{GetPixel[r,x0 + {1,0}],GetPixel[r,x0 + {1,1}],\n                   \
GetPixel[r,x0 + {0,1}],GetPixel[r,x0 + {-1,1}],\n                   \
GetPixel[r,x0 + {-1,0}],GetPixel[r,x0 + {-1,-1}],\n                   \
GetPixel[r,x0 + {0,-1}],GetPixel[r,x0 + {1,-1}]},\n                  \
_?Positive] != 2,False,\n            r0 = SetPixel[r0,x0,val];\n            \
And[check[x0 + {1,0}],check[x0 + {1,1}],\n                check[x0 + \
{0,1}],check[x0 + {-1,1}],\n                check[x0 + {-1,0}],check[x0 + \
{-1,-1}],\n                check[x0 + {0,-1}],check[x0 + {1,-1}]]],True];\n   \
  And[Not[EmptyQ[x]],check[Origin[r] + x[[1]] - 1],SameQ[r,r0]]]\n"
}], "Input",
  InitializationCell->True],

Cell["Oggetti Chain", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Chain[{x,y},v,c]\n",
    FontWeight->"Bold"],
  "Oggetto chain (catena di pixel) con origine nel punto di coordinate \
(intere) {x,y} e direzione iniziale v, descritto dal codice c.\n",
  StyleBox["ChainExpand[c]\n",
    FontWeight->"Bold"],
  "Espansione dell'oggetto chain c in termini di primitive grafiche."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Chain,ChainSteps,ChainDirections,ChainExpand]

ChainSteps = {{1,0},{1,1},{0,1},{-1,1},{-1,0},{-1,-1},{0,-1},{1,-1}};
ChainDirections = {{3,2,1},{4,8,0},{6,7,8}};

ChainExpand[Chain[x_,v_,c_]] :=
  Module[{chainrest},
    chainrest[xx_,vv_,cc_] :=
      If[EmptyQ[cc],{},
         If[ListQ[First[cc]],
            {chainrest[xx,vv,First[cc]],
             chainrest[xx,vv,Rest[cc]]},
            Module[{nxx,nvv},
              nvv = Mod[vv + First[cc],8];
              nxx = xx + ChainSteps[[nvv + 1]];
              {Line[{xx,nxx}],Point[nxx],
               chainrest[nxx,nvv,Rest[cc]]}]]];
    Flatten[{Point[x],chainrest[x,v,c]}]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["Origin[c]\n",
    FontWeight->"Bold"],
  "Origine dell'oggetto chain c.\n",
  StyleBox["StartDirection[c]",
    FontWeight->"Bold"],
  "\nDirezione iniziale di riferimento dell'oggetto chain c.\n",
  StyleBox["ChainCode[c]\n",
    FontWeight->"Bold"],
  "Codice dell'oggetto chain c."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[StartDirection,ChainCode]

Origin[c_Chain] := c[[1]]

StartDirection[c_Chain] := c[[2]]

ChainCode[c_Chain] := c[[3]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["FourChainQ[x]  EightChainQ[x]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se x e una \
4-/8-catena.",
    FontFamily->"Courier"],
  StyleBox["\nSimpleChainQ[x]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se x e' una catena \
semplice.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["FourChainQ",
    FontFamily->"Courier"],
  ",",
  StyleBox["EightChainQ",
    FontFamily->"Courier"],
  ",",
  StyleBox["SimpleChainQ",
    FontFamily->"Courier"],
  "]\n\nFourChainQ[x_] := \n  MatchQ[x,Chain[{_,_},v_?EvenQ /; 0 <= v <= 7,\n \
                c_List /; Length[Union[Flatten[c],Range[0,7,2]]] == 4]]\n\n\
EightChainQ[x_] := \n  MatchQ[x,Chain[{_,_},v_Integer /; 0 <= v <= 7,\n       \
          c_List /; Length[Union[Flatten[c],Range[0,7]]] == 8]]\n\n\
SimpleChainQ[x_] := And[EightChainQ[x],Depth[ChainCode[x]] == 2]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["ToFourChain[r,{x,y}]  ToEightChain[r,{x,y}]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto chain corrispondente alla componente 4-/8-connessa \
dell'oggetto raster r contenente il pixel di coordinate {x,y}. Vale Null se \
tale componente e' vuota. ",
    FontFamily->"Courier"],
  StyleBox["\nToRaster[c]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto raster corrispondente all'oggetto chain c.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["ToFourChain",
    FontFamily->"Courier"],
  ",",
  StyleBox["ToEightChain",
    FontFamily->"Courier"],
  ",",
  StyleBox["ToRaster",
    FontFamily->"Courier"],
  "]\n\nToFourChain[r_Raster,x_] := Null\n\nToEightChain[r_Raster,x_] := Null\
\n\nToRaster[c_Chain] := \n  \
Module[{makecoord,coord,c1,y,w,t,x1,x2,y1,y2,rst},\n    \
makecoord[x_,v_,code_] :=\n      If[Not[EmptyQ[code]],\n         Switch[c1 = \
code[[1]],\n           _Integer,\n             w = Mod[v + c1,8]; y = x + \
ChainSteps[[w + 1]];\n             AppendTo[coord,y]; \
makecoord[y,w,Rest[code]],\n           _List,makecoord[x,v,c1]; \
makecoord[x,v,Rest[code]]]];\n    coord = {Origin[c]};\n    \
makecoord[Origin[c],StartDirection[c],ChainCode[c]];\n    t = Thread[coord]; \
x1 = Min[t[[1]]]; x2 = Max[t[[1]]];\n                       y1 = Min[t[[2]]]; \
y2 = Max[t[[2]]];\n    rst = Raster[{x1,y1},Table[0,{x2 - x1 + 1},{y2 - y1 + \
1}]];\n    Scan[If[GetPixel[rst,#] == 0,rst = SetPixel[rst,#,1]]&,coord]; \
rst]\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["TranslateChain[c,v]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto chain ottenuto traslando r mediante il vettore v.",
    FontFamily->"Courier"],
  StyleBox["\nRotateChain[c,CCW]  RotateChain[c,CW]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto chain ottenuto ruotando r di 90\[Degree] in senso \
antiorario/orario.",
    FontFamily->"Courier"],
  StyleBox["\nReflectChain[c,X]  ReflectChain[c,X]  ReflectChain[c,XY]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Oggetto chain ottenuto riflettendo r nella direzione dell'asse \
X/Y/entrambi.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[TranslateChain,",
  StyleBox["RotateChain,FeflectChain",
    FontFamily->"Courier"],
  "]\n\nTranslateChain[c_Chain,v_] := \n  Chain[Origin[c] + \
v,StartDirection[c],ChainCode[c]]\n\nRotateChain[c_Chain,CCW] := \n  \
Chain[Origin[c],Mod[StartDirection[c] + 2,8],ChainCode[c]]\n\n\
RotateChain[c_Chain,CW] := \n  Chain[Origin[c],Mod[StartDirection[c] - \
2,8],ChainCode[c]]\n\nReflectChain[c_Chain,X] := \n  Chain[Origin[c],Mod[4 - \
StartDirection[c],8],Mod[- ChainCode[c],8]]  \n\nReflectChain[c_Chain,Y] := \n\
  Chain[Origin[c],Mod[- StartDirection[c],8],Mod[- ChainCode[c],8]]  \n\n\
ReflectChain[c_Chain,XY] := \n  Chain[Origin[c],Mod[4 + \
StartDirection[c],8],ChainCode[c]]  \n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["SimplePathQ[c]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se l'oggetto chain c \
rappresenta un arco semplice.\n",
    FontFamily->"Courier"],
  StyleBox["SimpleLoopQ[c]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Espressione booleana che vale vero se e solo se l'oggetto chain c \
rappresenta un cappio semplice.",
    FontFamily->"Courier"]
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell[TextData[{
  "ClearAll[",
  StyleBox["SimplePathQ",
    FontFamily->"Courier"],
  ",",
  StyleBox["SimplePathQ",
    FontFamily->"Courier"],
  "]",
  "\n\n",
  StyleBox["SimplePathQ",
    FontFamily->"Courier"],
  "[",
  "c_Chain",
  ",x_] := Null\n\n",
  StyleBox["SimpleLoopQ",
    FontFamily->"Courier"],
  "[",
  "c_Chain",
  ",x_] := Null\n"
}], "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{1, Automatic}, {Automatic, 2}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 355, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2075, 63, 379, 9, 80, "Text"],
Cell[2457, 74, 1024, 25, 305, "Input",
  InitializationCell->True],
Cell[3484, 101, 361, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[3848, 115, 533, 12, 110, "Text"],
Cell[4384, 129, 533, 16, 188, "Input",
  InitializationCell->True],
Cell[4920, 147, 967, 25, 245, "Text"],
Cell[5890, 174, 617, 24, 292, "Input",
  InitializationCell->True],
Cell[6510, 200, 379, 10, 65, "Text"],
Cell[6892, 212, 344, 15, 175, "Input",
  InitializationCell->True],
Cell[7239, 229, 771, 18, 140, "Text"],
Cell[8013, 249, 752, 21, 253, "Input",
  InitializationCell->True],
Cell[8768, 272, 813, 21, 125, "Text"],
Cell[9584, 295, 560, 21, 253, "Input",
  InitializationCell->True],
Cell[10147, 318, 665, 19, 110, "Text"],
Cell[10815, 339, 1201, 22, 305, "Input",
  InitializationCell->True],
Cell[12019, 363, 755, 17, 125, "Text"],
Cell[12777, 382, 767, 14, 201, "Input",
  InitializationCell->True],
Cell[13547, 398, 1140, 26, 200, "Text"],
Cell[14690, 426, 615, 12, 162, "Input",
  InitializationCell->True],
Cell[15308, 440, 505, 14, 80, "Text"],
Cell[15816, 456, 338, 10, 84, "Input",
  InitializationCell->True],
Cell[16157, 468, 630, 16, 110, "Text"],
Cell[16790, 486, 460, 16, 84, "Input",
  InitializationCell->True],
Cell[17253, 504, 331, 9, 50, "Text"],
Cell[17587, 515, 465, 17, 110, "Input",
  InitializationCell->True],
Cell[18055, 534, 623, 16, 110, "Text"],
Cell[18681, 552, 1565, 36, 396, "Input",
  InitializationCell->True],
Cell[20249, 590, 415, 10, 65, "Text"],
Cell[20667, 602, 1433, 27, 370, "Input",
  InitializationCell->True],
Cell[22103, 631, 651, 16, 110, "Text"],
Cell[22757, 649, 3822, 61, 877, "Input",
  InitializationCell->True],
Cell[26582, 712, 360, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[26945, 726, 464, 11, 95, "Text"],
Cell[27412, 739, 811, 24, 253, "Input",
  InitializationCell->True],
Cell[28226, 765, 437, 13, 110, "Text"],
Cell[28666, 780, 180, 10, 110, "Input",
  InitializationCell->True],
Cell[28849, 792, 554, 16, 95, "Text"],
Cell[29406, 810, 734, 19, 162, "Input",
  InitializationCell->True],
Cell[30143, 831, 634, 16, 110, "Text"],
Cell[30780, 849, 1187, 27, 292, "Input",
  InitializationCell->True],
Cell[31970, 878, 804, 21, 125, "Text"],
Cell[32777, 901, 868, 17, 266, "Input",
  InitializationCell->True],
Cell[33648, 920, 589, 16, 110, "Text"],
Cell[34240, 938, 505, 23, 84, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

