(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     50119,       1421]*)
(*NotebookOutlinePosition[     75942,       2365]*)
(*  CellTagsIndexPosition[     75898,       2361]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Strutture", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["Point[{x,y(,z)}]",
    FontWeight->"Bold"],
  "\nRappresenta il punto di coordinate {x,y(,z)}.\n",
  StyleBox["Line[{{x1,y1(,z1)},{x2,y2(,z2)}}]",
    FontWeight->"Bold"],
  "\nRappresenta il segmento di estremi {x1,y1(,z1)} e {x2,y2(,z2)}.\n",
  StyleBox["Polygon[{{x1,y1(,z1)},...,{xn,yn(,zn)}}]",
    FontWeight->"Bold"],
  "\nRappresenta il poligono di vertici {x1,y1(,z1)},...,{xn,yn(,zn)},\n\
ordinati seguendo l'orientazione positiva indotta sul bordo da quella del \
poligono."
}], "Subsubtitle",
  PageWidth->WindowWidth,
  CellFrame->True,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{1246, Inherited},
  FontSize->12,
  FontWeight->"Plain",
  Background->GrayLevel[0.849989],
  FontVariations->{"CompatibilityType"->0}],

Cell[TextData[{
  StyleBox["StructureQ[x]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se x e' una struttura.\n",
  StyleBox["StructureExpand[str]",
    FontWeight->"Bold"],
  "\nEspansione della struttura str in termini di Point, Line e Polygon."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[StructureQ,StructureExpand]
SetAttributes[StructureExpand,Listable]

StructureQ[_] := False

StructureExpand[x_] := x
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Graphics[str]  Graphics3D[str]",
    FontWeight->"Bold"],
  "\nOggetto grafico 2D (3D) generato dalla struttura (o lista di strutture) \
str, visualizzabile mediante la funzione di sistema Show."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
Unprotect[Graphics,Graphics3D];

Graphics[str_,opts___] /; Not[FreeQ[str,_?StructureQ]]:=
  Graphics[StructureExpand[str],opts]

Graphics3D[str_,opts___] /; Not[FreeQ[str,_?StructureQ]]:=
  Graphics3D[StructureExpand[str],opts]

Protect[Graphics,Graphics3D];
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["Export[str,filename,\"OBJ\"]\n",
    FontWeight->"Bold"],
  "Esporta la struttura (o lista di strutture) nel file specificato in \
formato .obj."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
Unprotect[Export];

Export[str_,filename_,\"OBJ\"] :=
  Module[{s = MakeIndexed[StructureExpand[str]]},
    Module[{v = Map[Prepend[#,\"v\"]&,Chop[s[[2]]] + 0.],
            l = Cases[s[[1]],Line[x_] :> Prepend[x,\"l\"],Infinity],
            p = Cases[s[[1]],Polygon[x_] :> Prepend[x,\"f\"],Infinity],f},
      f = OpenWrite[StringJoin[filename,\".obj\"]];
      WriteString[f,
        TableForm[v,TableSpacing->{0,1}],\"\\n\",
        TableForm[l,TableSpacing->{0,1}],\"\\n\",
        TableForm[p,TableSpacing->{0,1}],\"\\n\",
        FromCharacterCode[20]];
      Close[f];]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell["Strutture statiche", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["LineArray[{v1,...,v2n}]",
    FontWeight->"Bold"],
  "\nInsieme di segmenti di vertici {v1,v2},{v3,v4},...",
  StyleBox["\nLineStrip[{v1,...,vn}]",
    FontWeight->"Bold"],
  "\nPoligonale di vertici v1,...vn."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[LineArray,LineStrip]

StructureQ[_LineArray] := True
StructureExpand[LineArray[l_List]] := Map[Line,Partition[l,2]]

StructureQ[_LineStrip] := True
StructureExpand[LineStrip[l_List]] := Map[Line,Partition[l,2,1]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["TriangleArray[{v1,v2,v3,...,v3n}]",
    FontWeight->"Bold"],
  "\nLista dei triangoli di vertici {v1,v2,v3},{v4,v5,v6},...\n",
  StyleBox["TriangleStrip[{v1,v2,v3,...,vn}]\n",
    FontWeight->"Bold"],
  "Lista dei triangoli di vertici {v1,v2,v3},{v2,v3,v4},{v3,v4,v5},...\n",
  StyleBox["TriangleStrip[{c4,...,cn},{v1,v2,v3,...,vn}]\n",
    FontWeight->"Bold"],
  "Lista di triangoli definita ricorsivamente come segue: il primo ha vertici \
{v1,v2,v3}, ogni altro triangolo si ottiene dal precedente inserendo il \
vertice vi al posto del primo/secondo vertice ci e' 1/2.\n",
  StyleBox["TriangleFan[{v1,v2,v3,...,vn}]\n",
    FontWeight->"Bold"],
  "Lista dei triangoli di vertici {v1,v2,v3},{v1,v3,v4},{v1,v4,v5},..."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[TriangleArray,TriangleStrip,TriangleFan]

StructureQ[_TriangleArray] := True
StructureExpand[TriangleArray[l_List]] := Map[Polygon,Partition[l,3]]

StructureQ[_TriangleStrip] := True
StructureExpand[TriangleStrip[l_List]] :=
  Table[If[OddQ[i],Polygon[l[[{i,i+2,i+1}]]],
                   Polygon[l[[{i,i+1,i+2}]]]],{i,Length[l]-2}]
                   
StructureExpand[TriangleStrip[c_List,l_List]] := Null

StructureQ[_TriangleFan] := True
StructureExpand[TriangleFan[l_List]] :=
  Map[Polygon[{l[[1]],#1[[1]],#1[[2]]}]&,Partition[Rest[l],2,1]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["QuadArray[{v1,v2,v3,v4,...,v4n}]",
    FontWeight->"Bold"],
  "\nLista dei quadrilateri di vertici {v1,v2,v3,v4},{v5,v6,v7,v8},...\n",
  StyleBox["QuadStrip[{v1,v2,v3,v4,...,v2n}]\n",
    FontWeight->"Bold"],
  "Lista dei quadrilateri di vertici {v1,v2,v3,v4}, {v3,v4,v5,v6},...\n",
  StyleBox["QuadPatch[n,{v11,...,v1m,...,vn1,...,vnm}]\n",
    FontWeight->"Bold"],
  "Matrice di quadrilateri adiacenti generati dalla la matrice n x m di \
vertici che si ottiene raggruppando n ad n gli elementi della lista \
{v11,...,v1m,...,vn1,...,vnm}."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[QuadArray,QuadStrip,QuadPatch]

StructureQ[_QuadArray] := True
StructureExpand[QuadArray[l_List]] := Map[Polygon,Partition[l,4]]

StructureQ[_QuadStrip] := True
StructureExpand[QuadStrip[l_List]] :=
  Map[Polygon[#1[[{1,3,4,2}]]]&,Partition[l,4,2]]

StructureQ[_QuadPatch] := True
StructureExpand[QuadPatch[n_,l_List]] :=
  Map[Polygon[Join[#1[[1]],Reverse[#1[[2]]]]]&,
      Flatten[Partition[Partition[l,n],{2,2},{1,1}],1]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellFrame->False,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["Indexed[list,v]\n",
    FontWeight->"Bold"],
  "Struttura indicizzata dove slist e' una lista di strutture statiche (o \
Point, Line, Polygon) con i vertici rappresentati nella forma V[i] e v e' una \
matrice di coordinate di vertici. V[i] rappresenta il vertice di coordinate \
v[[i]].",
  StyleBox["\nMakeIndexed[list]\n",
    FontWeight->"Bold"],
  "Struttura indicizzata generata dalla lista list di strutture statiche non \
indicizzate (o Point, Line, Polygon).\n",
  StyleBox["IndexExpand[indstr]",
    FontWeight->"Bold"],
  "\nLista di strutture statiche non indicizzate corrispondente alla \
struttura indicizzata indstr."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[Indexed,IndexExpand,MakeIndexed]

StructureQ[_Indexed]\[NonBreakingSpace]:= True
StructureExpand[Indexed[l_,v_]] :=
  IndexExpand[Indexed[StructureExpand[l],v]]
  
IndexExpand[Indexed[l_,v_]] := Block[{V = v[[#]]&},l]

MakeIndexed[l_List?(FreeQ[#,Indexed]&)] :=
  Module[{ll = Chop[l],s,v},
    s = Cases[ll,_?StructureQ|_Point|_Line|_Polygon,Infinity];
    v = Union[Flatten[s /. {s_[t___,x_]?StructureQ :> x,
                            (Polygon|Line|Point)[x_] :> x},-1]];
    Indexed[s /. Dispatch[Table[v[[i]] -> V[i],{i,Length[v]}]],v]]
\
\>", "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["MatrixTransform[str,m]",
    FontWeight->"Bold"],
  "\nTrasformazione della struttura (o lista di strutture) str mediante \n\
l'applicazione lineare x -> x . m.\n",
  StyleBox["MatrixTransform[str,m,v]",
    FontWeight->"Bold"],
  "\nTrasformazione della struttura (o lista di strutture) str mediante \n\
l'applicazione affine x -> x . m + v.\n",
  StyleBox["FunctionalTransform[str,f]",
    FontWeight->"Bold"],
  "\nTrasformazione della struttura (o lista di strutture) str mediante \
l'applicazione f (che agisce sui vertici)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[MatrixTransform,FunctionalTransform]

MatrixTransform[str_,m_,v_:0] := 
  str /. {s_[t___,x_]?StructureQ :> s[t,Map[(# + v)&,x . m]],
          (p:Line|Polygon)[x_] :> p[Map[(# + v)&,x . m]],
          Point[x_] :> Point[x . m + v]}

FunctionalTransform[str_,f_] := 
  str /. {s_[t___,x_]?StructureQ :> s[t,Map[f,x]],
          (p:Line|Polygon)[x_] :> p[Map[f,x]],
          Point[x_] :> Point[f[x]]}
\
\>", "Input",
  PageWidth->WindowWidth,
  CellFrame->False,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell["Strutture dinamiche", "Subsubtitle",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  Evaluatable->False,
  CellSize->{66, Inherited},
  AspectRatioFixed->True,
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  StyleBox["DCEList[flist,elist,vlist,coord]\n",
    FontWeight->"Bold"],
  "Struttura DCEList (doubly-connected edge list) dove flist, elist e vlist \
sono le liste dei legami delle facce, degli spigoli e dei vertici, e coord e' \
la lista delle coordinate dei vertici. Le liste dei legami sono definite come \
segue:\nflist[[n]] = {out,in1,in2,...} (uno spigolo del bordo esterno (0 per \
la faccia illimitata) e uno spigolo di ogni eventuale componente del bordo \
interno) della n-esima faccia;\nelist[[n]] = {face,comp,prev,next,ori} \
(faccia bordata, componente del bordo, spigoli precedente e successivo, e \
vertice origine relativi all'n-esimo spigolo);\nvlist[[n]] = {edge} (uno \
spigolo uscente dall'n-esimo vertice).\nGli spigoli (2i - 1)-esimo e 2i-esimo \
sono gemelli, cioe' coincidono a meno dell'orientazione. Facce, spigoli e \
vertici non utilizzati sono rappresentati da Null (le coordinate di un tale \
vertice sono poste uguali a {0,0}).\n",
  StyleBox["DCEList[]",
    FontWeight->"Bold"],
  "\nStruttura DCEList vuota."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[DCEList,Labels,Faces]
Options[DCEList] = {Labels -> True,Faces -> False};

StructureQ[_DCEList] := True
StructureExpand[dce_DCEList] :=
  Module[{f = BoundedFaces[dce],e = Edges[dce],v = Vertices[dce],
          ee,pls,lns,pts,p,n,fi = 1,ei = 1,vi = 1},
    ee = e[[Range[1,Length[e],2]]];
    pls = N[FaceToPolygon[dce,f]];
    lns = N[EdgeToLine[dce,ee]];
    pts = N[VertexToPoint[dce,v]];
    {If[Not[SameQ[Faces /. Options[DCEList],True]],Nothing,
        {GrayLevel[.5],pls}],lns,pts,
     If[Not[SameQ[Labels /. Options[DCEList],True]],Nothing,
        {pls /. Polygon[x_] :>
                  (p = Position[Rest[x],First[x]];
                   p = If[EmptyQ[p],Length[x],p[[1,1]]];
                   Text[f[[fi++]],Apply[Plus,Take[x,p]]/p]),
         lns /. Line[{x1_,x2_}] :>
                  (p = (x1 + x2) / 2;
                   n = Reverse[Sign[x2 - x1]] {-1.7,1.2};
                   {Text[e[[ei++]],p,- n],Text[e[[ei++]],p,n]}),
         pts /. Point[x_] :> Text[v[[vi++]],x,{-1.7,-1.2}]}]}]

DCEList[] := DCEList[{{0}},{},{},{}];

DCEList::err = \"Structure error.\";
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["FaceList[dce]\n",
    FontWeight->"Bold"],
  "Lista dei legami delle facce della struttura dce.\n",
  StyleBox["EdgeList[dce]\n",
    FontWeight->"Bold"],
  "Lista dei legami degli spigoli della struttura dce.\n",
  StyleBox["VertexList[dce]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Lista dei legami dei vertici della struttura dce.\n",
  StyleBox["CoordList[dce]\n",
    FontWeight->"Bold"],
  "Lista delle coordinate dei vertici della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FaceList,EdgeList,VertexList,CoordList]

FaceList[dce_DCEList] := dce[[1]]

EdgeList[dce_DCEList] := dce[[2]]

VertexList[dce_DCEList] := dce[[3]]

CoordList[dce_DCEList] := dce[[4]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["FaceQ[dce,n]  EdgeQ[dce,n]  VertexQ[dce,n]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se n e' un indice di \
faccia/spigolo/vertice (utilizzato) della struttura dce.\n",
  StyleBox["Faces[dce]  Edges[dce]  Vertices[dce]",
    FontWeight->"Bold"],
  "\nLista degli indici di facce/spigoli/vertici (utilizzati) della struttura \
dce.",
  StyleBox["\nNormalize[dce]\n",
    FontWeight->"Bold"],
  "Struttura DCEList normalizzata ottenuta eliminando dalla struttura dce  \
gli elementi non utilizzati e rinumerando quelli utilizzati."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FaceQ,EdgeQ,VertexQ,Faces,Edges,Vertices,Normalize]

FaceQ[dce_DCEList,f_Integer?Positive] :=
  And[f <= Length[FaceList[dce]],Not[NullQ[FaceList[dce][[f]]]]]

EdgeQ[dce_DCEList,e_Integer?Positive] :=
  And[e <= Length[EdgeList[dce]],Not[NullQ[EdgeList[dce][[e]]]]]

VertexQ[dce_DCEList,v_Integer?Positive] :=
  And[v <= Length[VertexList[dce]],Not[NullQ[VertexList[dce][[v]]]]]

Faces[dce_DCEList] := Flatten[Position[FaceList[dce],_List]]

Edges[dce_DCEList] := Flatten[Position[EdgeList[dce],_List]]

Vertices[dce_DCEList] := Flatten[Position[VertexList[dce],_List]]

Normalize[dce_DCEList] := 
  Module[{ff = Faces[dce],ee = Edges[dce],vv = Vertices[dce],
          ft,et,vt,fi = 1,ei = 1,vi = 1},
    ft = Map[If[NullQ[#],0,fi++]&,FaceList[dce]];
    et = Map[If[NullQ[#],0,ei++]&,EdgeList[dce]];
    vt = Map[If[NullQ[#],0,vi++]&,VertexList[dce]];
    DCEList[FaceList[dce][[ff]] /. {0 :> 0,e_Integer :> et[[e]]},
            EdgeList[dce][[ee]] /. {f_Integer,c_,p_,n_,v_} :> 
                                   {ft[[f]],c,et[[p]],et[[n]],vt[[v]]},
            VertexList[dce][[vv]] /. e_Integer :> et[[e]],
            CoordList[dce][[vv]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["FaceOuterEdge[dce,f]",
    FontWeight->"Bold"],
  "\nPrimo spigolo del bordo esterno della faccia f della struttura dce (vale \
0 se tale componente non esiste, cioe' la faccia e' illimitata).\n",
  StyleBox["FaceInnerEdges[dce,f]",
    FontWeight->"Bold"],
  "\nLista dei primi spigoli delle componenti del bordo interno della faccia \
f della struttura dce (vale {} tali componenti non esistono, cioe' la faccia \
e' semplicemente connessa).\n",
  StyleBox["FaceEdges[dce,f]\n",
    FontWeight->"Bold"],
  "Lista dei primi spigoli di tutte le componenti di bordo della faccia f \
della struttura dce.",
  StyleBox["\nFaceOuterBoundary[dce,f]  FaceOuterVertices[dce,f]",
    FontWeight->"Bold"],
  "\nLista degli spigoli/vertici del bordo esterno della faccia f della \
struttura dce (vale {} se tale componente non esiste).\n",
  StyleBox["FaceInnerBoundaries[dce,f]  FaceInnerVertices[dce,f]",
    FontWeight->"Bold"],
  "\nLista costituita dalle liste degli spigoli/vertici delle componenti del \
bordo interno della faccia f della struttura dce (vale {} se tali componenti \
non esistono).\n",
  StyleBox["FaceBoundaries[dce,f]  FaceVertices[dce,f]\n",
    FontWeight->"Bold"],
  "Lista costituita dalle liste degli spigoli/vertici di tutte le componenti \
del bordo della faccia f della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FaceOuterEdge,FaceInnerEdges,FaceEdges,
         FaceOuterBoundary,FaceInnerBoundaries,FaceBoundaries,
         FaceOuterVertices,FaceInnerVertices,FaceVertices]
  
FaceOuterEdge[dce_DCEList,f_] := First[FaceList[dce][[f]]]

FaceInnerEdges[dce_DCEList,f_] := Rest[FaceList[dce][[f]]]

FaceEdges[dce_DCEList,f_] := FaceList[dce][[f]]

FaceOuterBoundary[dce_DCEList,f_] :=
  Module[{e = FaceOuterEdge[dce,f]},
    If[SameQ[e,0],{},EdgeLoop[dce,e]]]

FaceInnerBoundaries[dce_DCEList,f_] :=
  Map[EdgeLoop[dce,#]&,FaceInnerEdges[dce,f]]

FaceBoundaries[dce_DCEList,f_] := 
  Join[{FaceOuterBoundary[dce,f]},FaceInnerBoundaries[dce,f]]

FaceInnerVertices[dce_DCEList,f_] :=
  Map[EdgeOrigin[dce,#]&,FaceInnerBoundaries[dce,f],{2}]

FaceOuterVertices[dce_DCEList,f_] :=
  Map[EdgeOrigin[dce,#]&,FaceOuterBoundary[dce,f]]

FaceVertices[dce_DCEList,f_] :=
  Join[{FaceOuterVertices[dce,f]},FaceInnerVertices[dce,f]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["BoundedQ[dce,f]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se la faccia f della struttura dce e' \
limitata.",
  StyleBox["\nSimplyConnectedQ[dce,f]\n",
    FontWeight->"Bold"],
  "Espressione booleana vera se e solo se la faccia f della struttura dce e' \
semplicemente connessa.",
  StyleBox["\nBoundedFaces[dce]\n",
    FontWeight->"Bold"],
  "Lista delle facce limitate della struttura dce.\n",
  StyleBox["UnboundedFace[dce]\n",
    FontWeight->"Bold"],
  "Faccia illimitata della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[BoundedQ,SimplyConnectedQ,UnboundendFace,BoundedFaces]

BoundedQ[dce_DCEList,f_] := FaceOuterEdge[dce,f] > 0

SimplyConnectedQ[dce_DCEList,f_] := EmptyQ[FaceInnerEdges[dce,f]]

BoundedFaces[dce_DCEList] := Select[Faces[dce],BoundedQ[dce,#]&]
  
UnboundedFace[dce_DCEList] := 
  Select[Faces[dce],Not[BoundedQ[dce,#]]&,1][[1]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["EdgeFace[dce,e]  EdgeComp[dce,e]",
    FontWeight->"Bold"],
  "\nFaccia bordata dallo spigolo e della struttura dce, e componente del \
bordo della faccia a cui tale spigolo appartiene.\n",
  StyleBox["PrevEdge[dce,e]  NextEdge[dce,e]",
    FontWeight->"Bold"],
  "\nSpigoli precedente/successivo allo spigolo e della struttura dce lungo \
il bordo della faccia da esso bordata.\n",
  StyleBox["TwinEdge[dce,e]",
    FontWeight->"Bold"],
  "\nSpigolo gemello dell spigolo e.\n",
  StyleBox["EdgeOrigin[dce,e]  EdgeEnd[dce,e]",
    FontWeight->"Bold"],
  "\nVertice iniziale/finale dello spigolo e della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[EdgeFace,EdgeComp,PrevEdge,NextEdge,TwinEdge,
         EdgeOrigin,EdgeEnd,FACE,COMP,PREV,NEXT,ORIG]

FACE = 1; COMP = 2; PREV = 3; NEXT = 4; ORIG = 5;

EdgeFace[dce_DCEList,e_] := EdgeList[dce][[e,FACE]]

EdgeComp[dce_DCEList,e_] := EdgeList[dce][[e,COMP]]

PrevEdge[dce_DCEList,e_] := EdgeList[dce][[e,PREV]]

NextEdge[dce_DCEList,e_] := EdgeList[dce][[e,NEXT]]

TwinEdge[dce_:Null,e_] := If[OddQ[e],e + 1,e - 1]

EdgeOrigin[dce_DCEList,e_] := EdgeList[dce][[e,ORIG]]

EdgeEnd[dce_DCEList,e_] := EdgeOrigin[dce,TwinEdge[e]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["EdgePath[dce,e1,e2]\n",
    FontWeight->"Bold"],
  "Lista di spigoli consecutivi della struttura dce che formano un cammino \
dallo spigolo e1 fino allo spigolo e2.\n",
  StyleBox["EdgeLoop[dce,e]",
    FontWeight->"Bold"],
  "\nLista di spigoli consecutivi della struttura dce che formano un cappio a \
partire dallo spigolo e.\n",
  StyleBox["EdgeFan[dce,e1,e2]",
    FontWeight->"Bold"],
  "\nLista di spigoli uscenti dall'origine comune agli spigoli e1 e e2 della \
struttura dce, ordinati in senso antiorario dallo spigolo e1 allo spigolo e2.\
\n",
  StyleBox["EdgeFan[dce,e]\n",
    FontWeight->"Bold"],
  "Lista di tutti gli spigoli della struttura dce aventi la stessa origine di \
e, ordinati in senso antirario a partire da e."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[EdgePath,EdgeLoop,EdgeFan]

EdgePath[dce_DCEList,e1_,e2_] :=
  If[SameQ[e1,e2],{e1},Join[{e1},EdgePath[dce,NextEdge[dce,e1],e2]]]

EdgeLoop[dce_DCEList,e_] := EdgePath[dce,e,PrevEdge[dce,e]]

EdgeFan[dce_DCEList,e1_,e2_] := 
  If[SameQ[e1,e2],{e1},
     Join[{e1},EdgeFan[dce,TwinEdge[PrevEdge[dce,e1]],e2]]]

EdgeFan[dce_DCEList,e_] := EdgeFan[dce,e,NextEdge[dce,TwinEdge[e]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["VertexEdge[dce,v]",
    FontWeight->"Bold"],
  "\nPrimo spigolo uscente dal vertice v della struttura dce.\n",
  StyleBox["VertexEdgeList[dce,v]",
    FontWeight->"Bold"],
  "\nSpigoli uscenti dal vertice v della struttura dce, ordinati in senso \
antiorario.\n",
  StyleBox["VertexFaceList[dce,v]",
    FontWeight->"Bold"],
  "\nFacce uscenti dal vertice v della struttura dce, ordinate in senso \
antiorario.\n",
  StyleBox["VertexCoord[dce,v]",
    FontWeight->"Bold"],
  "\nCoordinate del vertice v della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[VertexEdge,VertexEdgeList,VertexFaceList,VertexCoord]
SetAttributes[VertexCoord,Listable]

VertexEdge[dce_DCEList,v_] := VertexList[dce][[v,1]]

VertexEdgeList[dce_DCEList,v_] := EdgeFan[dce,VertexEdge[dce,v]]

VertexFaceList[dce_DCEList,v_] :=
  Map[EdgeFace[dce,#]&,VertexEdgeList[dce,v]]

VertexCoord[dce_DCEList,v_] := CoordList[dce][[v]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["InsertEdge[dce,f,p1,p2]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta inserendo all'interno della faccia f della \
struttura dce una coppia di spigoli gemelli tra i punti p1 e p2.\n",
  StyleBox["InsertEdge[dce,e1,e2,p]\n",
    FontWeight->"Bold"],
  "Struttura DCEList ottenuta inserendo tra gli spigoli consecutivi e1 \
(entrante in v) e e2 (uscente da v) della struttura dce una coppia di spigoli \
gemelli congiungenti il vertice v con il punto p.\n",
  StyleBox["InsertEdge[dce,e1,e2,e3,e4]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta inserendo tra gli spigoli consecutivi e1 \
(entrante in v) e e2 (uscente da v) e tra gli spigoli consecutivi e3 \
(entrante in w) e e4 (uscente da w) della struttura dce una coppia di spigoli \
gemelli congiungenti i vertici v e w.\n",
  StyleBox["DeleteEdge[dce,e]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta eliminando dalla struttura dce lo spigolo e \
(e il suo gemello)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[InsertEdge,DeleteEdge]

InsertEdge[dce_DCEList,f_Integer,p1_List,p2_List] := 
  If[Not[FaceQ[dce,f]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          newe,newt,newv1,newv2},
    newe = Length[elist] + 1; 
    newt = Length[elist] + 2;
    elist = Join[elist,{{},{}}];
    newv1 = Length[vlist] + 1;
    newv2 = Length[vlist] + 2;
    vlist = Join[vlist,{{},{}}];
    coord = Join[coord,{{},{}}];
    flist[[f]] = Append[flist[[f]],newe];
    elist[[newe]] = {f,Length[flist[[f]]],newt,newt,newv1};
    elist[[newt]] = {f,Length[flist[[f]]],newe,newe,newv2};
    vlist[[newv1]] = {newe};
    vlist[[newv2]] = {newt};
    coord[[newv1]] = p1;
    coord[[newv2]] = p2;
    DCEList[flist,elist,vlist,coord]]]

InsertEdge[dce_DCEList,e1_Integer,e2_Integer,p_List] := 
  If[Not[And[EdgeQ[dce,e1],EdgeQ[dce,e2],
             SameQ[NextEdge[dce,e1],e2]]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          newe,newt,newv,f,c,v},
    newe = Length[elist] + 1; 
    newt = Length[elist] + 2;
    elist = Join[elist,{{},{}}];
    newv = Length[vlist] + 1;
    vlist = Append[vlist,{}];
    coord = Append[coord,{}];
    f = elist[[e1,FACE]];
    c = elist[[e1,COMP]];
    v = elist[[e2,ORIG]];
    elist[[e1,NEXT]] = newe;
    elist[[e2,PREV]] = newt;
    elist[[newe]] = {f,c,e1,newt,v};
    elist[[newt]] = {f,c,newe,e2,newv};
    vlist[[newv]] = {newt};
    coord[[newv]] = p;
    DCEList[flist,elist,vlist,coord]]]

InsertEdge[dce_DCEList,e1_,e2_,e3_,e4_] := 
  If[Not[And[EdgeQ[dce,e1],EdgeQ[dce,e2],EdgeQ[dce,e3],EdgeQ[dce,e4],
             SameQ[NextEdge[dce,e1],e2],SameQ[NextEdge[dce,e3],e4],
             SameQ[EdgeFace[dce,e1],EdgeFace[dce,e3]],
             Length[Union[{e1,e2,e3,e4}]] == 4]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          newe,newt,newf,f,c1,c2,c,ve,vt,l,pol,crit,l1,l2,path,i},
    newe = Length[elist] + 1;
    newt = Length[elist] + 2;
    elist = Join[elist,{{},{}}];
    f = elist[[e1,FACE]];
    c1 = elist[[e1,COMP]];
    c2 = elist[[e4,COMP]];
    ve = elist[[e2,ORIG]];
    vt = elist[[e4,ORIG]];
    elist[[e1,NEXT]] = newe;
    elist[[e2,PREV]] = newt;
    elist[[e3,NEXT]] = newt;
    elist[[e4,PREV]] = newe;
    If[SameQ[c1,c2],
      (newf = Length[flist] + 1;
       flist = Append[flist,{}];
       l = Delete[flist[[f]],Union[{{1},{c1}}]];
       pol = coord[[Append[elist[[EdgePath[dce,e4,e1],ORIG]],ve]]];
       crit = SameQ[PointPolygonClass[coord[[elist[[#,ORIG]]]],pol],1]&;
       l1 = Select[l,crit];
       l2 = Complement[l,l1];
       If[SameQ[c1,1],
         (flist[[f]] = Join[{newe},l1];
          flist[[newf]] = Join[{newt},l2];
          elist[[newe]] = {f,1,e1,e4,ve};
          elist[[newt]] = {newf,1,e3,e2,vt};
          path = EdgePath[dce,e2,e3];
          Map[(elist[[EdgeLoop[dce,#],FACE]] = newf)&,l2]), 
         (If[SameQ[PolygonClass[pol],1],
            (flist[[f]] = Join[{flist[[f,1]],newt},l2];
             flist[[newf]] = Join[{newe},l1];
             elist[[newe]] = {newf,1,e1,e4,ve};
             elist[[newt]] = {f,2,e3,e2,vt};
             elist[[EdgePath[dce,e2,e3],COMP]] = 2;
             path = EdgePath[dce,e4,e1]),
            (flist[[f]] = Join[{flist[[f,1]],newe},l2];
             flist[[newf]] = Join[{newt},l1];
             elist[[newe]] = {f,2,e1,e4,ve};
             elist[[newt]] = {newf,1,e3,e2,vt};
             elist[[EdgePath[dce,e4,e1],COMP]] = 2;
             path = EdgePath[dce,e2,e3])];
          Map[(elist[[EdgeLoop[dce,#],FACE]] = newf)&,l1])];
       elist[[path,FACE]] = newf;
       elist[[path,COMP]] = 1;
       i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l1];
       i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l2]),
      (flist[[f]] = Drop[flist[[f]],{Max[c1,c2]}];
       c = Min[c1,c2];
       elist[[newe]] = {f,c,e1,e4,ve};
       elist[[newt]] = {f,c,e3,e2,vt};
       path = If[c1 < c2,EdgePath[dce,e4,e3],EdgePath[dce,e2,e1]];
       elist[[path,COMP]] = c;
       l = Rest[flist[[f]]];
       i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l])];
    DCEList[flist,elist,vlist,coord]]]

DeleteEdge[dce_DCEList,e_] := 
  If[Not[EdgeQ[dce,e]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          t = TwinEdge[e],fe,ce,pe,ne,ve,ft,ct,pt,nt,vt,pol,n,l,i},
    fe = elist[[e,FACE]]; ft = elist[[t,FACE]]; 
    ce = elist[[e,COMP]]; ct = elist[[t,COMP]]; 
    pe = elist[[e,PREV]]; pt = elist[[t,PREV]]; 
    ne = elist[[e,NEXT]]; nt = elist[[t,NEXT]]; 
    ve = elist[[e,ORIG]]; vt = elist[[t,ORIG]]; 
    If[SameQ[ne,t],
       If[SameQ[nt,e],
         (flist[[fe]] = Drop[flist[[fe]],{ce}];
          vlist[[{ve,vt}]] = Null;
          coord[[{ve,vt}]] = {0,0};
          l = Rest[flist[[fe]]];
          i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l]),
         (flist[[fe,ce]] = pe;
          elist[[pe,NEXT]] = nt;
          elist[[nt,PREV]] = pe;
          vlist[[ve]] = {nt}; 
          vlist[[vt]] = Null;
          coord[[vt]] = Null)],
       If[SameQ[nt,e],
         (flist[[fe,ce]] = ne;
          elist[[pt,NEXT]] = ne;
          elist[[ne,PREV]] = pt;
          vlist[[vt]] = {ne}; 
          vlist[[ve]] = Null;
          coord[[ve]] = Null),
         (If[SameQ[fe,ft],
            (pol = coord[[elist[[EdgePath[dce,ne,t],ORIG]]]];
             n = Length[flist[[fe]]] + 1;
             If[SameQ[PolygonClass[pol],1],
               (flist[[fe,ce]] = ne;
                flist[[fe]] = Append[flist[[fe]],nt];
                elist[[EdgePath[dce,nt,pe],COMP]] = n),
               (flist[[fe,ce]] = pe;
                flist[[fe]] = Append[flist[[fe]],pt];
                elist[[EdgePath[dce,ne,pt],COMP]] = n)]),
            (If[SameQ[ce,1],
               (flist[[ft,ct]] = pt;
                flist[[ft]] = Join[flist[[ft]],Drop[flist[[fe]],{ce}]];
                elist[[EdgePath[dce,ne,pe],FACE]] = ft;
                elist[[EdgePath[dce,ne,pe],COMP]] = ct;
                l = Rest[flist[[fe]]];
                Map[(elist[[EdgeLoop[dce,#],FACE]] = ft)&,l];
                l = Rest[flist[[ft]]];
                i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l];
                flist[[fe]] = Null),
               (flist[[fe,ce]] = pe;
                flist[[fe]] = Join[flist[[fe]],Drop[flist[[ft]],{ct}]];
                elist[[EdgePath[dce,nt,pt],FACE]] = fe;
                elist[[EdgePath[dce,nt,pt],COMP]] = ce;  
                l = Rest[flist[[ft]]];
                Map[(elist[[EdgeLoop[dce,#],FACE]] = fe)&,l];
                l = Rest[flist[[fe]]];
                i = 1;Map[(i++;elist[[EdgeLoop[dce,#],COMP]] = i)&,l];      
                flist[[ft]] = Null)])];             
          elist[[pt,NEXT]] = ne;
          elist[[ne,PREV]] = pt;
          elist[[pe,NEXT]] = nt;
          elist[[nt,PREV]] = pe;
          vlist[[ve]] = {nt};
          vlist[[vt]] = {ne})]];
    elist[[{e,t}]] = Null;
    DCEList[flist,elist,vlist,coord]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["ContractEdge[dce,e]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta dalla struttura dce contraendo lo spigolo e \
sul vertice inizale (e il suo gemello su quello finale).\n",
  StyleBox["ExpandEdge[dce,e1,e2,p]\n",
    FontWeight->"Bold"],
  "Struttura DCEList ottenuta dalla struttura dce espandendo dal vertice v, \
tra gli spigoli e1 (entrante in v) e e2 (uscente da v), una coppia spigoli \
gemelli congiungenti v con il punto p, e modificando di conseguenza gli \
spigoli entranti/uscenti compresi tra e2 e e1 (in senso antiorario). "
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[ContractEdge,ExpandEdge]

ContractEdge[dce_DCEList,e_] :=
  If[Not[EdgeQ[dce,e]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          t = TwinEdge[e],pe,ne,ve,pt,nt,vt,p},
    pe = elist[[e,PREV]]; pt = elist[[t,PREV]]; 
    ne = elist[[e,NEXT]]; nt = elist[[t,NEXT]]; 
    ve = elist[[e,ORIG]]; vt = elist[[t,ORIG]];
    p = coord[[ve]];
    Which[SameQ[ne,t],DeleteEdge[dce,e],
          SameQ[nt,e],MoveVertex[DeleteEdge[dce,e],vt,p],
          True,flist[[elist[[e,FACE]],elist[[e,COMP]]]] = ne;
               flist[[elist[[t,FACE]],elist[[t,COMP]]]] = nt;
               elist[[VertexEdgeList[dce,vt],ORIG]] = ve; 
               elist[[pe,NEXT]] = ne;
               elist[[ne,PREV]] = pe;
               elist[[pt,NEXT]] = nt;
               elist[[nt,PREV]] = pt;
               elist[[{e,t}]] = Null;
               vlist[[ve]] = {nt};
               vlist[[vt]] = Null;
               coord[[vt]] = {0,0};
               DCEList[flist,elist,vlist,coord]]]]

ExpandEdge[dce_DCEList,e1_,e2_,p_] := 
  If[Not[And[EdgeQ[dce,e1],EdgeQ[dce,e2],
             SameQ[EdgeEnd[dce,e1],EdgeOrigin[dce,e2]]]],
     Message[DCEList::err];dce,
  Module[{flist = FaceList[dce],elist = EdgeList[dce],
          vlist = VertexList[dce],coord = CoordList[dce],
          t1 = TwinEdge[e1],t2 = TwinEdge[e2],
          ne1,pe2,v,newe,newt,newv},
    ne1 = elist[[e1,NEXT]]; 
    pe2 = elist[[e2,PREV]]; 
    v = elist[[e2,ORIG]];
    If[SameQ[ne1,e2],InsertEdge[dce,e1,e2,p],
       newe = Length[elist] + 1; 
       newt = Length[elist] + 2;
       elist = Join[elist,{{},{}}];
       newv = Length[vlist] + 1;
       vlist = Append[vlist,{}];
       coord = Append[coord,{}];
       elist[[e1,NEXT]] = newe;
       elist[[ne1,PREV]] = newe;
       elist[[e2,PREV]] = newt;
       elist[[pe2,NEXT]] = newt;
       elist[[EdgeFan[dce,TwinEdge[pe2],ne1],ORIG]] = newv;
       elist[[newe]] = {elist[[e1,FACE]],elist[[e1,COMP]],e1,ne1,v};
       elist[[newt]] = {elist[[e2,FACE]],elist[[e2,COMP]],pe2,e2,newv};
       vlist[[v]] = {newe};
       vlist[[newv]] = {newt};
       coord[[newv]] = p;
       DCEList[flist,elist,vlist,coord]]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["SplitEdge[dce,e,p]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta dalla struttura dce suddividendo lo spigolo e \
(e il suo gemello) con l'inserimento di un nuovo vertice nel punto p.",
  StyleBox["\nUnsplitEdge[dce,e1,e2]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta dalla struttura dce unificando gli spigoli \
consecutivi e1 e e2 (e i loro gemelli) con l'eliminazione del vertice comune \
(che si assume di ordine 2)."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[SplitEdge,UnsplitEdge]

SplitEdge[dce_DCEList,e_,p_] := 
  If[Not[EdgeQ[dce,e]],
     Message[DCEList::err];dce,
  If[SameQ[NextEdge[dce,e],TwinEdge[e]],
     MoveVertex[InsertEdge[dce,e,TwinEdge[e],
                  VertexCoord[dce,EdgeEnd[dce,e]]],EdgeEnd[dce,e],p],
     ExpandEdge[dce,PrevEdge[dce,TwinEdge[e]],NextEdge[dce,e],p]]]
  
UnsplitEdge[dce_DCEList,e1_,e2_] := 
  If[Not[And[EdgeQ[dce,e1],EdgeQ[dce,e2],SameQ[NextEdge[e1,e2]],
             SameQ[NextEdge[dce,TwinEdge[e2]],TwinEdge[e1]]]],
     Message[DCEList::err];dce,
  ContractEdge[dce,TwinEdge[e2]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["MoveVertex[dce,v,p]",
    FontWeight->"Bold"],
  "\nStruttura DCEList ottenuta dalla struttura dce muovendo il vertice v nel \
punto p."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[MoveVertex]

MoveVertex[dce_DCEList,v_,x_] := 
  If[Not[VertexQ[dce,v]],
     Message[DCEList::err];dce,
  ReplacePart[dce,x,{4,v}]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["BoxClip[dce,{{x1,x2},{y1,y2}}]",
    FontWeight->"Bold"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Struttura DCEList ottenuta dalla struttura dce mediante effettuando il \
clipping con il rettangolo [x1,x2] x [y1,y2]."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[BoxClip]

BoxClip[dce_DCEList,{{x1_,x2_},{y1_,y2_}}] :=
  Module[{clip,dce1 = dce,edges,v,c,p,p1,p2,t1,t2,l,lx1,lx2,ly1,ly2},
    clip[v_,c_] :=
      (l = {};
       Scan[(p1 = VertexCoord[dce1,EdgeOrigin[dce1,#]];
             p2 = VertexCoord[dce1,EdgeEnd[dce1,#]];
             t1 = Chop[p1 . v - c]; 
             t2 = Chop[p2 . v - c];
             Switch[{t1,t2},
               {_?NonNegative,_?NonNegative},
                 dce1 = DeleteEdge[dce1,#],
               {_?Negative,_?Positive},
                 p = p1 (1 + t1/(t2 - t1)) - p2 t1/(t2 - t1);
                 dce1 = SplitEdge[dce1,#,p];
                 dce1 = DeleteEdge[dce1,Length[EdgeList[dce1]]];
                 AppendTo[l,{p,#}],
               {_?Positive,_?Negative},
                 p = p1 (1 + t1/(t2 - t1)) - p2 t1/(t2 - t1);
                 dce1 = SplitEdge[dce1,#,p];
                 dce1 = DeleteEdge[dce1,#];
                 AppendTo[l,{p,Length[EdgeList[dce1]] - 1}],
               {_,0},
                 AppendTo[l,{p2,#}],
               {0,_},
                 AppendTo[l,{p1,TwinEdge[#]}]])&,
            Flatten[Partition[Edges[dce1],1,2]]]; l);
    lx1 = clip[{-1,0},-x1]; lx2 = clip[{1,0},x2];
    ly1 = clip[{0,-1},-y1]; ly2 = clip[{0,1},y2];
    edges = Edges[dce1];
    lx1 = Select[lx1,
      (MemberQ[edges,#[[2]]] &&
       Chop[VertexCoord[dce1,EdgeEnd[dce1,#[[2]]]][[1]] - x1] == 0)&];    
    lx2 = Select[lx2,
      (MemberQ[edges,#[[2]]] &&
       Chop[VertexCoord[dce1,EdgeEnd[dce1,#[[2]]]][[1]] - x2] == 0)&];    
    ly1 = Select[ly1,
      (MemberQ[edges,#[[2]]] &&
       Chop[VertexCoord[dce1,EdgeEnd[dce1,#[[2]]]][[2]] - y1] == 0)&];    
    ly2 = Select[ly2,
      (MemberQ[edges,#[[2]]] &&
       Chop[VertexCoord[dce1,EdgeEnd[dce1,#[[2]]]][[2]] - y2] == 0)&];   
    lx1 = Sort[lx1,(#1[[1,2]] > #2[[1,2]])&];
    lx2 = Sort[lx2,(#1[[1,2]] < #2[[1,2]])&];    
    ly1 = Sort[ly1,(#1[[1,1]] < #2[[1,1]])&];    
    ly2 = Sort[ly2,(#1[[1,1]] > #2[[1,1]])&];
    e1 = ly1[[1,2]]; e2 = NextEdge[dce1,e1];
    dce1 = InsertEdge[dce1,e1,e2,{x1,y1}];
    AppendTo[lx1,{{x1,y1},Length[EdgeList[dce1]] - 1}];
    Do[dce1 = InsertEdge[dce1,ly1[[i,2]],NextEdge[dce1,ly1[[i,2]]],
                         ly1[[i + 1,2]],NextEdge[dce1,ly1[[i + 1,2]]]],
       {i,1,Length[ly1] - 1}];
    e1 = ly1[[-1,2]]; e2 = NextEdge[dce1,e1];
    dce1 = InsertEdge[dce1,e1,e2,{x2,y1}];
    PrependTo[lx2,{{x2,y1},Length[EdgeList[dce1]] - 1}];
    Do[dce1 = InsertEdge[dce1,lx2[[i,2]],NextEdge[dce1,lx2[[i,2]]],
                         lx2[[i + 1,2]],NextEdge[dce1,lx2[[i + 1,2]]]],
       {i,1,Length[lx2] - 1}];
    e1 = lx2[[-1,2]]; e2 = NextEdge[dce1,e1];
    dce1 = InsertEdge[dce1,e1,e2,{x2,y2}];
    PrependTo[ly2,{{x2,y2},Length[EdgeList[dce1]] - 1}];
    Do[dce1 = InsertEdge[dce1,ly2[[i,2]],NextEdge[dce1,ly2[[i,2]]],
                         ly2[[i + 1,2]],NextEdge[dce1,ly2[[i + 1,2]]]],
       {i,1,Length[ly2] - 1}];
    e1 = ly2[[-1,2]]; e2 = NextEdge[dce1,e1];
    dce1 = InsertEdge[dce1,e1,e2,{x1,y2}];
    PrependTo[lx1,{{x1,y2},Length[EdgeList[dce1]] - 1}];
    Do[dce1 = InsertEdge[dce1,lx1[[i,2]],NextEdge[dce1,lx1[[i,2]]],
                         lx1[[i + 1,2]],NextEdge[dce1,lx1[[i + 1,2]]]],
       {i,1,Length[lx1] - 1}];
    edges = Edges[dce1];
    While[Not[NullQ[p = FirstPosition[edges,
                          _?((And[Not[NullQ[#]],
                                  Chop[EdgeLength[dce1,#]] == 0])&)]]],
      dce1 = ContractEdge[dce1,edges[[p]]]];
    dce1]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["EdgeLength[dce,e]",
    FontWeight->"Bold"],
  "\nLunghezza dello spigolo e della struttura dce.\n",
  StyleBox["LoopLength[dce,e]",
    FontWeight->"Bold"],
  "\nLunghezza del cappio uscente dallo spigolo e della struttura dce.\n",
  StyleBox["FaceOuterLength[dce,f]  FaceTotalLength[dce,f]",
    FontWeight->"Bold"],
  "\nPerimetro estreno/totale della faccia e della struttura dce.\n",
  StyleBox["TotalLength[dce]",
    FontWeight->"Bold"],
  "\nSomma delle lunghezze di tutti gli spigoli della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[EdgeLength,LoopLength,TotalLength,
         FaceOuterLength,FaceTotalLength]

EdgeLength[dce_DCEList,e_] := 
  LineLength[VertexCoord[dce,{EdgeOrigin[dce,e],EdgeEnd[dce,e]}]]

LoopLength[dce_DCEList,e_] := 
  Apply[Plus,Map[EdgeLength[dce,#]&,EdgeLoop[dce,e]]]

TotalLength[dce_DCEList] := 
  Apply[Plus,Map[EdgeLength[dce,#]&,
                 Flatten[Partition[Edges[dce],1,2]]]]

FaceOuterLength[dce_DCEList,f_] := 
  LoopLength[dce,FaceOuterEdge[dce,f]] 
  
FaceTotalLength[dce_DCEList,f_] := 
  Apply[Plus,Map[LoopLength[dce,#]&,FaceEdges[dce,f]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["LoopArea[dce,e]",
    FontWeight->"Bold"],
  "\nArea delimitata dal cappio uscente dallo spigolo e della struttura dce, \
positiva/negativa a seconda dell'orientazione del cappio.",
  StyleBox["\nFaceArea[dce,f]",
    FontWeight->"Bold"],
  "\nArea della faccia f della struttura dce.\n",
  StyleBox["TotalArea[dce]",
    FontWeight->"Bold"],
  "\nSomma delle aree di tutte le facce limitate della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[LoopArea,FaceArea,TotalArea]

LoopArea[dce_DCEList,e_] := 
  PolygonArea[Map[VertexCoord[dce,EdgeOrigin[dce,#]]&,EdgeLoop[dce,e]]]

FaceArea[dce_DCEList,f_] := 
  Apply[Plus,Map[LoopArea[dce,#]&,FaceEdges[dce,f]]]

TotalArea[dce_DCEList] := 
  - Apply[Plus,Map[LoopArea[dce,#]&,
          FaceInnerEdges[dce,UnboundedFace[dce]]]]
  \
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["InsideLoopQ[dce,e,p]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se il punto p sta all'interno della \
regione bordata dal cappio di spigoli consecutivi della struttura dce che \
contiene lo spigolo e.\n",
  StyleBox["InsideFaceQ[dce,f,p]",
    FontWeight->"Bold"],
  "\nEspressione booleana vera se e solo se il punto p sta all'interno della \
faccia f della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[InsideLoopQ,InsideFaceQ]

InsideLoopQ[dce_DCEList,e_,x_] := 
  Module[{v = Map[VertexCoord[dce,EdgeOrigin[dce,#]]&,EdgeLoop[dce,e]]},
    SameQ[PointPolygonClass[x,v],If[SameQ[EdgeComp[dce,e],1],1,0]]]

InsideFaceQ[dce_DCEList,f_,x_] := 
  Module[{e = DeleteCases[FaceEdges[dce,f],0]},
    Apply[And,Map[InsideLoopQ[dce,#,x]&,e]]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["FaceToPolygon[dce,f]\n",
    FontWeight->"Bold"],
  "Polygon corrispondente alla faccia f della struttura dce se questa e \
limitata o al suo complementare (cioe' all'unione delle faccie limitate) se \
questa e' illimitata.\n",
  StyleBox["EdgeToLine[dce,e]",
    FontWeight->"Bold"],
  "\nLine corrispondente allo spigolo e della struttura dce.\n",
  StyleBox["VertexToPoint[dce,v]",
    FontWeight->"Bold"],
  "\nPoint corrispondente al vertice v della struttura dce."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[FaceToPolygon,EdgeToLine,VertexToPoint]
SetAttributes[{FaceToPolygon,EdgeToLine,VertexToPoint},Listable]

FaceToPolygon[dce_DCEList,f_] := 
  Module[{edges,concat},
    edges = If[BoundedQ[dce,f],
               Join[{FaceOuterBoundary[dce,f]},
                    FaceInnerBoundaries[dce,f]],
               Map[Reverse,FaceInnerBoundaries[dce,f]]];
    concat[l_,ll_] :=
      If[EmptyQ[ll],l,
         concat[Join[l,{First[l]},First[ll],{First[ll][[1]]}],
                Rest[ll]]];
    Polygon[Map[VertexCoord[dce,EdgeOrigin[dce,#]]&,
                concat[First[edges],Rest[edges]]]]]
    
EdgeToLine[dce_DCEList,e_] := 
  Line[VertexCoord[dce,{EdgeOrigin[dce,e],EdgeEnd[dce,e]}]]

VertexToPoint[dce_DCEList,v_] := Point[VertexCoord[dce,v]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}],

Cell[TextData[{
  StyleBox["RegionToDCEList[reg]",
    FontWeight->"Bold"],
  "\nStruttura DCEList corrispondente alla regione reg data mediante un \
Polygon se e' semplicemente connessa o mediante una lista di Polygon (di cui \
il primo esterno e gli altri interni) altrimenti, tutti orientati come bordo \
della regione reg."
}], "Text",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  CellSize->{462, Inherited}],

Cell["\<\
ClearAll[RegionToDCEList]

RegionToDCEList[Polygon[x_]] := 
  Module[{n = Length[x]}, 
    DCEList[
      {{1},{0,2}},
      Table[If[OddQ[i],
               {1,1,Mod[i - 2,2 n],
                Mod[i + 2,2 n],(i + 1)/2},
               {2,2,Mod[i + 1,2 n] + 1,
                Mod[i - 3,2 n] + 1,Mod[i/2,n] + 1}],
            {i,1,2 n}],
      Table[{i},{i,1,2 n - 1,2}],x]]
 
RegionToDCEList[l_List] :=
  Module[{outbd = RegionToDCEList[First[l]],
          inbdlist = Map[RegionToDCEList,Rest[l]],
          addholes},
    addholes[reg_,holes_] :=
      If[EmptyQ[holes],reg,
         Module[{f = Length[FaceList[reg]],
                 e = Length[EdgeList[reg]],
                 v = Length[VertexList[reg]],
                 hole = First[holes]},
           addholes[
             DCEList[
               Append[Insert[FaceList[reg],e + 1,{1,-1}],{e + 2}],
               Join[EdgeList[reg],
                    EdgeList[hole] /. 
                      {{1,_,p_,n_,o_} :> {1,f,p + e,n + e,o + v},
                       {2,_,p_,n_,o_} :> {f + 1,1,p + e,n + e,o + v}}],
               Join[VertexList[reg],VertexList[hole] + e],
               Join[CoordList[reg],CoordList[hole]]],
             Rest[holes]]]];
    addholes[outbd,inbdlist]]
\
\>", "Input",
  PageWidth->WindowWidth,
  CellMargins->{{Inherited, 0}, {Inherited, Inherited}},
  InitializationCell->True,
  CellSize->{518, Inherited}]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 748}},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{553, 714},
WindowMargins->{{0, Automatic}, {Automatic, 1}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->7,
    FontSize->10],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellMargins->{{6, 6}, {Inherited, Inherited}},
    ScriptMinSize->9,
    FontSize->12,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    WindowSize->{565, Automatic},
    WindowMargins->{{2, Automatic}, {2, 2}},
    PageHeaders->{{None, None, None}, {None, None, None}},
    PageFooters->{{None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}, {None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"], " / ", 
              CounterBox[ "Page"]}], "Footer"], None}},
    PageHeaderLines->{False, False},
    PageFooterLines->{False, False},
    CellFrameLabelMargins->6,
    StyleMenuListing->None,
    FontFamily->"Times"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{6, 6}, {32, 16}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{6, 6}, {16, 8}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->48],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->24],
  
  Cell[StyleData["Title", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{6, 6}, {16, 8}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    TextJustification->0,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Courier",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{6, 6}, {8, 4}},
    TextAlignment->Center,
    FontSize->32],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{6, 6}, {4, 2}},
    TextAlignment->Center,
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Printout"],
    TextAlignment->Center]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{9, 6}, {12, 4}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Left,
    TextJustification->0,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{9, 6}, {12, 4}},
    TextAlignment->Left,
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{9, 6}, {2, 1}},
    TextAlignment->Left,
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{9, Inherited}, {12, 4}},
    TextAlignment->Left]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {12, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{28, Inherited}, {6, 4}},
    LineSpacing->{1, 0},
    FontSize->28],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{28, Inherited}, {6, 4}},
    FontSize->16],
  
  Cell[StyleData["Section", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {8, 6}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Courier",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{28, Inherited}, {4, 2}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{28, Inherited}, {4, 2}},
    FontSize->14],
  
  Cell[StyleData["Subsection", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{28, Inherited}, {4, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{28, Inherited}, {2, 2}},
    LineSpacing->{1, 0},
    FontSize->20],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{28, Inherited}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["Subsubsection", "Printout"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"Text",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["Text", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->24],
  
  Cell[StyleData["Text", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Text", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {2, 2}},
    CounterIncrements->"SmallText",
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[0.849989]],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->18],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellFrame->True,
    CellMargins->{{9, Inherited}, {Inherited, Inherited}}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{17, Inherited}, {2, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[StyleData["Input", "Presentation"],
    PageWidth->Infinity,
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Condensed"],
    PageWidth->Infinity,
    CellMargins->{{17, Inherited}, {1, 2}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Input", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontTracking->"Plain",
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False}],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Output",
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.700008]],
  
  Cell[StyleData["Output", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Output", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.8, 0, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Message", "Printout"],
    ScriptSizeMultipliers->0.7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Print", "Presentation"],
    ScriptSizeMultipliers->0.75,
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Print", "Printout"],
    ScriptSizeMultipliers->0.7]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{17, Inherited}, {2, 2}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{6, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    FormatType->InputForm,
    ScriptSizeMultipliers->0.8,
    CounterIncrements->"Graphics",
    ImageSize->{500, 500},
    ImageMargins->{{0, 0}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Graphics", "Presentation"],
    ScriptSizeMultipliers->0.75,
    ImageSize->{800, 500},
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["Graphics", "Condensed"],
    CellMargins->{{17, Inherited}, {1, 1}},
    ScriptSizeMultipliers->0.85,
    FontSize->10],
  
  Cell[StyleData["Graphics", "Printout"],
    ScriptSizeMultipliers->0.7,
    ImageSize->{500, 300}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{6, Inherited}, {2, 2}},
    LineSpacing->{1, 2},
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"]],
  
  Cell[StyleData["InlineFormula", "Condensed"]],
  
  Cell[StyleData["InlineFormula", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{56, Inherited}, {4, 4}},
    CellHorizontalScrolling->True,
    TextAlignment->Left,
    TextJustification->0,
    LineSpacing->{1, 4},
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"]],
  
  Cell[StyleData["DisplayFormula", "Condensed"]],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    StyleMenuListing->None],
  
  Cell[StyleData["Footer"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{6, 6}, {4, 4}},
    TextAlignment->Center,
    TextJustification->0,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->PrimaryPlaceholder,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    LineSpacing->{1, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    TextAlignment->Left,
    LineSpacing->{0.85, -3},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003?T97OnPokT=E@UX0fL5N`?P0080004/0B`000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000008000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 356, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[2076, 63, 783, 20, 152, "Subsubtitle"],
Cell[2862, 85, 395, 10, 80, "Text"],
Cell[3260, 97, 180, 9, 97, "Input",
  InitializationCell->True],
Cell[3443, 108, 348, 8, 65, "Text"],
Cell[3794, 118, 312, 12, 136, "Input",
  InitializationCell->True],
Cell[4109, 132, 298, 8, 65, "Text"],
Cell[4410, 142, 745, 20, 201, "Input",
  InitializationCell->True],
Cell[5158, 164, 365, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[5526, 178, 363, 10, 80, "Text"],
Cell[5892, 190, 275, 10, 110, "Input",
  InitializationCell->True],
Cell[6170, 202, 873, 18, 170, "Text"],
Cell[7046, 222, 722, 21, 214, "Input",
  InitializationCell->True],
Cell[7771, 245, 695, 15, 140, "Text"],
Cell[8469, 262, 621, 20, 188, "Input",
  InitializationCell->True],
Cell[9093, 284, 784, 18, 185, "Text"],
Cell[9880, 304, 605, 17, 201, "Input",
  InitializationCell->True],
Cell[10488, 323, 683, 16, 155, "Text"],
Cell[11174, 341, 596, 18, 162, "Input",
  InitializationCell->True],
Cell[11773, 361, 366, 12, 36, "Subsubtitle",
  Evaluatable->False],
Cell[12142, 375, 1186, 21, 290, "Text"],
Cell[13331, 398, 1263, 33, 370, "Input",
  InitializationCell->True],
Cell[14597, 433, 636, 18, 140, "Text"],
Cell[15236, 453, 358, 15, 136, "Input",
  InitializationCell->True],
Cell[15597, 470, 708, 16, 155, "Text"],
Cell[16308, 488, 1324, 34, 383, "Input",
  InitializationCell->True],
Cell[17635, 524, 1461, 30, 320, "Text"],
Cell[19099, 556, 1083, 34, 383, "Input",
  InitializationCell->True],
Cell[20185, 592, 679, 18, 170, "Text"],
Cell[20867, 612, 501, 16, 149, "Input",
  InitializationCell->True],
Cell[21371, 630, 771, 18, 170, "Text"],
Cell[22145, 650, 700, 24, 253, "Input",
  InitializationCell->True],
Cell[22848, 676, 890, 21, 215, "Text"],
Cell[23741, 699, 553, 18, 175, "Input",
  InitializationCell->True],
Cell[24297, 719, 677, 18, 170, "Text"],
Cell[24977, 739, 518, 17, 162, "Input",
  InitializationCell->True],
Cell[25498, 758, 1112, 23, 245, "Text"],
Cell[26613, 783, 7420, 186, 2359, "Input",
  InitializationCell->True],
Cell[34036, 971, 703, 14, 155, "Text"],
Cell[34742, 987, 2406, 62, 747, "Input",
  InitializationCell->True],
Cell[37151, 1051, 600, 13, 125, "Text"],
Cell[37754, 1066, 746, 21, 214, "Input",
  InitializationCell->True],
Cell[38503, 1089, 289, 8, 65, "Text"],
Cell[38795, 1099, 308, 12, 97, "Input",
  InitializationCell->True],
Cell[39106, 1113, 375, 10, 65, "Text"],
Cell[39484, 1125, 3665, 83, 1020, "Input",
  InitializationCell->True],
Cell[43152, 1210, 667, 16, 140, "Text"],
Cell[43822, 1228, 728, 24, 253, "Input",
  InitializationCell->True],
Cell[44553, 1254, 566, 14, 125, "Text"],
Cell[45122, 1270, 507, 17, 162, "Input",
  InitializationCell->True],
Cell[45632, 1289, 552, 13, 125, "Text"],
Cell[46187, 1304, 506, 15, 136, "Input",
  InitializationCell->True],
Cell[46696, 1321, 623, 15, 140, "Text"],
Cell[47322, 1338, 923, 26, 279, "Input",
  InitializationCell->True],
Cell[48248, 1366, 452, 10, 95, "Text"],
Cell[48703, 1378, 1412, 41, 474, "Input",
  InitializationCell->True]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

